@@ -5,7 +5,7 @@
  * Project led by Terence Parr at http://www.jGuru.com
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: LLkParser.hpp 312 2008-07-05 17:40:12Z vadim $
+ * $Id: LLkParser.hpp 646 2008-11-13 06:33:44Z vadim $
  */
 
 #include <antlr/config.hpp>
@@ -46,10 +46,8 @@ public:
 		return inputState->getInput().LA(i);
 	}
 
-	virtual inline RefToken LT(unsigned int i)
-	{
-		return inputState->getInput().LT(i);
-	}
+	virtual RefToken LT(unsigned int i);
+
 protected:
 	/// the lookahead this LL(k) parser is using.
 	int k;
