@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_cisco_acls.cpp,v 1.1 2008/03/06 06:48:57 vkurland Exp $
+  $Id: PolicyCompiler_cisco_acls.cpp 338 2008-07-07 18:29:33Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -65,12 +65,12 @@ bool PolicyCompiler_cisco::setInterfaceAndDirectionBySrc::processNext()
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
     Helper helper(compiler);
 
-    RuleElementItf *itfre=rule->getItf();
-    RuleElementSrc *srcre=rule->getSrc();
+    //RuleElementItf *itfre = rule->getItf();
+    RuleElementSrc *srcre = rule->getSrc();
 
-    list<string> intf_id_list;
+    list<int> intf_id_list;
 
-    if (rule->getInterfaceId().empty())
+    if (rule->getInterfaceId() == -1)
     {
         if (rule->getDirection()==PolicyRule::Both)
             intf_id_list = helper.findInterfaceByNetzoneOrAll( srcre );
@@ -78,15 +78,17 @@ bool PolicyCompiler_cisco::setInterfaceAndDirectionBySrc::processNext()
         if (rule->getDirection()==PolicyRule::Inbound)
             intf_id_list = helper.getAllInterfaceIDs();
 
-        for (list<string>::iterator i = intf_id_list.begin(); i!=intf_id_list.end(); ++i)
+        for (list<int>::iterator i = intf_id_list.begin();
+             i!=intf_id_list.end(); ++i)
         {
-            string intf_id = *i;
+            int intf_id = *i;
             Interface *ifs = Interface::cast(
                 rule->getRoot()->findInIndex(intf_id) );
             assert(ifs);
             if (ifs->isUnprotected()) continue;   // skip!
 
-            PolicyRule *new_rule= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
+            PolicyRule *new_rule = PolicyRule::cast(
+                compiler->dbcopy->create(PolicyRule::TYPENAME) );
             compiler->temp_ruleset->add(new_rule);
             new_rule->duplicate(rule);
             new_rule->setInterfaceId(intf_id);
@@ -114,12 +116,12 @@ bool PolicyCompiler_cisco::setInterfaceAndDirectionByDst::processNext()
         return true;
     }
 
-    RuleElementItf *itfre=rule->getItf(); 
+    //RuleElementItf *itfre=rule->getItf(); 
     RuleElementDst *dstre=rule->getDst();
 
-    list<string> intf_id_list;
+    list<int> intf_id_list;
 
-    if (rule->getInterfaceId().empty())
+    if (rule->getInterfaceId() == -1)
     {
         if (rule->getDirection()==PolicyRule::Both)
             intf_id_list = helper.findInterfaceByNetzoneOrAll( dstre );
@@ -127,15 +129,18 @@ bool PolicyCompiler_cisco::setInterfaceAndDirectionByDst::processNext()
         if (rule->getDirection()==PolicyRule::Outbound)
             intf_id_list = helper.getAllInterfaceIDs();
 
-        for (list<string>::iterator i = intf_id_list.begin(); i!=intf_id_list.end(); ++i)
+
+        for (list<int>::iterator i = intf_id_list.begin();
+             i!=intf_id_list.end(); ++i)
         {
-            string intf_id = *i;
+            int intf_id = *i;
             Interface *ifs = Interface::cast(
                 rule->getRoot()->findInIndex(intf_id) );
             assert(ifs);
             if (ifs->isUnprotected()) continue;   // skip!
 
-            PolicyRule *new_rule= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
+            PolicyRule *new_rule = PolicyRule::cast(
+                compiler->dbcopy->create(PolicyRule::TYPENAME) );
             compiler->temp_ruleset->add(new_rule);
             new_rule->duplicate(rule);
             new_rule->setInterfaceId(intf_id);
@@ -153,9 +158,9 @@ bool PolicyCompiler_cisco::setInterfaceAndDirectionIfInterfaceSet::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
 
-    RuleElementItf *itfre=rule->getItf(); 
+    //RuleElementItf *itfre=rule->getItf(); 
 
-    if (rule->getInterfaceId().empty() ||
+    if (rule->getInterfaceId() == -1 ||
         rule->getBool("interface_and_direction_set_from_src") ||
         rule->getBool("interface_and_direction_set_from_dst"))
     {
@@ -165,14 +170,14 @@ bool PolicyCompiler_cisco::setInterfaceAndDirectionIfInterfaceSet::processNext()
 
     PolicyRule *new_rule;
                     
-    if ( ! rule->getInterfaceId().empty() )
+    if ( rule->getInterfaceId() > -1 )
     {
-        string rule_iface_id = rule->getInterfaceId();
+        int rule_iface_id = rule->getInterfaceId();
 
         if (rule->getDirection()==PolicyRule::Both)
         {
             new_rule =
-                PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
+                PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME));
             compiler->temp_ruleset->add(new_rule);
             new_rule->duplicate(rule);
             new_rule->setInterfaceId( rule_iface_id );
@@ -181,7 +186,7 @@ bool PolicyCompiler_cisco::setInterfaceAndDirectionIfInterfaceSet::processNext()
             tmp_queue.push_back(new_rule);
 
             new_rule =
-                PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
+                PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME));
             compiler->temp_ruleset->add(new_rule);
             new_rule->duplicate(rule);
             new_rule->setInterfaceId( rule_iface_id );
@@ -191,7 +196,7 @@ bool PolicyCompiler_cisco::setInterfaceAndDirectionIfInterfaceSet::processNext()
         } else
         {
             new_rule =
-                PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
+                PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME));
             compiler->temp_ruleset->add(new_rule);
             new_rule->duplicate(rule);
             new_rule->setInterfaceId( rule_iface_id );
@@ -205,13 +210,16 @@ bool PolicyCompiler_cisco::setInterfaceAndDirectionIfInterfaceSet::processNext()
 
 bool PolicyCompiler_cisco::pickACL::processNext()
 {
-    PolicyCompiler_cisco *cisco_comp=dynamic_cast<PolicyCompiler_cisco*>(compiler);
+    PolicyCompiler_cisco *cisco_comp=dynamic_cast<PolicyCompiler_cisco*>(
+        compiler);
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
     
-    Interface  *rule_iface = compiler->getCachedFwInterface(rule->getInterfaceId());
+    Interface  *rule_iface = compiler->getCachedFwInterface(
+        rule->getInterfaceId());
     if(rule_iface==NULL)
     {
-        compiler->abort("Missing interface assignment for rule "+rule->getLabel());
+        compiler->abort("Missing interface assignment for rule " + 
+                        rule->getLabel());
     }
 
     /*
@@ -245,10 +253,23 @@ bool PolicyCompiler_cisco::pickACL::processNext()
      */
     string acl_name = rule_iface->getLabel();
     if (acl_name.empty()) acl_name = rule_iface->getName();
-    acl_name = cisco_comp->mangleInterfaceName(acl_name) + "_acl";
+    acl_name = cisco_comp->mangleInterfaceName(acl_name);
     string dir = "in";
-    if (rule->getDirection() == PolicyRule::Inbound)  { acl_name += "_in"; dir="in"; }
-    if (rule->getDirection() == PolicyRule::Outbound) { acl_name += "_out"; dir="out"; }
+    if (rule->getDirection() == PolicyRule::Inbound)
+    {
+        acl_name += "_in"; dir="in";
+    }
+    if (rule->getDirection() == PolicyRule::Outbound)
+    {
+        acl_name += "_out"; dir="out";
+    }
+
+    // if this is not the "main" rule set, use its name for the acl name
+    if (!compiler->getSourceRuleSet()->isTop())
+        acl_name = compiler->getSourceRuleSet()->getName() + "_" + acl_name;
+
+    if (cisco_comp->ipv6) acl_name = "ipv6_" + acl_name;
+
     rule->setStr("acl",acl_name);
 
     ciscoACL *acl = new ciscoACL(acl_name, rule_iface, dir, using_named_acl);
@@ -266,7 +287,8 @@ bool PolicyCompiler_cisco::pickACL::processNext()
  * in a human-readable way.
  */
 
-std::string PolicyCompiler_cisco::mangleInterfaceName(const string &interface_name)
+std::string PolicyCompiler_cisco::mangleInterfaceName(
+    const string &interface_name)
 {
     string::size_type n;
     string s = interface_name;
