@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: ActionsDialog.cpp 511 2008-09-01 07:40:48Z vadim $
+  $Id: ActionsDialog.cpp 647 2008-11-14 07:03:21Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -266,7 +266,7 @@ void ActionsDialog::setRule(PolicyRule *r )
     fillInterfaces(m_dialog->ipf_route_opt_if);
     fillInterfaces(m_dialog->pf_route_opt_if);
 
-    editor = Resources::getActionEditor(platform,act);
+    editor = Resources::getActionEditor(platform, act);
 
     branchNameInput = NULL;
 
@@ -358,12 +358,14 @@ void ActionsDialog::setRule(PolicyRule *r )
         w=m_dialog->TagIntPage;
         FWObject *o = rule->getTagObject();
         m_dialog->iptTagDropArea->setObject(o);
+        m_dialog->iptTagDropArea->update();
     }
     else if (editor=="TagStr")
     {
         w=m_dialog->TagStrPage;
         FWObject *o = rule->getTagObject();
         m_dialog->pfTagDropArea->setObject(o);
+        m_dialog->pfTagDropArea->update();
     }
     else if (editor=="AccountingStr")
     {
