@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: ActionsDialog.h,v 1.8 2006/09/13 15:46:46 vkurland Exp $
+  $Id: ActionsDialog.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,9 +27,10 @@
 #ifndef __ACTIONSDIALOG_H_
 #define __ACTIONSDIALOG_H_
 
-#include "config.h"
-#include <actionsdialog_q.h>
+#include "../../config.h"
+#include <ui_actionsdialog_q.h>
 #include "DialogData.h"
+#include <QWidget>
 
 #include "fwbuilder/FWObject.h"
 #include "fwbuilder/Rule.h"
@@ -43,8 +44,8 @@ namespace libfwbuilder
 
 class QLineEdit;
 class QComboBox;
-
-class ActionsDialog : public ActionsDialog_q
+class FWObjectDropArea;
+class ActionsDialog : public QWidget
 {
     Q_OBJECT
  private:
@@ -55,8 +56,17 @@ class ActionsDialog : public ActionsDialog_q
     QLineEdit                *branchNameInput;
     
     DialogData                data;
+    FWObjectDropArea * BranchChainArea ;
+    FWObjectDropArea * BranchAnchorArea;
+    FWObjectDropArea * TagIntArea ;
+    FWObjectDropArea * TagStrArea ;
+
  public:
-    ActionsDialog(QWidget *parent) : ActionsDialog_q(parent){};
+    Ui::ActionsDialog_q *m_dialog;
+     
+    ActionsDialog(QWidget *parent);
+    
+    ~ActionsDialog();
     virtual void closeEvent(QCloseEvent *e);
     void fillInterfaces(QComboBox *);
 
