@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: AddressTableDialog.cpp,v 1.12 2007/04/14 00:18:43 vkurland Exp $
+  $Id: AddressTableDialog.cpp 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,19 +17,19 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 #include "utils.h"
+#include "ProjectPanel.h"
 
 #include "AddressTableDialog.h"
 #include "SimpleTextView.h"
-#include "ObjectManipulator.h"
 #include "FWBSettings.h"
 #include "FWWindow.h"
 
@@ -51,8 +51,9 @@
 #include <qcursor.h>
 #include <qfiledialog.h>
 #include <qfile.h>
-#include <qtextstream.h> 
+#include <qtextstream.h>
 #include <qdir.h>
+#include "FWBSettings.h"
 
 
 #include <iostream>
@@ -60,43 +61,50 @@
 using namespace std;
 using namespace libfwbuilder;
 
+AddressTableDialog::AddressTableDialog(ProjectPanel *project, QWidget *parent) : QWidget(parent), m_project(project)
+{
+    m_dialog = new Ui::AddressTableDialog_q;
+    m_dialog->setupUi(this);
+    obj=NULL;
+}
+
+AddressTableDialog::~AddressTableDialog()
+{
+    delete m_dialog;
+}
+
 void AddressTableDialog::loadFWObject(FWObject *o)
 {
     obj=o;
     AddressTable *s = dynamic_cast<AddressTable*>(obj);
     assert(s!=NULL);
-    
-    
+
+
     init=true;
 
-    fillLibraries(libs,obj);
+    m_dialog->obj_name->setText( QString::fromUtf8(s->getName().c_str()) );
+    m_dialog->comment->setText( QString::fromUtf8(s->getComment().c_str()) );
 
-    obj_name->setText( QString::fromUtf8(s->getName().c_str()) );
-    comment->setText( QString::fromUtf8(s->getComment().c_str()) );
-
-    filename->setText( s->getSourceName().c_str() );
-    r_compiletime->setChecked(s->isCompileTime() );
-    r_runtime->setChecked(s->isRunTime() );
+    m_dialog->filename->setText( s->getSourceName().c_str() );
+    m_dialog->r_compiletime->setChecked(s->isCompileTime() );
+    m_dialog->r_runtime->setChecked(s->isRunTime() );
 
     //BrowseButton->setEnabled(s->isCompileTime() );
-    
+
     //apply->setEnabled( false );
 
-    obj_name->setEnabled(!o->isReadOnly());
-    setDisabledPalette(obj_name);
+    m_dialog->obj_name->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->obj_name);
 
-    libs->setEnabled(!o->isReadOnly());
-    setDisabledPalette(libs);
+    m_dialog->filename->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->filename);
 
-    filename->setEnabled(!o->isReadOnly());
-    setDisabledPalette(filename);
-
-    comment->setReadOnly(o->isReadOnly());
-    setDisabledPalette(comment);
+    m_dialog->comment->setReadOnly(o->isReadOnly());
+    setDisabledPalette(m_dialog->comment);
 
     init=false;
 }
-    
+
 void AddressTableDialog::changed()
 {
     //BrowseButton->setEnabled(r_compiletime->isChecked() );
@@ -112,10 +120,10 @@ void AddressTableDialog::validate(bool *res)
     assert(s!=NULL);
 
     if (!isTreeReadWrite(this,obj)) { *res=false; return; }
-    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
+    if (!validateName(this,obj,m_dialog->obj_name->text())) { *res=false; return; }
 }
 
-void AddressTableDialog::isChanged(bool *res)
+void AddressTableDialog::isChanged(bool *)
 {
     //*res=(!init && apply->isEnabled());
 }
@@ -131,25 +139,16 @@ void AddressTableDialog::applyChanges()
     assert(s!=NULL);
 
     string oldname=obj->getName();
-    obj->setName( string(obj_name->text().utf8()) );
-    obj->setComment( string(comment->text().utf8()) );
-    QCString cs=filename->text().local8Bit();
+    obj->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
+    obj->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
+    QByteArray cs=m_dialog->filename->text().toLocal8Bit();
     s->setSourceName( (const char *)cs );
-    s->setRunTime(r_runtime->isChecked() );
+    s->setRunTime(m_dialog->r_runtime->isChecked() );
 
-    om->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
-
-    init=true;
-
-/* move to another lib if we have to */
-    if ( ! Interface::isA( obj->getParent() ) &&
-         libs->currentText() != QString(obj->getLibrary()->getName().c_str()))
-        om->moveObject(libs->currentText(), obj);
-
-    init=false;
+    mw->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
 
     //apply->setEnabled( false );
-    om->updateLastModifiedTimestampForAllFirewalls(obj);
+    mw->updateLastModifiedTimestampForAllFirewalls(obj);
 }
 
 void AddressTableDialog::discardChanges()
@@ -172,39 +171,37 @@ void AddressTableDialog::browse()
     dir=st->getWDir();
     if (dir.isEmpty())  dir=st->getOpenFileDir();
     if (dir.isEmpty())  dir="~";
-    
-    QString s = QFileDialog::getOpenFileName(
+
+    QString s = QFileDialog::getOpenFileName(this,
+                    "Choose a file",
                     dir,
-                    "All files (*.*)",
-                    this,
-                    "open file dialog",
-                    "Choose a file" );
-    
+                    "All files (*.*)");
+
     if (!s.isEmpty())
     {
-        filename->setText(s);
+        m_dialog->filename->setText(s);
     }
 }
 void AddressTableDialog::preview( void )
 {
     SimpleTextView tv(this);
-    tv.setName(obj_name->text());
-    
+    tv.setName(m_dialog->obj_name->text());
+
     QFile f;
     QTextStream ts;
-    QString filePath = filename->text();
+    QString filePath = m_dialog->filename->text();
 
     if (QDir::isRelativePath(filePath))
-        f.setName(getFileDir(mw->getCurrentFileName()) + "/" + filePath);
+        f.setFileName(getFileDir(mw->getCurrentFileName()) + "/" + filePath);
     else
-        f.setName(filePath);
+        f.setFileName(filePath);
 
     if (f.exists())
     {
-        if(f.open(IO_ReadOnly ))
+        if(f.open(QIODevice::ReadOnly ))
         {
             ts.setDevice(&f);
-            tv.setText(ts.read());
+            tv.setText(ts.readAll());
             f.close();
         }
     }
