@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: CommentEditorPanel.cpp,v 1.2 2006/08/08 21:25:37 vkurland Exp $
+  $Id: CommentEditorPanel.cpp 398 2008-07-21 01:47:01Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,7 +17,7 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
@@ -25,7 +25,7 @@
 
 
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 
 #include "CommentEditorPanel.h"
@@ -44,47 +44,54 @@
 using namespace std;
 using namespace libfwbuilder;
 
-CommentEditorPanel::CommentEditorPanel(QWidget *p,
-                                   bool enableLoadFromFile):CommentEditorPanel_q(p)
+CommentEditorPanel::~CommentEditorPanel()
 {
-    if (enableLoadFromFile) inputFromFileButton->show();
-    else                    inputFromFileButton->hide();
+    delete m_widget;
+}
 
-    editor->setTextFormat(QTextEdit::PlainText);
+CommentEditorPanel::CommentEditorPanel(QWidget *p,
+                                   bool enableLoadFromFile):QWidget(p)
+{
+    m_widget = new Ui::CommentEditorPanel_q;
+    m_widget->setupUi(this);
+
+    if (enableLoadFromFile) m_widget->inputFromFileButton->show();
+    else                    m_widget->inputFromFileButton->hide();
+
+    //m_widget->editor->setTextFormat(QTextEdit::PlainText);
     rule=NULL;
     //editor->setText(txt);
 }
 
 QString CommentEditorPanel::text()
 {
-    return editor->text();
+    return m_widget->editor->toPlainText();
 }
 void CommentEditorPanel::setText(QString s)
 {
-    editor->setText(s);
+    m_widget->editor->setText(s);
 }
 void CommentEditorPanel::setTitle(QString s)
 {
-    editorTitle->setText(s);
+    m_widget->editorTitle->setText(s);
 }
 
 void CommentEditorPanel::loadFromFile()
 {
     if ( QMessageBox::warning(
-       this,"Firewall Builder", 
+       this,"Firewall Builder",
        tr("Warning: loading from file discards current contents of the script."),
        "&Load", "&Cancel", QString::null, 0, 1 )==0)
     {
-        QString filename = QFileDialog::getOpenFileName( st->getWDir(),
-                                                         NULL,  this, NULL,
-                                                         tr("Choose file that contains PIX commands") );
+        QString filename = QFileDialog::getOpenFileName(
+                this, tr("Choose file that contains PIX commands"), st->getWDir());
         if (filename!="")
         {
-           ifstream ifile(filename.latin1());
+           ifstream ifile(filename.toLatin1().constData());
            if (!ifile)
            {
                QMessageBox::warning(
-                   this,"Firewall Builder", 
+                   this,"Firewall Builder",
                    tr("Could not open file %1").arg(filename),
                    "&Continue", QString::null, QString::null, 0, 1 );
                return;
@@ -93,27 +100,33 @@ void CommentEditorPanel::loadFromFile()
            char buf[1024];
            while (ifile.getline(buf,1024))
            {
-               editor->append( buf );
+               m_widget->editor->append( buf );
            }
         }
     }
 }
+
 void CommentEditorPanel::changed()
 {
     emit changed_sign();
 }
+
 void CommentEditorPanel::applyChanges()
 {
-    om->updateLastModifiedTimestampForAllFirewalls(rule);
-    rule->setComment( string(editor->text().utf8()) );
-    
+    if (fwbdebug) qDebug("CommentEditorPanel::applyChanges()");
+
+    mw->updateLastModifiedTimestampForAllFirewalls(rule);
+    rule->setComment(
+        string(m_widget->editor->toPlainText().toUtf8().constData())
+    );
 }
+
 void CommentEditorPanel::loadFWObject(FWObject *obj)
 {
     Rule *r=Rule::cast(obj);
 
     rule=r;
-    
+
     FWObject *o = r;
     while (o!=NULL && Firewall::cast(o)==NULL) o=o->getParent();
     assert(o!=NULL);
@@ -125,19 +138,22 @@ void CommentEditorPanel::loadFWObject(FWObject *obj)
             .arg(r->getTypeName().c_str())
             .arg(r->getPosition()));
 }
+
 void CommentEditorPanel::discardChanges()
 {
 }
+
 void CommentEditorPanel::validate(bool* b)
 {
     *b=true;
 }
+
 void CommentEditorPanel::isChanged(bool*)
 {
-    
+
 }
+
 void CommentEditorPanel::closeEvent(QCloseEvent *e)
 {
     emit close_sign(e);
-
 }
