@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: ConfirmDeleteObjectDialog.cpp,v 1.6 2007/05/23 03:05:50 vkurland Exp $
+  $Id: ConfirmDeleteObjectDialog.cpp 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,18 +17,18 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 #include "utils.h"
 #include "utils_no_qt.h"
 #include "platforms.h"
-#include "definitions.h"
+#include "../../definitions.h"
 
 #include "ConfirmDeleteObjectDialog.h"
 #include "FindWhereUsedWidget.h"
@@ -53,9 +53,9 @@
 #include "fwbuilder/Library.h"
 
 
-#include <qhbox.h> 
-#include <qlayout.h> 
-#include <qlistbox.h> 
+//#include <qhbox.h>
+#include <qlayout.h>
+#include <qlistwidget.h>
 #include <qpixmapcache.h>
 
 #include <vector>
@@ -63,20 +63,26 @@
 using namespace std;
 using namespace libfwbuilder;
 
-
-ConfirmDeleteObjectDialog::ConfirmDeleteObjectDialog(QWidget*p) : ConfirmDeleteObjectDialog_q(p) 
+ConfirmDeleteObjectDialog::ConfirmDeleteObjectDialog(QWidget*p) : QDialog(p)
 {
+    m_dialog = new Ui::ConfirmDeleteObjectDialog_q;
+    m_dialog->setupUi(this);
     //QVBoxLayout *b=new QVBoxLayout((QWidget*)FrameForList);
     //fwu = new FindWhereUsedWidget((QWidget*)FrameForList,0,0,  true);
     //b->addWidget(fwu);
-    
+
     //connect(objectsList, SIGNAL(selectionChanged(QListBoxItem *)), this, SLOT(listItemSelected(QListBoxItem *)));
 }
 
+ConfirmDeleteObjectDialog::~ConfirmDeleteObjectDialog()
+{
+    delete m_dialog;
+}
+
 void ConfirmDeleteObjectDialog::load(vector<FWObject *> objs)
 {
     if (objs.size()==0) return;
-    
+
     vector<FWObject*>::iterator i;
     for( i=objs.begin(); i!=objs.end(); ++i)
     {
@@ -90,30 +96,27 @@ void ConfirmDeleteObjectDialog::findForObject(FWObject *obj)
     //objectsView->clear();
     //mapping.clear();
     //resset.clear();
-    
-    string icn="icon-tree";
-//    QPixmap pm0 = QPixmap::fromMimeSource( 
-//        Resources::global_res->getObjResourceStr(obj, icn).c_str() );
+
     QPixmap pm0;
-    QString icn_file = Resources::global_res->getObjResourceStr(obj, icn).c_str();
+    QString icn_file = (":/Icons/" + obj->getTypeName() + "/icon-tree").c_str();
+
     if ( ! QPixmapCache::find( icn_file, pm0) )
     {
-        pm0 = QPixmap::fromMimeSource( icn_file );
+        pm0.load( icn_file );
         QPixmapCache::insert( icn_file, pm0);
     }
-        
-    
+
     mw->db()->findWhereUsed(obj,mw->db(),resset);
 
     if (fwbdebug)
     {
         qDebug(QString("ConfirmDeleteObjectDialog::findForObject   deleting obj=%1").
-               arg(obj->getName().c_str()));
-        qDebug(QString("resset.size()==%1").arg(resset.size()));
+               arg(obj->getName().c_str()).toAscii().constData());
+        qDebug(QString("resset.size()==%1").arg(resset.size()).toAscii().constData());
     }
 
     set<FWObject*>::iterator i=resset.begin();
-    QListViewItem *item;
+    QTreeWidgetItem *item;
     QString c1;
     QString c2;
     FWObject* o;
@@ -129,29 +132,29 @@ void ConfirmDeleteObjectDialog::findForObject(FWObject *obj)
         fw=NULL;
         r=NULL;
         rs=NULL;
-            
+
         if (findRef(obj,o)==NULL) continue;
 
-        if (RuleElement::cast(o)!=NULL)            
+        if (RuleElement::cast(o)!=NULL)
         {
             fw=o->getParent();
-            
-            while (fw!=NULL && !Firewall::isA(fw)) 
+
+            while (fw!=NULL && !Firewall::isA(fw))
             {
                 if (Rule::cast(fw))
                 {
-                    r=Rule::cast(fw); 
+                    r=Rule::cast(fw);
                 } else if (RuleSet::cast(fw))
                 {
                     rs=RuleSet::cast(fw);
                 }
-                        
+
                 fw=fw->getParent();
             }
             if (fw==NULL || r==NULL || rs==NULL) continue;
-            
+
             c1=QString::fromUtf8(fw->getName().c_str());
-            
+
             if (NAT::isA(rs))
             {
                 c2=tr("NAT");
@@ -166,11 +169,11 @@ void ConfirmDeleteObjectDialog::findForObject(FWObject *obj)
                 c2=tr("Unknown rule set");
             }
             c2+=tr("/Rule%1").arg(r->getPosition());
-            
+
         } else if (
-                FWBTree::isSystem(o) ||
-                Rule::cast(o) || 
-                RuleSet::cast(o) || 
+                mw->isSystem(o) ||
+                Rule::cast(o) ||
+                RuleSet::cast(o) ||
                 Firewall::cast(o) ||
                 Library::cast(o))
         {
@@ -184,23 +187,23 @@ void ConfirmDeleteObjectDialog::findForObject(FWObject *obj)
 
         string icn="icon-tree";
 //        FWObject *pixobj=(fw==NULL)?o:fw;
-//        QPixmap pm = QPixmap::fromMimeSource( 
+//        QPixmap pm = QPixmap::fromMimeSource(
 //            Resources::global_res->getObjResourceStr(pixobj, icn).c_str() );
-        
-        item = new QListViewItem(
-            objectsView,
-            QString::fromUtf8( obj->getName().c_str()),c1,c2);
-        item->setPixmap(0,pm0);
+
+        QStringList qsl;
+        qsl << QString::fromUtf8( obj->getName().c_str()) << c1 << c2;
+        item = new QTreeWidgetItem(m_dialog->objectsView, qsl);
+        item->setIcon(0,QIcon(pm0));
 
         itemCounter++;
     }
 
     if (itemCounter==0)
     {
-        item = new QListViewItem(
-            objectsView,
-            QString::fromUtf8( obj->getName().c_str()),
-            tr("Not used anywhere"),"");
-        item->setPixmap(0,pm0);
+        QStringList qsl;
+        qsl << QString::fromUtf8( obj->getName().c_str())
+            << tr("Not used anywhere") << "";
+        item = new QTreeWidgetItem(m_dialog->objectsView, qsl);
+        item->setIcon(0,QIcon(pm0));
     }
 }
