@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: DNSNameDialog.cpp,v 1.7 2007/04/14 00:18:43 vkurland Exp $
+  $Id: DNSNameDialog.cpp 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,18 +17,18 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 #include "utils.h"
 
 #include "DNSNameDialog.h"
-#include "ObjectManipulator.h"
+#include "ProjectPanel.h"
 
 #include "fwbuilder/Library.h"
 #include "fwbuilder/DNSName.h"
@@ -46,49 +46,58 @@
 #include <qpushbutton.h>
 #include <qapplication.h>
 #include <qcursor.h>
+#include "FWBSettings.h"
 
 #include <iostream>
 
+#include "FWWindow.h"
 using namespace std;
 using namespace libfwbuilder;
 
+DNSNameDialog::DNSNameDialog(ProjectPanel *project, QWidget *parent) : QWidget(parent), m_project(project)
+{
+    m_dialog = new Ui::DNSNameDialog_q;
+    m_dialog->setupUi(this);
+    obj=NULL;
+}
+
+DNSNameDialog::~DNSNameDialog()
+{
+    delete m_dialog;
+}
+
 void DNSNameDialog::loadFWObject(FWObject *o)
 {
     obj=o;
     DNSName *s = dynamic_cast<DNSName*>(obj);
     assert(s!=NULL);
-    
-    
+
+
     init=true;
 
-    fillLibraries(libs,obj);
+    m_dialog->obj_name->setText( QString::fromUtf8(s->getName().c_str()) );
+    m_dialog->comment->setText( QString::fromUtf8(s->getComment().c_str()) );
 
-    obj_name->setText( QString::fromUtf8(s->getName().c_str()) );
-    comment->setText( QString::fromUtf8(s->getComment().c_str()) );
+    m_dialog->dnsrec->setText( s->getSourceName().c_str() );
+    m_dialog->r_compiletime->setChecked(s->isCompileTime() );
+    m_dialog->r_runtime->setChecked(s->isRunTime() );
 
-    dnsrec->setText( s->getSourceName().c_str() );
-    r_compiletime->setChecked(s->isCompileTime() );
-    r_runtime->setChecked(s->isRunTime() );
-    
     //apply->setEnabled( false );
 
-    obj_name->setEnabled(!o->isReadOnly());
-    setDisabledPalette(obj_name);
+    m_dialog->obj_name->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->obj_name);
 
-    libs->setEnabled(!o->isReadOnly());
-    setDisabledPalette(libs);
+    m_dialog->dnsrec->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->dnsrec);
 
-    dnsrec->setEnabled(!o->isReadOnly());
-    setDisabledPalette(dnsrec);
-
-    comment->setReadOnly(o->isReadOnly());
-    setDisabledPalette(comment);
+    m_dialog->comment->setReadOnly(o->isReadOnly());
+    setDisabledPalette(m_dialog->comment);
 
 
 
     init=false;
 }
-    
+
 void DNSNameDialog::changed()
 {
     //apply->setEnabled( true );
@@ -102,10 +111,10 @@ void DNSNameDialog::validate(bool *res)
     assert(s!=NULL);
 
     if (!isTreeReadWrite(this,obj)) { *res=false; return; }
-    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
+    if (!validateName(this,obj,m_dialog->obj_name->text())) { *res=false; return; }
 }
 
-void DNSNameDialog::isChanged(bool *res)
+void DNSNameDialog::isChanged(bool*)
 {
    // *res=(!init && apply->isEnabled());
 }
@@ -121,24 +130,16 @@ void DNSNameDialog::applyChanges()
     assert(s!=NULL);
 
     string oldname=obj->getName();
-    obj->setName( string(obj_name->text().utf8()) );
-    obj->setComment( string(comment->text().utf8()) );
+    obj->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
+    obj->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
 
-    s->setSourceName( dnsrec->text().latin1() );
-    s->setRunTime(r_runtime->isChecked() );
+    s->setSourceName( m_dialog->dnsrec->text().toLatin1().constData() );
+    s->setRunTime(m_dialog->r_runtime->isChecked() );
 
-    om->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
-
-    init=true;
-
-/* move to another lib if we have to */
-    if (libs->currentText() != QString(obj->getLibrary()->getName().c_str()))
-        om->moveObject(libs->currentText(), obj);
-
-    init=false;
+    mw->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
 
     //apply->setEnabled( false );
-    om->updateLastModifiedTimestampForAllFirewalls(obj);
+    mw->updateLastModifiedTimestampForAllFirewalls(obj);
 }
 
 void DNSNameDialog::discardChanges()
