@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWBSettings.cpp 565 2008-10-04 14:34:24Z vadim $
+  $Id: FWBSettings.cpp 603 2008-10-11 20:59:46Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -59,6 +59,7 @@ using namespace libfwbuilder;
 
 const char* DTDSetpath = SETTINGS_PATH_PREFIX "/System/DTDPath";
 const char* ResSetpath = SETTINGS_PATH_PREFIX "/System/ResPath";
+const char* compression = SETTINGS_PATH_PREFIX "/DataFile/compression";
 const char* wdirSetpath = SETTINGS_PATH_PREFIX "/Environment/WDir";
 const char* ofdirSetpath = SETTINGS_PATH_PREFIX "/Environment/OpenFileDir";
 const char* sfdirSetpath = SETTINGS_PATH_PREFIX "/Environment/SaveFileDir";
@@ -82,6 +83,7 @@ const char* WindowGeometrySetpath= SETTINGS_PATH_PREFIX "/Layout/";
 const char* screenPositionSetpath= SETTINGS_PATH_PREFIX "/ScreenPos/";
 
 const char* SSHPath = SETTINGS_PATH_PREFIX "/SSH/SSHPath";
+const char* SCPPath = SETTINGS_PATH_PREFIX "/SSH/SCPPath";
 const char* showIconsInRules = SETTINGS_PATH_PREFIX "/UI/Icons/ShowIconsInRules";
 const char* showDirectionText = SETTINGS_PATH_PREFIX "/UI/Icons/ShowDirectionTextInRules";
 const char* iconsInRulesSize = SETTINGS_PATH_PREFIX "/UI/Icons/IconsInRulesSize";
@@ -189,8 +191,12 @@ void FWBSettings::init()
     ok = contains(checkUpdates);
     if (!ok) setCheckUpdates(true);
 
+    ok = contains(compression);
+    if (!ok) setCompression(false);
+
 #ifndef _WIN32
     if (getSSHPath().isEmpty())  setSSHPath("ssh");
+    if (getSCPPath().isEmpty())  setSCPPath("scp");
 #endif
 }
 
@@ -300,6 +306,9 @@ void    FWBSettings::setRCSLogState(bool f) { setValue( emptyRCSLog , f ); }
 bool    FWBSettings::getAutoSave() { return value( autoSave ).toBool(); }
 void    FWBSettings::setAutoSave(bool f) { setValue( autoSave, f); }
 
+bool    FWBSettings::getCompression() { return value(compression).toBool(); }
+void    FWBSettings::setCompression(bool f) { setValue(compression, f); }
+
 bool    FWBSettings::getDontSaveStdLib() {return value(dontSaveStdLib).toBool();}
 void    FWBSettings::setDontSaveStdLib( bool f) { setValue(dontSaveStdLib,f);}
 
@@ -499,6 +508,16 @@ void FWBSettings::setSSHPath(const QString &path)
     setValue(SSHPath,path);
 }
 
+QString FWBSettings::getSCPPath()
+{
+    return value(SCPPath).toString();
+}
+
+void FWBSettings::setSCPPath(const QString &path)
+{
+    setValue(SCPPath,path);
+}
+
 void FWBSettings::getPrinterOptions(QPrinter *printer,
                                     int &pageWidth,
                                     int &pageHeight)
