@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWBSettings.h 565 2008-10-04 14:34:24Z vadim $
+  $Id: FWBSettings.h 603 2008-10-11 20:59:46Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -26,6 +26,9 @@
 #ifndef __FWBSETTINGS_H_
 #define __FWBSETTINGS_H_
 
+#include "fwbuilder/FWObject.h"
+
+
 #include <qsettings.h>
 #include <qrect.h>
 #include <qprinter.h>
@@ -105,6 +108,9 @@ class FWBSettings : public QSettings {
     bool    getAutoSave();
     void    setAutoSave(bool f);
 
+    bool    getCompression();
+    void    setCompression(bool f);
+
     bool    getDontSaveStdLib();
     void    setDontSaveStdLib( bool f);
     
@@ -134,6 +140,9 @@ class FWBSettings : public QSettings {
     QString getSSHPath();
     void    setSSHPath(const QString &path);
 
+    QString getSCPPath();
+    void    setSCPPath(const QString &path);
+
     void    getPrinterOptions(QPrinter *printer,int &pageWidth,int &pageHeight);
     void    setPrinterOptions(QPrinter *printer,int pageWidth,int pageHeight);
 
