@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: FWObjectDropArea.cpp,v 1.4 2007/11/15 16:36:12 vkurland Exp $
+  $Id: FWObjectDropArea.cpp 419 2008-07-27 19:13:17Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,22 +17,23 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "config.h"
+#include "../../config.h"
+#include "../../definitions.h"
 #include "global.h"
 #include "utils.h"
 #include "platforms.h"
-#include "definitions.h"
 
 #include "FWObjectDropArea.h"
 #include "FWObjectDrag.h"
 #include "FWObjectClipboard.h"
 #include "FWWindow.h"
+#include "ProjectPanel.h"
 
 #include "fwbuilder/Resources.h"
 
@@ -41,7 +42,12 @@
 #include <qpixmap.h>
 #include <qpixmapcache.h>
 #include <qrect.h>
-#include <qpopupmenu.h>
+#include <qmenu.h>
+//Added by qt3to4:
+#include <QDragEnterEvent>
+#include <QDropEvent>
+#include <QContextMenuEvent>
+#include <QPaintEvent>
 
 #include <iostream>
 #include <stdlib.h>
@@ -49,20 +55,31 @@
 using namespace std;
 using namespace libfwbuilder;
 
-FWObjectDropArea::FWObjectDropArea(QWidget*p, const char * n, WFlags f) : FWObjectDropArea_q(p,n,f) 
+FWObjectDropArea::~FWObjectDropArea()
 {
+    delete m_objectDropArea;
+}
+
+FWObjectDropArea::FWObjectDropArea(QWidget*p, const char * n, Qt::WFlags f):
+    QWidget(p)
+{
+    setObjectName( QString(n) );
+    setWindowFlags( f );
+    m_objectDropArea = new Ui::FWObjectDropArea_q;
+    m_objectDropArea->setupUi(this);
     object=NULL;
+    helperText =tr("Drop object here.");
 
 }
-void FWObjectDropArea::paintEvent(QPaintEvent *ev)
+void FWObjectDropArea::paintEvent(QPaintEvent *)
 {
     int w=width();
     int h=height();
-        
+
     QPainter p(this);
-    
+
     QPixmap bufferpixmap;
-    bufferpixmap.resize( w , h );
+    bufferpixmap = QPixmap( w , h );
     bufferpixmap.fill( Qt::white );
     QPainter tp( &bufferpixmap );
 
@@ -71,50 +88,49 @@ void FWObjectDropArea::paintEvent(QPaintEvent *ev)
     tp.drawLine(w-1,0,w-1,h-1);
     tp.drawLine(w-1,h-1,0,h-1);
     tp.drawLine(0,h-1,0,0);
-
     tp.fillRect(1, 1, w-2, h-2, Qt::white);
-    
-    if (object!=NULL) 
+
+    if (object!=NULL)
     {
 
         QPixmap pm;
-        QString icn_file = 
-            Resources::global_res->getObjResourceStr(object, "icon-tree").c_str();
+        QString icn_file = (":/Icons/"+object->getTypeName()+"/icon").c_str();
+
         if ( ! QPixmapCache::find( icn_file, pm) )
         {
-            pm = QPixmap::fromMimeSource( icn_file );
+            pm.load( icn_file );
             QPixmapCache::insert( icn_file, pm);
         }
 
         tp.drawPixmap( ((w-pm.width())/2), (h/2)-(2+pm.height()) , pm );
-        
+
         QString t=QString::fromUtf8(object->getName().c_str());
-        
+
         int t_x=2;
         int t_y=2+h/2;
         int t_w=w-4;
         int t_h=h/2-4;
-        
+
         tp.drawText( t_x, t_y , t_w, t_h ,
-                     Qt::AlignHCenter|Qt::AlignTop|Qt::WordBreak, t );
+                     Qt::AlignHCenter|Qt::AlignTop|Qt::TextWordWrap, t );
     }
     else
     {
-        QString t=tr("Drop object here.");
-        
+        QString t=helperText ; 
+
         int t_x=2;
         int t_y=2;
         int t_w=w-4;
         int t_h=h-4;
 
         tp.drawText( t_x, t_y , t_w, t_h ,
-                     Qt::AlignHCenter|Qt::AlignVCenter|Qt::WordBreak, t );
+                     Qt::AlignHCenter|Qt::AlignVCenter|Qt::TextWordWrap, t );
+
 
-        
     }
     tp.end();
     p.drawPixmap( 0, 0, bufferpixmap );
-    
+
 }
 void FWObjectDropArea::insertObject(libfwbuilder::FWObject *o)
 {
@@ -135,16 +151,23 @@ void FWObjectDropArea::deleteObject()
 
 void FWObjectDropArea::contextMenuEvent (QContextMenuEvent * e)
 {
-    QPopupMenu *popup;
-    
-    popup=new QPopupMenu(this);
-    int psId = popup->insertItem( tr("Paste") ,    this , SLOT( pasteObject( )) );
-    popup->insertSeparator();
-    int dlId = popup->insertItem( tr("Delete") ,   this , SLOT( deleteObject( )) );
-    
-    popup->setItemEnabled(dlId,object!=NULL);
-    popup->setItemEnabled(psId,FWObjectClipboard::obj_clipboard->size()>0);
-    
+    QMenu *popup;
+
+    popup=new QMenu(this);
+
+    QAction *sitAct = popup->addAction( tr("Show in the tree") ,    this , SLOT( showInTreeObject( )) );
+    QAction *editAct = popup->addAction( tr("Edit") ,    this , SLOT( editObject( )) );
+    popup->addSeparator();
+
+    QAction *psAct = popup->addAction( tr("Paste") ,    this , SLOT( pasteObject( )) );
+    popup->addSeparator();
+    QAction *dlAct = popup->addAction( tr("Delete") ,   this , SLOT( deleteObject( )) );
+
+    sitAct->setEnabled(object!=NULL);
+    editAct->setEnabled(object!=NULL);
+    dlAct->setEnabled(object!=NULL);
+    psAct->setEnabled(FWObjectClipboard::obj_clipboard->size()>0);
+
     popup->exec(e->globalPos ());
     delete popup;
 }
@@ -153,10 +176,10 @@ void FWObjectDropArea::dropEvent( QDropEvent *ev)
 {
     if (fwbdebug)
     {
-        qDebug("FWObjectDropArea::dropEvent  drop event mode=%d", ev->action());
+        qDebug("FWObjectDropArea::dropEvent  drop event mode=%d", ev->dropAction());
         qDebug("                        src widget = %p", ev->source());
     }
-    
+
     list<FWObject*> dragol;
     if (FWObjectDrag::decode(ev, dragol))
     {
@@ -169,17 +192,71 @@ void FWObjectDropArea::dropEvent( QDropEvent *ev)
 
 void FWObjectDropArea::dragEnterEvent( QDragEnterEvent *ev)
 {
-    ev->acceptAction( FWObjectDrag::canDecode(ev) );
+    list<FWObject*> dragol;
+    if (FWObjectDrag::decode(ev, dragol))
+    {
+        if (dragol.size()>0)
+        {
+            FWObject * o = dragol.front();
+            bool ok = false ;
+            if (acceptedTypes.size()==0)
+                ok = true ;
+            for (int p = 0 ; p < acceptedTypes.size(); p++)
+            {
+                QString type =o->getTypeName().c_str(); 
+                if (type==acceptedTypes[p])
+                {
+                    ok = true ;
+                    break ;
+                }
+            }
+            if (!ok)
+            {
+                ev->setAccepted(false);
+                return ;
+            }
+        }
+    }
+
+    ev->setAccepted( ev->mimeData()->hasFormat(FWObjectDrag::FWB_MIME_TYPE) );
 }
 
 void FWObjectDropArea::pasteObject()
 {
-    vector<string>::iterator i;
+    vector<std::pair<int,ProjectPanel*> >::iterator i;
     for( i= FWObjectClipboard::obj_clipboard->begin();
          i!=FWObjectClipboard::obj_clipboard->end(); ++i)
     {
-        FWObject *co= mw->db()->findInIndex(*i);
+        FWObject *co= mw->db()->findInIndex(i->first);
         insertObject(co);
     }
-    
+
+}
+
+void FWObjectDropArea::showInTreeObject()
+{
+    ProjectPanel * pp = mw->activeProject();
+    if (pp!=NULL)
+    {
+        pp->m_panel->om->openObject(object);
+    }
+}
+
+void FWObjectDropArea::editObject()
+{
+    ProjectPanel * pp = mw->activeProject();
+    if (pp!=NULL)
+    {
+        pp->m_panel->om->openObject(object);
+        pp->openEditor(object);
+    }
+
+}
+
+void FWObjectDropArea::mouseDoubleClickEvent ( QMouseEvent * )
+{
+    if (object!=NULL)
+    {
+        editObject();
+    }
 }
