@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWObjectPropertiesFactory.cpp,v 1.53 2007/05/23 03:05:50 vkurland Exp $
+  $Id: FWObjectPropertiesFactory.cpp 550 2008-09-24 13:19:48Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -23,11 +23,11 @@
 
 */
 
-#include "config.h"
+#include "../../config.h"
+#include "../../definitions.h"
 #include "global.h"
 #include "utils_no_qt.h"
 #include "utils.h"
-#include "definitions.h"
 
 #include <qobject.h>
 #include <qtextstream.h>
@@ -37,36 +37,35 @@
 #include "FWObjectPropertiesFactory.h"
 #include "platforms.h"
 
-#include "fwbuilder/FWException.h"
-
-#include "fwbuilder/Library.h"
-#include "fwbuilder/Group.h"
-
-#include "fwbuilder/Firewall.h"
-#include "fwbuilder/Host.h"
-#include "fwbuilder/Network.h"
-#include "fwbuilder/IPv4.h"
-#include "fwbuilder/physAddress.h"
-#include "fwbuilder/DNSName.h"
-#include "fwbuilder/AddressTable.h"
 #include "fwbuilder/AddressRange.h"
-#include "fwbuilder/ObjectGroup.h"
-#include "fwbuilder/Rule.h"
-#include "fwbuilder/Policy.h"
-
-#include "fwbuilder/FWReference.h"
-#include "fwbuilder/Interface.h"
-
+#include "fwbuilder/AddressTable.h"
 #include "fwbuilder/CustomService.h"
-#include "fwbuilder/IPService.h"
+#include "fwbuilder/DNSName.h"
+#include "fwbuilder/FWException.h"
+#include "fwbuilder/FWObjectDatabase.h"
+#include "fwbuilder/FWReference.h"
+#include "fwbuilder/Firewall.h"
+#include "fwbuilder/Group.h"
+#include "fwbuilder/Host.h"
+#include "fwbuilder/ICMP6Service.h"
 #include "fwbuilder/ICMPService.h"
-#include "fwbuilder/TCPService.h"
-#include "fwbuilder/UDPService.h"
-#include "fwbuilder/TagService.h"
-
+#include "fwbuilder/IPService.h"
+#include "fwbuilder/IPv4.h"
+#include "fwbuilder/IPv6.h"
+#include "fwbuilder/Interface.h"
 #include "fwbuilder/Interval.h"
-
+#include "fwbuilder/Library.h"
+#include "fwbuilder/Network.h"
+#include "fwbuilder/NetworkIPv6.h"
+#include "fwbuilder/ObjectGroup.h"
+#include "fwbuilder/Policy.h"
 #include "fwbuilder/Resources.h"
+#include "fwbuilder/Rule.h"
+#include "fwbuilder/TCPService.h"
+#include "fwbuilder/TagService.h"
+#include "fwbuilder/UDPService.h"
+#include "fwbuilder/UserService.h"
+#include "fwbuilder/physAddress.h"
 
 #include <sstream>
 #include <iostream>
@@ -84,16 +83,27 @@ using namespace libfwbuilder;
 QString FWObjectPropertiesFactory::getObjectProperties(FWObject *obj)
 {
     QString res;
-    QTextStream str(&res, IO_WriteOnly);
-
-    try {
+    QTextStream str(&res, QIODevice::WriteOnly);
+    FWObject *parent_obj = obj->getParent();
 
+    try
+    {
         if (IPv4::isA(obj))
         {
-            str <<  Address::cast(obj)->getAddress().toString().c_str();
-            str << "/";
-            str << Address::cast(obj)->getNetmask().toString().c_str();
-
+            str <<  IPv4::cast(obj)->getAddressPtr()->toString().c_str();
+            if (parent_obj && Interface::isA(parent_obj))
+            {
+                str << "/";
+                str << IPv4::cast(obj)->getNetmaskPtr()->toString().c_str();
+            }
+        } else if (IPv6::isA(obj))
+        {
+            str <<  IPv6::cast(obj)->getAddressPtr()->toString().c_str();
+            if (parent_obj && Interface::isA(parent_obj))
+            {
+                str << "/";
+                str << QString("%1").arg(IPv6::cast(obj)->getNetmaskPtr()->getLength());
+            }
         } else if (physAddress::isA(obj))
         {
             str <<  physAddress::cast(obj)->getPhysAddress().c_str();
@@ -134,7 +144,11 @@ QString FWObjectPropertiesFactory::getObjectProperties(FWObject *obj)
 
         } else if (Host::isA(obj))
         {
-            str <<  Address::cast(obj)->getAddress().toString().c_str();
+            const InetAddr *addr = Address::cast(obj)->getAddressPtr();
+            if (addr)
+                str <<  addr->toString().c_str();
+            else
+                str << "(no ip address)";
 
             FWObject *co=obj->getFirstByType("Interface");
             if (co!=NULL) 
@@ -147,9 +161,16 @@ QString FWObjectPropertiesFactory::getObjectProperties(FWObject *obj)
         } else if (Network::isA(obj))
         {
             Network *n=Network::cast(obj);
-            str << n->getAddress().toString().c_str();
+            str << n->getAddressPtr()->toString().c_str();
             str << "/";
-            str << n->getNetmask().toString().c_str();
+            str << n->getNetmaskPtr()->toString().c_str();
+
+        } else if (NetworkIPv6::isA(obj))
+        {
+            NetworkIPv6 *n=NetworkIPv6::cast(obj);
+            str << n->getAddressPtr()->toString().c_str();
+            str << "/";
+            str << QString("%1").arg(n->getNetmaskPtr()->getLength());
 
         } else if (Group::cast(obj)!=NULL)   // just any group
         {
@@ -161,18 +182,23 @@ QString FWObjectPropertiesFactory::getObjectProperties(FWObject *obj)
 
         } else if (Interface::isA(obj))
         {
-            physAddress *paddr=(Interface::cast(obj))->getPhysicalAddress();
-            if (paddr!=NULL) 
+            Interface *intf = Interface::cast(obj);
+            FWObjectTypedChildIterator j = obj->findByType(IPv4::TYPENAME);
+            for ( ; j!=j.end(); ++j)
             {
-                str << "    ";
-                str <<  paddr->getPhysAddress().c_str();
+                str << getObjectProperties(*j);
+                str << "<br>";
             }
+            str << " MAC: ";
+            physAddress *paddr = intf->getPhysicalAddress();
+            if (paddr!=NULL) 
+                str <<  paddr->getPhysAddress().c_str();
 
         } else if (IPService::isA(obj))
         {
             str << QObject::tr("protocol: %1").arg(obj->getStr("protocol_num").c_str());
 
-        } else if (ICMPService::isA(obj))
+        } else if (ICMPService::isA(obj) || ICMP6Service::isA(obj))
         {
             str << QObject::tr("type: %1").arg(obj->getStr("type").c_str())
                 << "  "
@@ -182,16 +208,20 @@ QString FWObjectPropertiesFactory::getObjectProperties(FWObject *obj)
         {
             int sps,spe,dps,dpe;
 
-            sps=obj->getInt("src_range_start");
-            spe=obj->getInt("src_range_end");
-            dps=obj->getInt("dst_range_start");
-            dpe=obj->getInt("dst_range_end");
+            sps=TCPUDPService::cast(obj)->getSrcRangeStart();
+            spe=TCPUDPService::cast(obj)->getSrcRangeEnd();
+            dps=TCPUDPService::cast(obj)->getDstRangeStart();
+            dpe=TCPUDPService::cast(obj)->getDstRangeEnd();
 
             str << sps << ":" << spe << " / ";
             str << dps << ":" << dpe;
         } else if (TagService::isA(obj)) 
         {
             str << "Pattern: \"" << obj->getStr("tagcode").c_str() << "\"" ;
+        } else if (UserService::isA(obj)) 
+        {
+            const UserService* user_srv = UserService::constcast(obj);
+            str << "User id: \"" << user_srv->getUserId().c_str() << "\"" ;
         } else if (Interval::isA(obj))
         {
 
@@ -229,6 +259,7 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
                                                                bool richText)
 {
     QString str;
+    FWObject *parent_obj = obj->getParent();
 
     QString path = obj->getPath().c_str();
     path = path.section('/',2,-1);
@@ -241,7 +272,7 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
         if (!tooltip)
         {
             str += QObject::tr("<b>Object Id:</b> ");
-            str += QString(obj->getId().c_str()) + "<br>\n";
+            str += QString(FWObjectDatabase::getStringId(obj->getId()).c_str()) + "<br>\n";
         }
     }
 
@@ -255,15 +286,26 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
     if (accentName) str += "</font>";
     str += "<br>\n";
 
-    try {
-
+    try
+    {
         if (IPv4::isA(obj))
         {
             if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
-            str +=  Address::cast(obj)->getAddress().toString().c_str();
-            str += "/";
-            str += Address::cast(obj)->getNetmask().toString().c_str();
-
+            str +=  IPv4::cast(obj)->getAddressPtr()->toString().c_str();
+            if (parent_obj && Interface::isA(parent_obj))
+            {
+                str += "/";
+                str += IPv4::cast(obj)->getNetmaskPtr()->toString().c_str();
+            }
+        } else if (IPv6::isA(obj))
+        {
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
+            str +=  IPv6::cast(obj)->getAddressPtr()->toString().c_str();
+            if (parent_obj && Interface::isA(parent_obj))
+            {
+                str += "/";
+                str += QString("%1").arg(IPv6::cast(obj)->getNetmaskPtr()->getLength());
+            }
         } else if (physAddress::isA(obj))
         {
             if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
@@ -295,24 +337,30 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
         {
             if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
 
-            str +=  Address::cast(obj)->getAddress().toString().c_str() ;
-
-            FWObject *co=obj->getFirstByType("Interface");
-            if (co!=NULL) 
+            FWObjectTypedChildIterator j = obj->findByType(
+                Interface::TYPENAME);
+            for ( ; j!=j.end(); ++j)
             {
-                physAddress *paddr=(Interface::cast(co))->getPhysicalAddress();
-                if (paddr!=NULL) 
-                    str += QString("    ") +  paddr->getPhysAddress().c_str() ;
+                str += (*j)->getName().c_str();
+                str += ": ";
+                str += getObjectProperties(*j);
+                str += "<br>";
             }
-
         } else if (Network::isA(obj))
         {
             if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             Network *n=Network::cast(obj);
-            str += n->getAddress().toString().c_str();
+            str += n->getAddressPtr()->toString().c_str();
             str += "/";
-            str += n->getNetmask().toString().c_str();
+            str += n->getNetmaskPtr()->toString().c_str();
 
+        } else if (NetworkIPv6::isA(obj))
+        {
+            if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
+            NetworkIPv6 *n=NetworkIPv6::cast(obj);
+            str += n->getAddressPtr()->toString().c_str();
+            str += "/";
+            str += QString("%1").arg(n->getNetmaskPtr()->getLength());
         } else if (Group::cast(obj)!=NULL)   // just any group
         {
             if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
@@ -382,7 +430,22 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
             str += "</table>";
         } else if (Interface::isA(obj))
         {
-            str+=QObject::tr("<b>Path:</b> ")+ path +"<br>\n";
+            str += QObject::tr("<b>Path:</b> ")+ path +"<br>\n";
+
+            FWObjectTypedChildIterator j = obj->findByType(IPv4::TYPENAME);
+            for ( ; j!=j.end(); ++j)
+            {
+                str += getObjectProperties(*j);
+                str += "<br>";
+            }
+            physAddress *paddr=(Interface::cast(obj))->getPhysicalAddress();
+            if (paddr!=NULL) 
+            {
+                str += "MAC: ";
+                str +=  paddr->getPhysAddress().c_str() ;
+                str += "<br>";
+            }
+
             QString q;
             if (Interface::constcast(obj)->isDyn())        q=" dyn";
             if (Interface::constcast(obj)->isUnnumbered()) q=" unnum";
@@ -405,14 +468,6 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
             str += "<br>\n";
             if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
 
-            physAddress *paddr=(Interface::cast(obj))->getPhysicalAddress();
-            if (paddr!=NULL) 
-            {
-                str += "    ";
-                str +=  paddr->getPhysAddress().c_str() ;
-            }
-            
-
         } else if (CustomService::isA(obj))
         {
 
@@ -443,7 +498,7 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
             if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             str += QObject::tr("protocol ") + obj->getStr("protocol_num").c_str();
 
-        } else if (ICMPService::isA(obj))
+        } else if (ICMPService::isA(obj) || ICMP6Service::isA(obj))
         {
             if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             str += QObject::tr("type: ") + obj->getStr("type").c_str()
@@ -454,10 +509,10 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
         {
             int sps,spe,dps,dpe;
 
-            sps=obj->getInt("src_range_start");
-            spe=obj->getInt("src_range_end");
-            dps=obj->getInt("dst_range_start");
-            dpe=obj->getInt("dst_range_end");
+            sps=TCPUDPService::cast(obj)->getSrcRangeStart();
+            spe=TCPUDPService::cast(obj)->getSrcRangeEnd();
+            dps=TCPUDPService::cast(obj)->getDstRangeStart();
+            dpe=TCPUDPService::cast(obj)->getDstRangeEnd();
 
             if (showPath && !tooltip) str += "<b>Path: </b>" + path + "<br>\n";
             str += "<table cellspacing=\"0\" cellpadding=\"0\">";
@@ -469,6 +524,10 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
         } else if (TagService::isA(obj)) 
         {
             str += QObject::tr("Pattern: \"%1\"").arg(obj->getStr("tagcode").c_str());
+        } else if (UserService::isA(obj)) 
+        {
+            const UserService* user_srv = UserService::constcast(obj);
+            str += QObject::tr("User id: \"%1\"").arg(user_srv->getUserId().c_str());
         } else if (Interval::isA(obj))
         {
 
@@ -497,7 +556,8 @@ QString FWObjectPropertiesFactory::getRuleActionProperties(PolicyRule *rule)
         
         FWObject *o = rule;
         while (o!=NULL && Firewall::cast(o)==NULL) o=o->getParent();
-        assert(o!=NULL);
+        if (o==NULL) return "";
+
         Firewall *f=Firewall::cast(o);
         string platform=f->getStr("platform");
         
@@ -508,22 +568,33 @@ QString FWObjectPropertiesFactory::getRuleActionProperties(PolicyRule *rule)
         {
             switch (rule->getAction())
             {
-            case PolicyRule::Reject     :
+            case PolicyRule::Reject:
                 par = ropt->getStr("action_on_reject").c_str();
                 break;
-            case PolicyRule::Tag        :
-                par = ropt->getStr("tagvalue").c_str();
+            case PolicyRule::Tag:
+            {
+                FWObject *tag_object = rule->getTagObject();
+                if (tag_object)
+                    par = tag_object->getName().c_str();
+                else
+                    par = rule->getTagValue().c_str();
                 break;
+            }
             case PolicyRule::Accounting :
                 par = ropt->getStr("rule_name_accounting").c_str();
                 break;
-            case PolicyRule::Custom :
+            case PolicyRule::Custom:
                 par = ropt->getStr("custom_str").c_str();
                 break;
-            case PolicyRule::Branch :
-                par = ropt->getStr("branch_name").c_str();
+            case PolicyRule::Branch:
+            {
+                FWObject *branch_ruleset = rule->getBranch();
+                if (branch_ruleset)
+                    par = branch_ruleset->getName().c_str();
+                // ropt->getStr("branch_name").c_str();
                 break;
-            case PolicyRule::Classify :
+            }
+            case PolicyRule::Classify:
                 if (platform=="ipfw")
                 {
                     if (ropt->getInt("ipfw_classify_method") == DUMMYNETPIPE)
@@ -813,7 +884,7 @@ QString FWObjectPropertiesFactory::getNATRuleOptions(Rule *rule)
         FWOptions *ropt = rule->getOptionsObject();
 
         if (fwbdebug)
-            qDebug(QString("getNATRuleOptions: platform: %2").arg(platform.c_str()));
+            qDebug(QString("getNATRuleOptions: platform: %2").arg(platform.c_str()).toAscii().constData());
             
         if (platform=="pf")
         {
