@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindow.cpp 565 2008-10-04 14:34:24Z vadim $
+  $Id: FWWindow.cpp 676 2008-11-28 18:22:49Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -50,6 +50,7 @@
 #include "FindObjectWidget.h"
 #include "FindWhereUsedWidget.h"
 #include "longTextDialog.h"
+#include "Help.h"
 
 #include "FWBAboutDialog.h"
 #include "debugDialog.h"
@@ -289,7 +290,7 @@ void FWWindow::startupLoad()
 
     if (activeProject())
     {
-        activeProject()->load(NULL);
+        activeProject()->loadStandardObjects();
         activeProject()->readyStatus(true);
         activeProject()->loadState(true);
     }
@@ -501,9 +502,9 @@ void FWWindow::importPolicy()
     druid.exec();
 }
 
-void FWWindow::load(QWidget *dialogs_parent)
+void FWWindow::load(QWidget*)
 {
-    if (activeProject()) activeProject()->load(dialogs_parent);
+    if (activeProject()) activeProject()->loadStandardObjects();
 }
 
 FWObject* FWWindow::getVisibleFirewalls()
@@ -512,9 +513,9 @@ FWObject* FWWindow::getVisibleFirewalls()
     return 0;
 }
 
-void FWWindow::load(QWidget *dialogs_parent,RCS *_rcs)
+void FWWindow::load(QWidget*, RCS *_rcs)
 {
-    if (activeProject()) activeProject()->load(dialogs_parent, _rcs);
+    if (activeProject()) activeProject()->loadFromRCS(_rcs);
 }
 
 bool FWWindow::checkin(bool unlock)
@@ -657,9 +658,9 @@ void FWWindow::updateRuleOptions()
     if (activeProject()) activeProject()->updateRuleOptions();
 }
 
-void FWWindow::updateFirewallName(FWObject *obj,const QString &str)
+void FWWindow::updateFirewallName()
 {
-    if (activeProject()) activeProject()->updateFirewallName(obj, str);
+    if (activeProject()) activeProject()->updateFirewallName();
 }
 
 void FWWindow::scheduleRuleSetRedraw()
@@ -944,7 +945,15 @@ void FWWindow::prepareEditMenu()
 
 void FWWindow::prepareObjectMenu()
 {
-    if (!activeProject())return;
+    if (!activeProject())
+    {
+        m_mainWindow->newObjectAction->setEnabled(false);
+        m_mainWindow->findAction->setEnabled(false);
+        m_mainWindow->ObjectLockAction->setEnabled(false);
+        m_mainWindow->ObjectUnlockAction->setEnabled(false);
+        return;
+    }
+
     ObjectTreeView* otv = activeProject()->getCurrentObjectTree();
     m_mainWindow->ObjectUnlockAction->setEnabled(otv->isUnlockable());
     m_mainWindow->ObjectLockAction->setEnabled(otv->isLockable());
@@ -961,6 +970,8 @@ void FWWindow::prepareFileMenu()
         m_mainWindow->fileCommitAction->setEnabled(false);
         m_mainWindow->fileDiscardAction->setEnabled(false);
         m_mainWindow->filePropAction->setEnabled(false);
+        m_mainWindow->libImportAction->setEnabled(false);
+        m_mainWindow->policyImportAction->setEnabled(false);
         return;
     }
 
@@ -1689,3 +1700,9 @@ void FWWindow::projectWindowClosed()
 //    if (m_space->subWindowList().size() == 0) QCoreApplication::exit(0);
 }
 
+void FWWindow::help()
+{
+    Help *h = new Help(this, "main", "Firewall Builder");
+    h->show();
+}
+
