@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindow.h 563 2008-10-03 14:06:56Z vadim $
+  $Id: FWWindow.h 660 2008-11-23 03:19:04Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -110,7 +110,8 @@ public slots:
     virtual void helpContents();
     virtual void helpContentsAction();
     virtual void helpIndex();
-     
+    virtual void help();
+
     virtual void fileNew();
     virtual void fileOpen();
     virtual void fileClose();
@@ -209,7 +210,7 @@ public slots:
     
     bool saveIfModified();
     
-    void updateFirewallName(libfwbuilder::FWObject *obj,const QString &oldName);
+    void updateFirewallName();
     void updateRuleSetView();
     void updateRuleOptions();
     void updateRuleSetViewSelection();
