@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindowPrint.cpp 332 2008-07-06 20:11:03Z vadim $
+  $Id: FWWindowPrint.cpp 654 2008-11-20 06:58:15Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -56,7 +56,6 @@
 #include <qprintdialog.h>
 
 #include "fwbuilder/Policy.h"
-#include "fwbuilder/InterfacePolicy.h"
 #include "fwbuilder/NAT.h"
 #include "fwbuilder/Routing.h"
 #include "fwbuilder/Interface.h"
@@ -167,13 +166,6 @@ list<FWObject*> findAllUsedByType(list<FWObject*> &result,FWObject *obj,const st
         ruleSet = obj->getFirstByType(Policy::TYPENAME);
         findAllUsedByType(result,ruleSet,typeName);
 
-        FWObjectTypedChildIterator j=obj->findByType(Interface::TYPENAME);
-        for ( ; j!=j.end(); ++j )
-        {
-          if ((ruleSet = (*j)->getFirstByType(InterfacePolicy::TYPENAME))!=NULL)
-            findAllUsedByType(result,ruleSet,typeName);
-        }
-
         ruleSet = obj->getFirstByType(NAT::TYPENAME);
         findAllUsedByType(result,ruleSet,typeName);
 
@@ -276,23 +268,36 @@ void printFirewall(FWObject *fw,
                    bool newPageForSection,
                    ProjectPanel *project)
 {
-    if (Firewall::cast(fw)==NULL)
-        return ;
+    if (Firewall::cast(fw)==NULL) return ;
     list<pixmapOrText> listPT;
 
     QString txt;
 
-    QString platform = fw->getStr("platform").c_str();
-    QString version  = fw->getStr("version").c_str();
-    QString readableVersion = getVersionString(platform,version);
-    QString hostOS = fw->getStr("host_OS").c_str();
+    if (fwbdebug) fw->dump(false,false);
+
+    string platform = fw->getStr("platform");
+    string version  = fw->getStr("version");
+    string hostOS = fw->getStr("host_OS");
+
+    if (fwbdebug)
+    {
+        qDebug("platform: %s", platform.c_str());
+        qDebug("version: %s", version.c_str());
+        qDebug("host_OS: %s", hostOS.c_str());
+    }
+
+    QString readableVersion = getVersionString(QString(platform.c_str()),
+                                               QString(version.c_str()));
+    if (fwbdebug) qDebug("Readable version: %s",
+                         readableVersion.toAscii().constData());
 
     pr.beginPage();   // resets yPos
 
-    pr.printText(QObject::tr("Firewall name: %1").arg(QString::fromUtf8(fw->getName().c_str())));
-    pr.printText(QObject::tr("Platform: ") + platform);
+    pr.printText(QObject::tr("Firewall name: %1").arg(
+                     QString::fromUtf8(fw->getName().c_str())));
+    pr.printText(QObject::tr("Platform: ") + platform.c_str());
     pr.printText(QObject::tr("Version: ")  + readableVersion);
-    pr.printText(QObject::tr("Host OS: ")  + hostOS);
+    pr.printText(QObject::tr("Host OS: ")  + hostOS.c_str());
     pr.printText(" ");
     RuleSetView *ruleView =NULL;
 //            ppd->genericProgressIndicator(ppdCounter++,QObject::tr("Processing global policy"));
@@ -302,112 +307,75 @@ void printFirewall(FWObject *fw,
     FWObjectTypedChildIterator j =fw->findByType(Policy::TYPENAME);
     for ( ; j!=j.end(); ++j )
     {
-    Policy * pol = Policy::cast(*j) ;
-    QString name = QObject::tr("Policy: ");
-    name += pol->getName().c_str();
-    pr.printText(name);
-
-    ruleView=new PolicyView(project,
-        pol,NULL);
-    ruleView->setSizePolicy( QSizePolicy( (QSizePolicy::Policy)7,
-                                          (QSizePolicy::Policy)7) );
-    ruleView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    ruleView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-
-    ruleView->setMaximumHeight(pr.getPageHeight());
-
-    /*if (fwbdebug) qDebug("Contents: %dx%d",
-                         ruleView->contentsWidth(),ruleView->contentsHeight());
-    if (fwbdebug) qDebug("Visible: %dx%d",
-                         ruleView->visibleWidth(),ruleView->visibleHeight());*/
-    if (fwbdebug) qDebug("Viewport: %dx%d",
-                         ruleView->viewport()->width(),ruleView->viewport()->height());
-    /*if (fwbdebug) qDebug("Clipper: %dx%d",
-                         ruleView->clipper()->width(),ruleView->clipper()->height());*/
-
-    if (fwbdebug) qDebug("Size: %dx%d",ruleView->width(),ruleView->height());
-
-//    pr.printPixmap(QPixmap::grabWidget(ruleView,0,0));
-    pr.printQTable(ruleView);
-
-    delete ruleView;
-    }
-
-    j=fw->findByType(Interface::TYPENAME);
-    for ( ; j!=j.end(); ++j )
-    {
-        Interface       *intf = Interface::cast(*j);
-        InterfacePolicy *ip   = InterfacePolicy::cast((*j)->getFirstByType(InterfacePolicy::TYPENAME));
-        if (ip)
-        {
-          QString tabName;
-          if ( !intf->getLabel().empty() )
-            tabName=QString::fromUtf8(intf->getLabel().c_str());
-          else
-            tabName=QString::fromUtf8(intf->getName().c_str());
-
-//                ppd->genericProgressIndicator(ppdCounter++,QObject::tr("Processing policy for interface %1").arg(tabName));
-          if (fwbdebug)
-              qDebug("******** Interface policy for %s",tabName.toLatin1().constData());
-
-
-          if (newPageForSection)
-            {
-              pr.flushPage();
-              pr.beginPage();   // resets yPos
-            } else
-            pr.printText(" ");
-
-          pr.printText(QObject::tr("Interface %1").arg(tabName));
-
-          ruleView=new InterfacePolicyView(project, ip,NULL);
-          ruleView->setSizePolicy( QSizePolicy( (QSizePolicy::Policy)7,
-                                                (QSizePolicy::Policy)7) );
-          ruleView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-          ruleView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-
-          if (fwbdebug) qDebug("%dx%d",ruleView->width(),ruleView->height());
-
-          pr.printQTable(ruleView);
-          //        pr.printPixmap(QPixmap::grabWidget(ruleView,0,0));
-          delete ruleView;
-        }
-    }
-
-//            ppd->genericProgressIndicator(ppdCounter++,QObject::tr("Processing NAT rules"));
-    if (fwbdebug)  qDebug("******** NAT");
-    j=fw->findByType(NAT::TYPENAME);
-    for ( ; j!=j.end(); ++j )
-    {
-
-    NAT *nat  = NAT::cast(*j);
-    if (nat && nat->size()!=0)
-    {
-        if (newPageForSection)
-        {
-            pr.flushPage();
-            pr.beginPage();   // resets yPos
-        } else
-            pr.printText(" ");
-        QString name = QObject::tr("NAT: ");
-        name += nat->getName ().c_str(); 
+        Policy * pol = Policy::cast(*j) ;
+        QString name = QObject::tr("Policy: ");
+        name += pol->getName().c_str();
         pr.printText(name);
 
-        ruleView=new NATView(project, nat,NULL);
-
+        ruleView=new PolicyView(project,
+                                pol,NULL);
         ruleView->setSizePolicy( QSizePolicy( (QSizePolicy::Policy)7,
                                               (QSizePolicy::Policy)7) );
         ruleView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
         ruleView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
-        if (fwbdebug) qDebug("%dx%d",ruleView->width(),ruleView->height());
+        ruleView->setMaximumHeight(pr.getPageHeight());
+
+        /*if (fwbdebug) qDebug("Contents: %dx%d",
+          ruleView->contentsWidth(),ruleView->contentsHeight());
+          if (fwbdebug) qDebug("Visible: %dx%d",
+          ruleView->visibleWidth(),ruleView->visibleHeight());*/
+        if (fwbdebug)
+            qDebug("Viewport: %dx%d",
+                   ruleView->viewport()->width(),ruleView->viewport()->height());
+        /*if (fwbdebug) qDebug("Clipper: %dx%d",
+          ruleView->clipper()->width(),ruleView->clipper()->height());*/
+
+        if (fwbdebug) qDebug("Size: %dx%d",ruleView->width(),ruleView->height());
 
-        pr.printQTable(ruleView);
 //    pr.printPixmap(QPixmap::grabWidget(ruleView,0,0));
+        pr.printQTable(ruleView);
+
         delete ruleView;
     }
+
+
+    if (fwbdebug)  qDebug("******** NAT");
+
+    j=fw->findByType(NAT::TYPENAME);
+    for ( ; j!=j.end(); ++j )
+    {
+
+        NAT *nat  = NAT::cast(*j);
+        if (nat && nat->size()!=0)
+        {
+            if (newPageForSection)
+            {
+                pr.flushPage();
+                pr.beginPage();   // resets yPos
+            } else
+                pr.printText(" ");
+            QString name = QObject::tr("NAT: ");
+            name += nat->getName ().c_str(); 
+            pr.printText(name);
+
+            ruleView=new NATView(project, nat,NULL);
+
+            ruleView->setSizePolicy( QSizePolicy( (QSizePolicy::Policy)7,
+                                                  (QSizePolicy::Policy)7) );
+            ruleView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+            ruleView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+
+            if (fwbdebug) qDebug("%dx%d",ruleView->width(),ruleView->height());
+
+            pr.printQTable(ruleView);
+//    pr.printPixmap(QPixmap::grabWidget(ruleView,0,0));
+            delete ruleView;
+        }
     }
+
     if (fwbdebug)  qDebug("******** Routing");
+
     Routing *routing  = Routing::cast(fw->getFirstByType(Routing::TYPENAME));
     if (routing && routing->size()!=0)
     {
@@ -448,7 +416,7 @@ void FWWindow::filePrint()
     bool  fullPage = false;
 
     float margin = 0;
-    int   resolution = 150;
+    float table_scaling = 1.0;
     bool  printHeader = true;
     bool  printLegend = true;
     bool  printObjects = true;
@@ -495,18 +463,18 @@ void FWWindow::filePrint()
         st->setBool("PrintSetup/printObjects",     printObjects     );
         st->setInt("PrintSetup/tableResolution",   tableResolution  );
 
+        st->getPrinterOptions(printer, pageWidth, pageHeight);
+
         switch (tableResolution)
         {
-        case 0: resolution = 300; break;
-        case 1: resolution = 225; break;
-        case 2: resolution = 150; break;
-        case 3: resolution = 100; break;
-        case 4: resolution = 75;  break;
+        case 0: table_scaling = 0.5; break;
+        case 1: table_scaling = 0.75; break;
+        case 2: table_scaling = 1.0; break;
+        case 3: table_scaling = 1.5; break;
+        case 4: table_scaling = 2.0; break;
         }
 
-        st->getPrinterOptions(printer,pageWidth,pageHeight);
-
-        printer->setResolution(resolution);
+        //printer->setResolution(resolution);
         printer->setFullPage(fullPage);
 
         QPrintDialog pdialog(printer, this);
@@ -524,17 +492,21 @@ void FWWindow::filePrint()
 
             statusBar()->showMessage( "Printing..." );
 
-            PrintingProgressDialog *ppd = new PrintingProgressDialog(this,printer,0,false);
+            PrintingProgressDialog *ppd = 
+                new PrintingProgressDialog(this, printer, 0, false);
 
             QString headerText = mw->printHeader();
 
 #if defined(Q_OS_MACX)
-            printerStream pr(printer,margin,printHeader,headerText,NULL);
+            printerStream pr(printer, table_scaling, margin, printHeader, headerText, NULL);
 #else
-            printerStream pr(printer,margin,printHeader,headerText,ppd);
+            printerStream pr(printer, table_scaling, margin, printHeader, headerText, ppd);
             ppd->show();
 #endif
-            pr.setFromTo(fromPage,toPage);
+            pr.setFromTo(fromPage, toPage);
+
+            if (fwbdebug)
+                qDebug("Printer resolution: %d dpi", printer->resolution());
 
             if ( !pr.begin())
             {
@@ -543,17 +515,22 @@ void FWWindow::filePrint()
                 return;
             }
 
-            int leftMargin = printer->paperRect().left() - printer->pageRect().left();
-            int topMargin = printer->paperRect().top() - printer->pageRect().top();
+            int leftMargin = printer->paperRect().left() -
+                printer->pageRect().left();
+            int topMargin = printer->paperRect().top() -
+                printer->pageRect().top();
 
             if (fwbdebug)
             {
-                qDebug("Margins: %d,%d",leftMargin,topMargin);
+                qDebug("Margins: %d,%d", leftMargin, topMargin);
             }
 
 //            int ppdCounter = 1;
-            printFirewall(activeProject()->getCurrentRuleSet()->getParent(),pr,ppd,
-                  newPageForSection, activeProject());
+            printFirewall(activeProject()->getCurrentRuleSet()->getParent(),
+                          pr,
+                          ppd, 
+                          newPageForSection, 
+                          activeProject());
 
             if (printLegend)
             {
@@ -1052,7 +1029,8 @@ void FWWindow::printFirewallFromFile (QString fileName,
     FWObjectDatabase * objdb = new FWObjectDatabase();
     QPrinter *printer = new QPrinter(QPrinter::HighResolution);
     objdb->load(fileName.toLatin1().constData(), NULL,librespath);
-    FWObject* obj = objdb->findObjectByName(Firewall::TYPENAME,firewallName.toAscii().data());
+    FWObject* obj = objdb->findObjectByName(Firewall::TYPENAME,
+                                            firewallName.toAscii().data());
     if (obj!=NULL)
     {
         int pageWidth = 0;
@@ -1060,7 +1038,7 @@ void FWWindow::printFirewallFromFile (QString fileName,
         bool  fullPage = false;
     
         float margin = 0;
-        int   resolution = 150;
+        float table_scaling = 1.0;
         bool  printHeader = true;
         bool  printLegend = true;
         bool  printObjects = true;
@@ -1084,135 +1062,136 @@ void FWWindow::printFirewallFromFile (QString fileName,
     
         switch (tableResolution)
         {
-        case 0: resolution = 300; break;
-        case 1: resolution = 225; break;
-        case 2: resolution = 150; break;
-        case 3: resolution = 100; break;
-        case 4: resolution = 75;  break;
+        case 0: table_scaling = 0.5; break;
+        case 1: table_scaling = 0.75; break;
+        case 2: table_scaling = 1.0; break;
+        case 3: table_scaling = 1.5; break;
+        case 4: table_scaling = 2.0; break;
         }
 
         st->getPrinterOptions(printer,pageWidth,pageHeight);
 
-        printer->setResolution(resolution);
+        //printer->setResolution(resolution);
         printer->setFullPage(fullPage);
         printer->setOutputFileName (outputFileName);
-            int fromPage = 1;
-            int toPage = 9999;
+        int fromPage = 1;
+        int toPage = 9999;
 
+        QString headerText = fileName; //mw->printHeader();
+        printerStream pr(printer, table_scaling,
+                         margin, printHeader, headerText, NULL);
 
-            QString headerText = fileName; //mw->printHeader();
-            printerStream pr(printer,margin,printHeader,headerText,NULL);
+        pr.setFromTo(fromPage,toPage);
 
-            pr.setFromTo(fromPage,toPage);
+        if ( !pr.begin())
+        {
+            return;
+        }
 
-            if ( !pr.begin())
-            {
-                return;
-            }
+        int leftMargin = printer->paperRect().left() -
+            printer->pageRect().left();
+        int topMargin = printer->paperRect().top() -
+            printer->pageRect().top();
 
-            int leftMargin = printer->paperRect().left() - printer->pageRect().left();
-            int topMargin = printer->paperRect().top() - printer->pageRect().top();
-
-            if (fwbdebug)
-            {
-                qDebug("Margins: %d,%d",leftMargin,topMargin);
-            }
+        if (fwbdebug)
+        {
+            qDebug("Margins: %d,%d",leftMargin,topMargin);
+        }
 
 //            int ppdCounter = 1;
-            printFirewall(obj,pr,NULL,newPageForSection, NULL);
+        printFirewall(obj, pr, NULL, newPageForSection, NULL);
 
-            if (printLegend)
+        if (printLegend)
+        {
+            if (fwbdebug) qDebug("******** Legend");
+
+            if (newPageForSection)
             {
-                if (fwbdebug) qDebug("******** Legend");
+                pr.flushPage();
+                pr.beginPage();   // resets yPos
+            } else
+                pr.printText("\n");
 
-                if (newPageForSection)
+            pr.printText(tr("Legend"));
+            pr.printText(" ");
+
+            QTableWidget legendTbl(1,2);
+            legendTbl.resize(pr.getWorkspaceWidth(),
+                             pr.getWorkspaceHeight());
+            legendTbl.setSizePolicy( QSizePolicy( (QSizePolicy::Policy)7,
+                                                  (QSizePolicy::Policy)7) );
+            legendTbl.setShowGrid(false);
+            legendTbl.setFrameStyle(QFrame::NoFrame | QFrame::Plain);
+
+            legendTbl.horizontalHeader()->hide();
+            legendTbl.verticalHeader()->hide();
+            //legendTbl.setTopMargin(0);
+            //legendTbl.setLeftMargin(0);
+
+            legendTbl.setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+            legendTbl.setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+
+            string icon_path="/FWBuilderResources/Type/";
+            int row=0;
+            int col=0;
+
+            QPixmap pm;
+
+            QPixmap bfr(32,32);
+            QPainter bfrp(&bfr);
+
+            for (int i=0; !legendList[i].isEmpty(); ++i,++i)
+            {
+                if (row>=legendTbl.rowCount()) legendTbl.insertRow(row);
+
+                QString typeName=legendList[i];
+                QString objName=legendList[i+1];
+
+                if (typeName==CustomService::TYPENAME)
                 {
-                    pr.flushPage();
-                    pr.beginPage();   // resets yPos
-                } else
-                    pr.printText("\n");
-
-                pr.printText(tr("Legend"));
-                pr.printText(" ");
-
-                QTableWidget legendTbl(1,2);
-                legendTbl.resize(pr.getWorkspaceWidth(),
-                                 pr.getWorkspaceHeight());
-                legendTbl.setSizePolicy( QSizePolicy( (QSizePolicy::Policy)7,
-                                                      (QSizePolicy::Policy)7) );
-                legendTbl.setShowGrid(false);
-                legendTbl.setFrameStyle(QFrame::NoFrame | QFrame::Plain);
-
-                legendTbl.horizontalHeader()->hide();
-                legendTbl.verticalHeader()->hide();
-                //legendTbl.setTopMargin(0);
-                //legendTbl.setLeftMargin(0);
-
-                legendTbl.setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-                legendTbl.setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-
-
-                string icon_path="/FWBuilderResources/Type/";
-                int row=0;
-                int col=0;
-
-                QPixmap pm;
-
-                QPixmap bfr(32,32);
-                QPainter bfrp(&bfr);
-
-                for (int i=0; !legendList[i].isEmpty(); ++i,++i)
-                {
-                  if (row>=legendTbl.rowCount()) legendTbl.insertRow(row);
-
-                    QString typeName=legendList[i];
-                    QString objName=legendList[i+1];
-
-                    if (typeName==CustomService::TYPENAME)
-                    {
-                        col++;
-                        row=0;
-                    }
-
-                    if (fwbdebug)
-                        qDebug("Legend table: row=%d col=%d %s %s",
-                               row,col,typeName.toAscii().constData(),objName.toAscii().constData());
-
-//                    pm.load( Resources::global_res->getResourceStr(
-//                        icon_path+string(typeName.toLatin1().constData())+"/icon").c_str() );
-
-                    QString icn = ":/Icons/"+typeName+"/icon";
-                    QPixmap pm;
-                    if ( ! QPixmapCache::find( icn, pm) )
-                    {
-                        pm.load( icn );
-                        QPixmapCache::insert( icn, pm);
-                    }
-
-                    bfrp.fillRect(0,0,32,32,QColor(Qt::white));
-                    bfrp.drawPixmap(4,4,pm);
-
-                    QTableWidgetItem *itm = new QTableWidgetItem;
-                    itm->setIcon(QIcon(bfr));
-                    itm->setText(objName);
-                    legendTbl.setItem(row, col, itm);
-
-                    row++;
+                    col++;
+                    row=0;
                 }
 
-                legendTbl.resizeColumnToContents(0);
-                legendTbl.resizeColumnToContents(1);
+                if (fwbdebug)
+                    qDebug("Legend table: row=%d col=%d %s %s",
+                           row,
+                           col,
+                           typeName.toAscii().constData(),
+                           objName.toAscii().constData());
 
-                for (int i=0; i<legendTbl.rowCount(); ++i)
-                    legendTbl.resizeRowToContents(i);
+                QString icn = ":/Icons/"+typeName+"/icon";
+                QPixmap pm;
+                if ( ! QPixmapCache::find( icn, pm) )
+                {
+                    pm.load( icn );
+                    QPixmapCache::insert( icn, pm);
+                }
 
-                QSize sh = legendTbl.sizeHint();
-                legendTbl.resize(sh.width(),sh.height());
-                if (fwbdebug) qDebug("legendTbl size: %dx%d",
-                                     legendTbl.width(),legendTbl.height());
+                bfrp.fillRect(0,0,32,32,QColor(Qt::white));
+                bfrp.drawPixmap(4,4,pm);
 
-                pr.printQTable(&legendTbl, false, false);
+                QTableWidgetItem *itm = new QTableWidgetItem;
+                itm->setIcon(QIcon(bfr));
+                itm->setText(objName);
+                legendTbl.setItem(row, col, itm);
+
+                row++;
             }
+
+            legendTbl.resizeColumnToContents(0);
+            legendTbl.resizeColumnToContents(1);
+
+            for (int i=0; i<legendTbl.rowCount(); ++i)
+                legendTbl.resizeRowToContents(i);
+
+            QSize sh = legendTbl.sizeHint();
+            legendTbl.resize(sh.width(),sh.height());
+            if (fwbdebug) qDebug("legendTbl size: %dx%d",
+                                 legendTbl.width(),legendTbl.height());
+
+            pr.printQTable(&legendTbl, false, false);
+        }
     }
     else
     {   
