@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: FindWhereUsedWidget.cpp,v 1.6 2007/05/23 03:05:50 vkurland Exp $
+  $Id: FindWhereUsedWidget.cpp 557 2008-09-29 13:22:09Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,21 +17,20 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "config.h"
+#include "../../config.h"
+#include "../../definitions.h"
 #include "global.h"
 #include "utils.h"
 #include "utils_no_qt.h"
 #include "platforms.h"
-#include "definitions.h"
 
 #include "FindWhereUsedWidget.h"
-#include "ObjectManipulator.h"
 #include "FWWindow.h"
 #include "FWObjectDropArea.h"
 #include "ObjectManipulator.h"
@@ -39,8 +38,7 @@
 #include "FWBSettings.h"
 #include "ObjectTreeView.h"
 #include "RuleSetView.h"
-#include "ObjectEditor.h"
-
+#include "ProjectPanel.h"
 
 #include "fwbuilder/FWObjectDatabase.h"
 #include "fwbuilder/FWReference.h"
@@ -58,7 +56,7 @@
 #include "fwbuilder/UDPService.h"
 #include "fwbuilder/Resources.h"
 
-#include <qwidgetstack.h>
+#include <qstackedwidget.h>
 #include <qradiobutton.h>
 #include <qcheckbox.h>
 #include <qcombobox.h>
@@ -78,31 +76,44 @@ using namespace std;
 using namespace libfwbuilder;
 
 
-FindWhereUsedWidget::FindWhereUsedWidget(QWidget*p, const char * n, WFlags f, bool f_mini) : findWhereUsedWidget_q(p,n,f) 
+FindWhereUsedWidget::FindWhereUsedWidget(QWidget *p,
+                                         const char * n,
+                                         Qt::WindowFlags f,
+                                         bool f_mini) : QWidget(p)
 {
+    m_widget = new Ui::findWhereUsedWidget_q;
+    m_widget->setupUi(this);
+
+    setObjectName(n);
+    setWindowFlags(f);
+
     flShowObject=true;
     if (f_mini)
     {
-        buttonsBox->hide();
-        dropBox->hide();
+        m_widget->buttonsBox->hide();
+        m_widget->dropBox->hide();
     }
     else
     {
-        //connect (dropArea,SIGNAL(objectInserted()),this,SLOT(findFromDrop()));
-        connect (dropArea,SIGNAL(objectDeleted()),this,SLOT(init()));
+        connect (m_widget->dropArea,SIGNAL(objectDeleted()),this,SLOT(init()));
     }
 }
 
+FindWhereUsedWidget::~FindWhereUsedWidget()
+{
+    delete m_widget;
+}
+
 void FindWhereUsedWidget::setShowObject(bool fl)
 {
     flShowObject=fl;
 }
 
-void FindWhereUsedWidget::itemActivated(QListViewItem* item)
+void FindWhereUsedWidget::itemActivated(QTreeWidgetItem* item)
 {
     FWObject *o;
-    o=mapping[item];
-    
+    o = mapping[item];
+
     if (flShowObject && o!=NULL)
     {
         showObject(o);
@@ -116,22 +127,24 @@ void FindWhereUsedWidget::find()
 
 void FindWhereUsedWidget::find(FWObject *obj)
 {
-    dropArea->insertObject(obj);
+    m_widget->dropArea->insertObject(obj);
     find();
 }
 
 void FindWhereUsedWidget::_find(FWObject *obj)
 {
-    object=obj;
-    resListView->clear();
+    object = obj;
+    m_widget->resListView->clear();
     mapping.clear();
     resset.clear();
-    
-    
-    mw->db()->findWhereUsed(obj,mw->db(),resset);
+
+    if (fwbdebug) qDebug("FindWhereUsedWidget: initiate search for %s",
+                         obj->getName().c_str());
+
+    mw->db()->findWhereUsed(obj, mw->db(), resset);
 
     set<FWObject*>::iterator i=resset.begin();
-    QListViewItem *item;
+    QTreeWidgetItem *item;
     QString c1;
     QString c2;
     FWObject* o;
@@ -144,28 +157,39 @@ void FindWhereUsedWidget::_find(FWObject *obj)
         fw=NULL;
         r=NULL;
         rs=NULL;
-            
-        if (findRef(object,o)==NULL) continue;
-        if (RuleElement::cast(o)!=NULL)            
+
+
+        if (fwbdebug) qDebug("Search result object id=%d type=%s name=%s",
+                             o->getId(),
+                             o->getTypeName().c_str(),
+                             o->getName().c_str());
+
+//        if (findRef(object,o)==NULL) continue;
+
+        if (mw->isSystem(o) || RuleSet::cast(o) ||
+            Firewall::cast(o) || Library::cast(o)) continue;
+
+        c1 = QString::fromUtf8(o->getName().c_str());
+        c2 = tr("Type: ")+QString::fromUtf8(o->getTypeName().c_str());
+
+        if (RuleElement::cast(o)!=NULL || Rule::cast(o)!=NULL)
         {
-            fw=o->getParent();
-            
-            while (fw!=NULL && !Firewall::isA(fw)) 
+            fw = o;
+            while (fw!=NULL && !Firewall::isA(fw))
             {
                 if (Rule::cast(fw))
                 {
-                    r=Rule::cast(fw); 
+                    r=Rule::cast(fw);
                 } else if (RuleSet::cast(fw))
                 {
                     rs=RuleSet::cast(fw);
                 }
-                        
                 fw=fw->getParent();
             }
             if (fw==NULL || r==NULL || rs==NULL) continue;
-            
-            c1=QString::fromUtf8(fw->getName().c_str());
-            
+
+            c1 = QString::fromUtf8(fw->getName().c_str());
+
             if (NAT::isA(rs))
             {
                 c2=tr("NAT");
@@ -180,39 +204,25 @@ void FindWhereUsedWidget::_find(FWObject *obj)
                 c2=tr("Unknown rule set");
             }
             c2+=tr("/Rule%1").arg(r->getPosition());
-            
-        } else if (
-                FWBTree::isSystem(o) ||
-                Rule::cast(o) || 
-                RuleSet::cast(o) || 
-                Firewall::cast(o) ||
-                Library::cast(o))
-        {
-            continue;
-        }
-        else
-        {
-            c1=QString::fromUtf8(o->getName().c_str());
-            c2=tr("Type: ")+QString::fromUtf8(o->getTypeName().c_str());
         }
 
-        string icn="icon-tree";
         FWObject *pixobj=(fw==NULL)?o:fw;
-        
-//        QPixmap pm = QPixmap::fromMimeSource( 
-//            Resources::global_res->getObjResourceStr(pixobj, icn).c_str() );
+
         QString icn_file =
-            Resources::global_res->getObjResourceStr(pixobj, icn).c_str();
+            (":/Icons/"+pixobj->getTypeName()+"/icon-tree").c_str();
+
         QPixmap pm;
         if ( ! QPixmapCache::find( icn_file, pm) )
         {
-            pm = QPixmap::fromMimeSource( icn_file );
+            pm.load( icn_file );
             QPixmapCache::insert( icn_file, pm);
         }
-        
-        item=new QListViewItem(resListView,c1,c2);
-        item->setPixmap(0,pm);
-        mapping[item]=o;
+
+        QStringList qsl;
+        qsl << c1 << c2;
+        item = new QTreeWidgetItem(m_widget->resListView, qsl);
+        item->setIcon(0, QIcon(pm));
+        mapping[item] = o;
     }
     show();
 }
@@ -220,57 +230,68 @@ void FindWhereUsedWidget::_find(FWObject *obj)
 void FindWhereUsedWidget::init()
 {
     object=NULL;
-    resListView->clear();
+    m_widget->resListView->clear();
     mapping.clear();
     resset.clear();
-    
+
 }
 
 void FindWhereUsedWidget::findFromDrop()
 {
-    _find(dropArea->getObject());
+    _find(m_widget->dropArea->getObject());
 }
 
 void FindWhereUsedWidget::showObject(FWObject* o)
 {
-    if (fwbdebug) qDebug("FindWhereUsedWidget::showObject");
-    
+    if (fwbdebug) qDebug("FindWhereUsedWidget::showObject  o=%s (%s)",
+                         o->getName().c_str(), o->getTypeName().c_str());
+
     if (object==NULL || o==NULL) return;
-    
-    FWReference* ref=NULL;
-    
-            
+
+    FWReference* ref = NULL;
+
     if (RuleElement::cast(o)!=NULL)
     {
-        ref=findRef(object,o);
-        if (ref==NULL) return;
-        
-        om->clearFocus();
-        mw->ensureObjectVisibleInRules( ref );
-        mw->selectRules();
-        if (oe->isVisible())
-        {
-            om->editObject( object );
-        }
-        return;
-    }
-    mw->unselectRules();
+        mw->activeProject()->openRuleSet(o->getParent()->getParent());
+        mw->clearManipulatorFocus();
+        RuleSetView *rsv = mw->activeProject()->getCurrentRuleSetView();
+        rsv->selectRE(RuleElement::cast(o), object);
+        rsv->setFocus(Qt::MouseFocusReason);
 
-    if (Group::cast(o)!=NULL)
+        if (mw->isEditorVisible()) mw->editObject( object );
+    } else
     {
-
-        om->openObject( o );
-        mw->unselectRules();
-        
-        if (oe->isVisible())
+        if (Rule::cast(o)!=NULL)
         {
-            om->editObject( o );
-            oe->selectObject( object);
+            mw->activeProject()->openRuleSet(o->getParent());
+            mw->clearManipulatorFocus();
+            RuleSetView *rsv = mw->activeProject()->getCurrentRuleSetView();
+            rsv->selectRE(Rule::cast(o),rsv->getColByType(RuleSetView::Action));
+
+            if (mw->isEditorVisible()) mw->editObject( object );
+        } else
+        {
+            mw->unselectRules();
+
+            if (Group::cast(o)!=NULL)
+            {
+                mw->openObject( o );
+                mw->unselectRules();
+
+                if (mw->isEditorVisible())
+                {
+                    mw->editObject( o );
+                    mw->selectObjectInEditor( object);
+                }
+            } else
+            {
+                mw->openObject( object );
+                mw->unselectRules();
+
+                if (mw->isEditorVisible()) mw->editObject( object );
+            }
         }
-        return;
     }
-    qDebug("4444");
-    //oe->close();
-    //om->openObject( o );
-    //om->select();  // selects an item in the tree and assigns kbd focus to it
+    //mw->closeEditor();
+    //mw->openObject( o );
 }
