@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FirewallDialog.cpp,v 1.43 2007/08/02 05:20:08 vkurland Exp $
+  $Id: FirewallDialog.cpp 553 2008-09-25 13:37:21Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,20 +17,20 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 #include "utils.h"
 #include "platforms.h"
+#include "ProjectPanel.h"
 
 #include "FWBTree.h"
 #include "FirewallDialog.h"
-#include "ObjectManipulator.h"
 #include "DialogFactory.h"
 #include "FWWindow.h"
 
@@ -40,10 +40,10 @@
 #include "fwbuilder/Management.h"
 #include "fwbuilder/FWException.h"
 #include "fwbuilder/Resources.h"
+#include "FWBSettings.h"
 
 #include <vector>
 #include <map>
-#include <algorithm>
 
 #include <qlineedit.h>
 #include <qspinbox.h>
@@ -52,7 +52,7 @@
 #include <qcombobox.h>
 #include <qmessagebox.h>
 #include <qpushbutton.h>
-#include <qiconview.h>
+#include <qlistwidget.h>
 #include <qtabwidget.h>
 #include <qlabel.h>
 #include <qtimer.h>
@@ -62,23 +62,35 @@
 using namespace std;
 using namespace libfwbuilder;
 
+FirewallDialog::~FirewallDialog()
+{
+    delete m_dialog;
+}
+
+FirewallDialog::FirewallDialog(ProjectPanel *project, QWidget *parent) :
+    QWidget(parent), m_project(project)
+{
+    m_dialog = new Ui::FirewallDialog_q;
+    m_dialog->setupUi(this);
+    obj=NULL;
+}
+
 void FirewallDialog::loadFWObject(FWObject *o)
 {
     obj=o;
     Firewall *s = dynamic_cast<Firewall*>(obj);
     assert(s!=NULL);
 
-    init=true;
-
-    fillLibraries(libs,obj);
+    init = true;
+    modified = false;
 
 /* fill in platform */
-    setPlatform(platform, obj->getStr("platform").c_str() );
+    setPlatform(m_dialog->platform, obj->getStr("platform").c_str() );
 
     fillVersion();
 
 /* fill in host OS  */
-    setHostOS(hostOS, obj->getStr("host_OS").c_str() );
+    setHostOS(m_dialog->hostOS, obj->getStr("host_OS").c_str() );
 
 /* ---------------- */
 
@@ -87,48 +99,39 @@ void FirewallDialog::loadFWObject(FWObject *o)
 
 //    FWOptions  *opt =s->getOptionsObject();
 
-    obj_name->setText( QString::fromUtf8(s->getName().c_str()) );
-//    snmpCommunity->setText( mgmt->getSNMPManagement()->getReadCommunity().c_str() );
+    m_dialog->obj_name->setText( QString::fromUtf8(s->getName().c_str()) );
 
-    comment->setTextFormat(QTextEdit::PlainText);
+    m_dialog->comment->setText( QString::fromUtf8(s->getComment().c_str()) );
 
-    comment->setText( QString::fromUtf8(s->getComment().c_str()) );
+    m_dialog->inactive->setChecked(s->getInactive());
 
-    inactive->setChecked(s->getInactive());
+    m_dialog->obj_name->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->obj_name);
 
-    //apply->setEnabled( false );
+    m_dialog->platform->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->platform);
 
+    m_dialog->version->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->version);
 
-    obj_name->setEnabled(!o->isReadOnly());
-    setDisabledPalette(obj_name);
+    m_dialog->hostOS->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->hostOS);
 
-    libs->setEnabled(!o->isReadOnly());
-    setDisabledPalette(libs);
+    m_dialog->fwAdvanced->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->fwAdvanced);
 
-    platform->setEnabled(!o->isReadOnly());
-    setDisabledPalette(platform);
+    m_dialog->osAdvanced->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->osAdvanced);
 
-    version->setEnabled(!o->isReadOnly());
-    setDisabledPalette(version);
-
-    hostOS->setEnabled(!o->isReadOnly());
-    setDisabledPalette(hostOS);
-
-    fwAdvanced->setEnabled(!o->isReadOnly());
-    setDisabledPalette(fwAdvanced);
-
-    osAdvanced->setEnabled(!o->isReadOnly());
-    setDisabledPalette(osAdvanced);
-
-    comment->setReadOnly(o->isReadOnly());
-    setDisabledPalette(comment);
+    m_dialog->comment->setReadOnly(o->isReadOnly());
+    setDisabledPalette(m_dialog->comment);
 
 //    snmpCommunity->setEnabled(!o->isReadOnly());
 //    setDisabledPalette(snmpCommunity);
 
-    inactive->setEnabled(!o->isReadOnly());
-    setDisabledPalette(inactive);
-    
+    m_dialog->inactive->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->inactive);
+
 
     init=false;
 }
@@ -136,43 +139,33 @@ void FirewallDialog::loadFWObject(FWObject *o)
 /* fill in version */
 void FirewallDialog::fillVersion()
 {
-    version->clear();
+    m_dialog->version->clear();
 
-    list<QStringPair> vl=getVersionsForPlatform( readPlatform(platform) );
-    QString            v=obj->getStr("version").c_str();
-    int cp=0;
+    list<QStringPair> vl = getVersionsForPlatform(
+        readPlatform(m_dialog->platform) );
+    QString v = obj->getStr("version").c_str();
+    int cp = 0;
     for (list<QStringPair>::iterator i1=vl.begin(); i1!=vl.end(); i1++,cp++)
     {
         if (fwbdebug)
-            qDebug(QString("Adding version %1").arg(i1->second));
+            qDebug(QString("Adding version %1").arg(
+                       i1->second).toAscii().constData());
 
-        version->insertItem( i1->second );
-        if ( v == i1->first ) version->setCurrentItem( cp );
+        m_dialog->version->addItem( i1->second );
+        if ( v == i1->first ) m_dialog->version->setCurrentIndex( cp );
     }
 }
 
 void FirewallDialog::saveVersion()
 {
-    QString pl = readPlatform(platform);
+    QString pl = readPlatform(m_dialog->platform);
 
-    list<QStringPair> vl=getVersionsForPlatform( pl.latin1() );
-    QString           v = version->currentText();
+    list<QStringPair> vl=getVersionsForPlatform( pl.toLatin1().constData() );
+    QString           v = m_dialog->version->currentText();
     list<QStringPair>::iterator li =
         std::find_if(vl.begin(),vl.end(),findSecondInQStringPair(v));
     if (li!=vl.end())
-        obj->setStr("version", li->first.latin1() );
-
-#if 0
-    int cp=0;
-    for (list<QStringPair>::iterator i1=vl.begin(); i1!=vl.end(); i1++,cp++)
-    {
-        if ( v == i1.data() )
-        {
-            obj->setStr("version", i1.key().latin1() );
-            break;
-        }
-    }
-#endif
+        obj->setStr("version", li->first.toLatin1().constData() );
 }
 
 void FirewallDialog::platformChanged()
@@ -180,41 +173,50 @@ void FirewallDialog::platformChanged()
     fillVersion();
     changed();
 
-    QString so=Resources::platform_res[readPlatform(platform).latin1()]->getResourceStr("/FWBuilderResources/Target/supported_os").c_str();
+    QString so = Resources::platform_res[
+        readPlatform(m_dialog->platform).toLatin1().constData()
+    ]->getResourceStr("/FWBuilderResources/Target/supported_os").c_str();
     if (so.isEmpty()) return;
 
     QString ho=so.section(",",0);
-    setHostOS( hostOS, ho.latin1() );
+    setHostOS( m_dialog->hostOS, ho.toLatin1().constData() );
 
-    QString pl = readPlatform(platform);
-    fwAdvanced->setEnabled( pl!="unknown" );
+    QString pl = readPlatform(m_dialog->platform);
+    m_dialog->fwAdvanced->setEnabled( pl!="unknown" );
 }
 
 void FirewallDialog::hostOSChanged()
 {
     changed();
-    QString ho = readHostOS(hostOS);
-    osAdvanced->setEnabled( ho!="unknown_os" );
+    QString ho = readHostOS(m_dialog->hostOS);
+    m_dialog->osAdvanced->setEnabled( ho!="unknown_os" );
 }
 
 void FirewallDialog::changed()
 {
-    //apply->setEnabled( true );
+    if (fwbdebug) qDebug("FirewallDialog::changed init=%d", init);
+    if (!init) modified = true;
     emit changed_sign();
 }
 
 void FirewallDialog::validate(bool *res)
 {
-    *res=true;
-    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
-    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
+    *res = true;
+    if (!isTreeReadWrite(this,obj))
+    {
+        *res=false;
+        return;
+    }
+    if (!validateName(this,obj,m_dialog->obj_name->text()))
+    {
+        *res = false;
+        return;
+    }
 }
 
-void FirewallDialog::isChanged(bool *res)
+void FirewallDialog::isChanged(bool *m)
 {
-    if (fwbdebug)
-        qDebug("FirewallDialog::isChanged");
-    //*res=(!init && apply->isEnabled());
+    *m = modified;
 }
 
 void FirewallDialog::libChanged()
@@ -233,58 +235,50 @@ void FirewallDialog::applyChanges()
     assert(s!=NULL);
 
     string oldname=obj->getName();
-    string newname=string(obj_name->text().utf8());
+    string newname=string(m_dialog->obj_name->text().toUtf8().constData());
     string oldplatform=obj->getStr("platform");
 
     string oldVer=obj->getStr("version");
 
-    obj->setName( newname );
-    obj->setComment( string(comment->text().utf8()) );
-//    mgmt->getSNMPManagement()->setReadCommunity( snmpCommunity->text().latin1() );
+    obj->setName(newname);
+    obj->setComment(
+        string(m_dialog->comment->toPlainText().toUtf8().constData()));
 
-    string pl = readPlatform(platform).latin1();
+    string pl = readPlatform(m_dialog->platform).toLatin1().constData();
     obj->setStr("platform", pl );
 
-    obj->setStr("host_OS", readHostOS(hostOS).latin1() );
-    
-    s->setInactive(inactive->isChecked());
-    
+    obj->setStr("host_OS",
+                readHostOS(m_dialog->hostOS).toLatin1().constData());
+
+    s->setInactive(m_dialog->inactive->isChecked());
+
     saveVersion();
 
     string newVer=obj->getStr("version");
-        
-    om->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
+
+    mw->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
 
     if (oldplatform!=pl || oldname!=newname || oldVer!=newVer)
     {
         if (fwbdebug)
-            qDebug("FirewallDialog::applyChanges() scheduling call to reopenFirewall()");
-        //mw->reopenFirewall();
-        //QTimer::singleShot( 0, mw, SLOT(reopenFirewall()) );
+            qDebug("FirewallDialog::applyChanges() scheduling call "
+                   "to reopenFirewall()");
         mw->scheduleRuleSetRedraw();
     }
 
     if (oldplatform!=pl)
     {
         if (fwbdebug)
-            qDebug("FirewallDialog::applyChanges() platform has changed - clear option 'compiler'");
+            qDebug("FirewallDialog::applyChanges() platform has changed - "
+                   "clear option 'compiler'");
         Firewall *s = Firewall::cast(obj);
         assert(s!=NULL);
         FWOptions  *opt =s->getOptionsObject();
         opt->setStr("compiler","");
     }
 
-    init=true;
-
-/* move to another lib if we have to */
-    if (! FWBTree::isSystem(obj) && libs->currentText() != QString(obj->getLibrary()->getName().c_str()))
-        om->moveObject(libs->currentText(), obj);
-
-    init=false;
-
-    //apply->setEnabled( false );
-    om->updateLastModifiedTimestampForAllFirewalls(s);
-
+    mw->updateLastModifiedTimestampForAllFirewalls(s);
+    modified = false;
 }
 
 void FirewallDialog::discardChanges()
@@ -294,9 +288,12 @@ void FirewallDialog::discardChanges()
 
 void FirewallDialog::openFWDialog()
 {
-    /*if (apply->isEnabled())*/ applyChanges();
+    if (fwbdebug)
+        qDebug("FirewallDialog::openFWDialog: modified=%d", modified);
 
-    if (obj->getStr("version").empty()) saveVersion();
+    if (modified) applyChanges();
+
+//    if (obj->getStr("version").empty()) saveVersion();
 
     try
     {
@@ -321,7 +318,7 @@ void FirewallDialog::openFWDialog()
 
 void FirewallDialog::openOSDialog()
 {
-    /*if (apply->isEnabled())*/ applyChanges();
+    if (modified) applyChanges();
 
     try
     {
@@ -350,6 +347,5 @@ void FirewallDialog::openOSDialog()
 void FirewallDialog::closeEvent(QCloseEvent *e)
 {
     emit close_sign(e);
-
 }
 
