@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: GroupObjectDialog.h,v 1.16 2006/08/18 04:10:33 vkurland Exp $
+  $Id: GroupObjectDialog.h 529 2008-09-13 04:37:24Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,8 +27,8 @@
 #ifndef __GROUPOBJECTDIALOG_H_
 #define __GROUPOBJECTDIALOG_H_
 
-#include "config.h"
-#include <groupobjectdialog_q.h>
+#include "../../config.h"
+#include <ui_groupobjectdialog_q.h>
 
 #include <qtooltip.h>
 #include <vector>
@@ -36,54 +36,40 @@
 #include "fwbuilder/FWObject.h"
 #include "ObjectListView.h"
 #include "ObjectIconView.h"
+#include <QWidget>
 
 class ObjectIconViewItem;
 class ObjectListViewItem;
+class ProjectPanel;
 
-class IconViewObjToolTip : public QToolTip {
-
-    QIconView *view;
- public:
-    IconViewObjToolTip(QIconView *w);
-    virtual ~IconViewObjToolTip() {}
-    virtual void maybeTip(const QPoint &p);
-};
-
-class ListViewObjToolTip : public QToolTip {
-
-    QListView *view;
- public:
-    ListViewObjToolTip(QListView *w);
-    virtual ~ListViewObjToolTip() {}
-    virtual void maybeTip(const QPoint &p);
-};
-
-class GroupObjectDialog : public GroupObjectDialog_q
+class GroupObjectDialog : public QWidget
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
 
+    Ui::GroupObjectDialog_q*m_dialog;
     ObjectIconView         *iconView;
     ObjectListView         *listView;
 
-    std::vector<libfwbuilder::FWObject*> selectedObjects;
+    std::vector<int> selectedObjects;
 
     libfwbuilder::FWObject *selectedObject;
-    std::map<std::string, ObjectIconViewItem*> allIconViewItems;
-    std::map<std::string, ObjectListViewItem*> allListViewItems;
 
     bool init;
 
+    ProjectPanel *m_project;
     void addIcon(libfwbuilder::FWObject *o);
     void addIcon(libfwbuilder::FWObject *o, bool ref);
 
     void insertObject(libfwbuilder::FWObject *o);
 
     void setupPopupMenu(const QPoint&);
+    void saveColumnWidths();
 
  public:
-    GroupObjectDialog(QWidget *parent);
+    GroupObjectDialog(ProjectPanel *project, QWidget *parent);
+    ~GroupObjectDialog();
 
     enum viewType { Icon, List };
 
@@ -98,20 +84,21 @@ class GroupObjectDialog : public GroupObjectDialog_q
     virtual void switchToIconView();
     virtual void switchToListView();
     virtual void openObject();
-    virtual void openObject(QIconViewItem *itm);
-    virtual void openObject(QListViewItem *itm);
+    virtual void openObject(QListWidgetItem *itm);
+    virtual void openObject(QTreeWidgetItem *itm);
     virtual void dropped(QDropEvent *ev);
-    virtual void iconContextMenu(QIconViewItem*,const QPoint&);
-    virtual void listContextMenu(QListViewItem*,const QPoint&,int);
+    virtual void iconContextMenu(const QPoint & pos);
+    virtual void listContextMenu(const QPoint & pos);
     virtual void closeEvent(QCloseEvent *e);
+    virtual void hideEvent(QHideEvent *e);
     
     void copyObj();
     void cutObj();
     void pasteObj();
     void deleteObj();
 
-    void iconViewCurrentChanged(QIconViewItem *itm);
-    void listViewCurrentChanged(QListViewItem *itm);
+    void iconViewCurrentChanged(QListWidgetItem *itm);
+    void listViewCurrentChanged(QTreeWidgetItem *itm);
     
     void iconViewSelectionChanged();
     void listViewSelectionChanged();
