@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland <vadim@fwbuilder.org>
 
-  $Id: SimpleTextView.h 353 2008-07-13 01:26:39Z vadim $
+  $Id: Help.h 669 2008-11-24 23:49:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -30,6 +30,7 @@
 #include "../../config.h"
 #include "SimpleTextView.h"
 
+#include <QFile>
 
 
 class Help : public SimpleTextView
@@ -42,6 +43,11 @@ public:
     virtual ~Help() {};
 
     void scrollToAnchor(const QString &anchor);
+
+    static QString getHelpFileContents(const QString &help_file);
+    static bool getFile(const QString &help_file, const QString &locale,
+                        QFile &file);
+
 };
 
 #endif 
