@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: HostDialog.cpp,v 1.20 2007/04/14 00:18:43 vkurland Exp $
+  $Id: HostDialog.cpp 553 2008-09-25 13:37:21Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,19 +17,19 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 #include "utils.h"
 
 #include "FWBTree.h"
 #include "HostDialog.h"
-#include "ObjectManipulator.h"
+#include "ProjectPanel.h"
 
 #include "fwbuilder/Library.h"
 #include "fwbuilder/Host.h"
@@ -44,68 +44,87 @@
 #include <qcombobox.h>
 #include <qmessagebox.h>
 #include <qpushbutton.h>
+#include "FWBSettings.h"
+
+#include "FWWindow.h"
 
 using namespace std;
 using namespace libfwbuilder;
 
+HostDialog::HostDialog(ProjectPanel *project, QWidget *parent) : QWidget(parent), m_project(project)
+{
+    m_dialog = new Ui::HostDialog_q;
+    m_dialog->setupUi(this);
+    obj=NULL;
+}
+
+HostDialog::~HostDialog()
+{
+    delete m_dialog;
+}
+
 void HostDialog::loadFWObject(FWObject *o)
 {
     obj=o;
     Host *s = dynamic_cast<Host*>(obj);
     assert(s!=NULL);
 
-    init=true;
-
-    fillLibraries(libs,obj);
+    init = true;
+    modified = false;
 
     Management *mgmt=s->getManagementObject();
     assert(mgmt!=NULL);
 
     FWOptions  *opt =s->getOptionsObject();
 
-    obj_name->setText( QString::fromUtf8(s->getName().c_str()) );
+    m_dialog->obj_name->setText( QString::fromUtf8(s->getName().c_str()) );
 //    snmpCommunity->setText( mgmt->getSNMPManagement()->getReadCommunity().c_str() );
-    MACmatching->setChecked( opt->getBool("use_mac_addr_filter") );
+    m_dialog->MACmatching->setChecked( opt->getBool("use_mac_addr_filter") );
 
-    comment->setText( QString::fromUtf8(s->getComment().c_str()) );
+    m_dialog->comment->setText( QString::fromUtf8(s->getComment().c_str()) );
 
     //apply->setEnabled( false );
 
-    obj_name->setEnabled(!o->isReadOnly());
-    setDisabledPalette(obj_name);
-
-    libs->setEnabled(!o->isReadOnly());
-    setDisabledPalette(libs);
+    m_dialog->obj_name->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->obj_name);
 
 //    snmpCommunity->setEnabled(!o->isReadOnly());
 //    setDisabledPalette(snmpCommunity);
 
-    MACmatching->setEnabled(!o->isReadOnly());
-    setDisabledPalette(MACmatching);
+    m_dialog->MACmatching->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->MACmatching);
 
-    comment->setReadOnly(o->isReadOnly());
-    setDisabledPalette(comment);
+    m_dialog->comment->setReadOnly(o->isReadOnly());
+    setDisabledPalette(m_dialog->comment);
 
 
     init=false;
 }
-    
+
 void HostDialog::changed()
 {
-    //apply->setEnabled( true );
+    if (!init) modified = true;
     emit changed_sign();
 }
 
 void HostDialog::validate(bool *res)
 {
-    *res=true;
-    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
-    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
+    *res = true;
+    if (!isTreeReadWrite(this,obj))
+    {
+        *res=false;
+        return;
+    }
+    if (!validateName(this,obj,m_dialog->obj_name->text()))
+    {
+        *res=false;
+        return;
+    }
 }
 
-void HostDialog::isChanged(bool *res)
+void HostDialog::isChanged(bool *m)
 {
-    //*res=(!init && apply->isEnabled());
+    *m = modified;
 }
 
 void HostDialog::libChanged()
@@ -124,24 +143,16 @@ void HostDialog::applyChanges()
     FWOptions  *opt =s->getOptionsObject();
 
     string oldname=obj->getName();
-    obj->setName( string(obj_name->text().utf8()) );
-    obj->setComment( string(comment->text().utf8()) );
+    obj->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
+    obj->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
 //    mgmt->getSNMPManagement()->setReadCommunity( snmpCommunity->text().latin1() );
-    opt->setBool("use_mac_addr_filter", MACmatching->isChecked() );
+    opt->setBool("use_mac_addr_filter", m_dialog->MACmatching->isChecked() );
 
-    om->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
-
-    init=true;
-
-/* move to another lib if we have to */
-    if (! FWBTree::isSystem(obj) &&
-	libs->currentText() != QString(obj->getLibrary()->getName().c_str()))
-        om->moveObject(libs->currentText(), obj);
-
-    init=false;
+    mw->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
 
     //apply->setEnabled( false );
-    om->updateLastModifiedTimestampForAllFirewalls(obj);
+    mw->updateLastModifiedTimestampForAllFirewalls(obj);
+    modified = false;
 }
 
 void HostDialog::discardChanges()
