@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: HostDialog.h,v 1.6 2006/05/13 06:53:05 vkurland Exp $
+  $Id: HostDialog.h 553 2008-09-25 13:37:21Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,21 +27,27 @@
 #ifndef __HOSTDIALOG_H_
 #define __HOSTDIALOG_H_
 
-#include "config.h"
-#include <hostdialog_q.h>
+#include "../../config.h"
+#include <ui_hostdialog_q.h>
+#include <QWidget>
 
 #include "fwbuilder/FWObject.h"
 
+class ProjectPanel;
 
-class HostDialog : public HostDialog_q
+class HostDialog : public QWidget
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
     bool init;
+    bool modified;
+    Ui::HostDialog_q *m_dialog;
+    ProjectPanel *m_project;
 
  public:
-    HostDialog(QWidget *parent) : HostDialog_q(parent) { obj=NULL; }
+    HostDialog(ProjectPanel *project, QWidget *parent);
+    ~HostDialog();
     
 public slots:
     virtual void changed();
