@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ICMPServiceDialog.h,v 1.11 2006/05/13 06:53:05 vkurland Exp $
+  $Id: ICMPServiceDialog.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,21 +27,26 @@
 #ifndef __ICMPSERVICEDIALOG_H_
 #define __ICMPSERVICEDIALOG_H_
 
-#include "config.h"
-#include <icmpservicedialog_q.h>
+#include "../../config.h"
+#include <ui_icmpservicedialog_q.h>
+#include <QWidget>
 
 #include "fwbuilder/FWObject.h"
 
 
-class ICMPServiceDialog : public ICMPServiceDialog_q
+class ProjectPanel;
+class ICMPServiceDialog : public QWidget
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
     bool init;
+    Ui::ICMPServiceDialog_q *m_dialog;
     
+    ProjectPanel *m_project;
  public:
-    ICMPServiceDialog(QWidget *parent) : ICMPServiceDialog_q(parent) { obj=NULL; }
+     ICMPServiceDialog(ProjectPanel *project, QWidget *parent);
+     ~ICMPServiceDialog();
     
 public slots:
     virtual void changed();
