@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPTImporter.cpp 332 2008-07-06 20:11:03Z vadim $
+  $Id: IPTImporter.cpp 647 2008-11-14 07:03:21Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -34,6 +34,7 @@
 #include <ios>
 #include <iostream>
 #include <algorithm>
+#include <map>
 
 #ifndef _WIN32
 #  include <netdb.h>
@@ -419,7 +420,9 @@ void IPTImporter::pushPolicyRule()
     PolicyRule::Action action = PolicyRule::Unknown;
 
     if (target=="ACCEPT")   action = PolicyRule::Accept;
+
     if (target=="DROP")     action = PolicyRule::Deny;
+
     if (target=="REJECT")
     {
         action = PolicyRule::Reject;
@@ -428,8 +431,11 @@ void IPTImporter::pushPolicyRule()
         else
             ropt->setStr("action_on_reject", action_params["reject_with"]);
     }
+
     if (target=="QUEUE")    action = PolicyRule::Pipe;
+
     if (target=="CLASSIFY") action = PolicyRule::Classify;
+
     if (target=="LOG")
     {
         action = PolicyRule::Continue;
@@ -447,6 +453,7 @@ void IPTImporter::pushPolicyRule()
                 ropt->setStr("limit_burst", limit_burst);
         }
     }
+
     if (target=="ULOG")
     {
         action = PolicyRule::Continue;
@@ -454,26 +461,14 @@ void IPTImporter::pushPolicyRule()
         fwopt->setBool("use_ULOG", true);
         ropt->setStr("log_prefix", action_params["log_prefix"]);
     }
+
     if (target=="MARK")
     {
         action = PolicyRule::Tag;
         last_mark_rule = rule;
         std::string mark_code = action_params["set_mark"];
-        std::istringstream str(mark_code);
-        int m_code = 0;
-
-        // check if the code is in hex
-        if (mark_code.find("0x")==0)
-        {
-            char c;
-            str >> c >> c >> std::hex >> m_code;
-        } else
-        {
-            str >> m_code;
-        }
-        ropt->setInt("tagvalue", m_code);
-//        if (current_chain=="PREROUTING")
-//            ropt->setBool("ipt_mark_prerouting",true);
+        FWObject *tag_service = getTagService(mark_code);
+        rule->setTagObject(tag_service);
     }
     if (target=="CONNMARK")        action = PolicyRule::Continue;
 
@@ -508,54 +503,37 @@ void IPTImporter::pushPolicyRule()
             << "\n";
     }
 
+    if (target=="TOS")
+    {
+        // special-case target TOS, create custom action
+        // this is not very useful though because compiler can not properly
+        // put such rule in POSTROUTING chain.
+        action = PolicyRule::Custom;
+        ropt->setStr("custom_str",
+                     "-j TOS --set-tos " + action_params["set_tos"]);
+    }
+
     if (action==PolicyRule::Unknown)
     {
+        if (fwbdebug)
+            qDebug("Unknown target %s, creating branch", target.c_str());
+
         // unknown target, consider it a branch
-        // NOTE:
-        // as of fwbuilder v2.1, branch ruleset is a child object of
-        // PolicyRule. This means two different rules can not point at the same
-        // branch ruleset. This is unfortunate. To fix this we need
-        // to change XML DTD and API. Will do this in 3.0
-        // Meanwhile, have to check if branch ruleset with requested name
-        // already exists and change the name by adding suffix '1', '2' etc
-        // to make it different.
         //
         std::string branch_ruleset_name = target;
-        bool duplicate_branch = false;
-        int cntr = 0;
         action = PolicyRule::Branch;
-        UnidirectionalRuleSet *rs = NULL;
-        while (true)
-        {
-            rs = branch_rulesets[branch_ruleset_name];
-            if (rs==NULL)
-            {
-                rs = getUnidirRuleSet(branch_ruleset_name);
-                break;
-            } else
-            {
-                std::ostringstream ostr;
-                ostr << ++cntr;
-                branch_ruleset_name = target + ostr.str();
-                duplicate_branch = true;
-            }
-        }
+        UnidirectionalRuleSet *rs = branch_rulesets[branch_ruleset_name];
+        if (rs==NULL)
+            rs = getUnidirRuleSet(branch_ruleset_name);
 
-        current_rule->add(rs->ruleset);
-        ropt->setStr("branch_name", branch_ruleset_name);
-        getFirewallObject()->remove(rs->ruleset, false);
         branch_rulesets[branch_ruleset_name] = rs;
 
-        if (duplicate_branch)
-            markCurrentRuleBad(
-                std::string("Rule passes control to branch ") + target +
-                std::string(
-                    " which \n"
-                    "is already used by some rule prior to this one. \n"
-                    "fwbuilder 2.1 does not support multiple rules \n"
-                    "passing control to the same branch. This will \n"
-                    "be fixed in the next major release (v3.0)"));
+        //current_rule->add(rs->ruleset);
+        //ropt->setStr("branch_name", branch_ruleset_name);
+        //getFirewallObject()->remove(rs->ruleset, false);
 
+        rs->ruleset->setName(target);
+        rule->setBranch(rs->ruleset);
     }
 
     rule->setAction(action);
@@ -646,7 +624,7 @@ void IPTImporter::pushPolicyRule()
     if (!skip_rule)
     {
 /* we set "firewall_is_part_of_any_and_networks" to False */
-        rule_comment += std::string("\n") + "Chain " + current_chain + ". ";
+        rule_comment += "Chain " + current_chain + ". ";
 
         if (current_chain=="INPUT")
         {
@@ -666,18 +644,19 @@ void IPTImporter::pushPolicyRule()
 
         //  add rule to the right ruleset
         std::string ruleset_name = "";
-        if (current_chain=="INPUT" ||
-            current_chain=="OUTPUT" ||
-            current_chain=="FORWARD" ||
-            current_chain=="PREROUTING" ||
-            current_chain=="POSTROUTING") ruleset_name = "filter";
-        else
-            ruleset_name = current_chain;
-
-        UnidirectionalRuleSet *rs = getUnidirRuleSet(ruleset_name);
-        assert(rs!=NULL);
-        rs->ruleset->add(current_rule);
-
+        if (isStandardChain(current_chain))
+        {
+            RuleSet *policy = RuleSet::cast(
+                getFirewallObject()->getFirstByType(Policy::TYPENAME));
+            assert( policy!=NULL );
+            policy->add(current_rule);
+        } else
+        {
+            UnidirectionalRuleSet *rs = getUnidirRuleSet(current_chain);
+            assert(rs!=NULL);
+            rs->ruleset->add(current_rule);
+        }
+    
         rule->setDirection(PolicyRule::Both);
 
         if ( !i_intf.empty() && !o_intf.empty())
@@ -846,10 +825,10 @@ void IPTImporter::pushNATRule()
 
     current_rule->setComment(rule_comment);
 
-    UnidirectionalRuleSet *rs = getUnidirRuleSet("nat");
-    assert(rs!=NULL);
-    rs->ruleset->add(current_rule);
-
+    RuleSet *nat = RuleSet::cast(
+        getFirewallObject()->getFirstByType(NAT::TYPENAME));
+    assert( nat!=NULL );
+    nat->add(current_rule);
 
     current_rule = NULL;
     rule_comment = "";
@@ -876,45 +855,25 @@ Firewall* IPTImporter::finalize()
 
         fwopt->setBool("firewall_is_part_of_any_and_networks", false);
 
-        FWObject *policy =
-            getFirewallObject()->getFirstByType(Policy::TYPENAME);
-        assert( policy!=NULL );
-
-        UnidirectionalRuleSet *rs = getUnidirRuleSet("filter");
-        assert(rs!=NULL);
-
-        FWObject::iterator i;
-        for (i=rs->ruleset->begin(); i!=rs->ruleset->end(); ++i)
-        {
-            policy->add(*i);
-        }
-
-        // call clearChidren() not recursive because children objects
-        // of all rules should not be deleted
-        rs->ruleset->clearChildren(false);
-        getFirewallObject()->remove(rs->ruleset, false);
-        delete rs->ruleset;
-
-
-        FWObject *nat =
-            getFirewallObject()->getFirstByType(NAT::TYPENAME);
-        assert( nat!=NULL );
-
-        rs = getUnidirRuleSet("nat");
-        if (rs!=NULL)
-        {
-            for (i=rs->ruleset->begin(); i!=rs->ruleset->end(); ++i)
-            {
-                nat->add(*i);
-            }
-
-            rs->ruleset->clearChildren(false);
-            getFirewallObject()->remove(rs->ruleset, false);
-            delete rs->ruleset;
-        }
-
         return getFirewallObject();
     }
     else
         return NULL;
 }
+
+void IPTImporter::newUnidirRuleSet(const std::string &ruleset_name)
+{
+    if (!isStandardChain(ruleset_name))
+        Importer::newUnidirRuleSet(ruleset_name);
+}
+
+
+bool IPTImporter::isStandardChain(const std::string &ipt_chain)
+{
+    return (ipt_chain == "INPUT" ||
+            ipt_chain == "OUTPUT" ||
+            ipt_chain == "FORWARD" ||
+            ipt_chain == "PREROUTING" ||
+            ipt_chain == "POSTROUTING");
+}
+
