@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPv4Dialog.cpp,v 1.28 2007/04/14 00:18:43 vkurland Exp $
+  $Id: IPv4Dialog.cpp 373 2008-07-17 15:40:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,19 +17,19 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 #include "utils.h"
 
 #include "IPv4Dialog.h"
-#include "ObjectManipulator.h"
 
+#include "ProjectPanel.h"
 #include "fwbuilder/Library.h"
 #include "fwbuilder/IPv4.h"
 #include "fwbuilder/Interface.h"
@@ -43,28 +43,42 @@
 #include <qmessagebox.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
-#include <qdns.h>
+#include <qhostinfo.h>
 #include <qapplication.h>
 #include <qcursor.h>
+#include "FWBSettings.h"
 
 #include <iostream>
 
+#include "FWWindow.h"
+
 using namespace std;
 using namespace libfwbuilder;
 
+IPv4Dialog::IPv4Dialog(ProjectPanel *project, QWidget *parent) : QWidget(parent), m_project(project)
+{
+    m_dialog = new Ui::IPv4Dialog_q;
+    m_dialog->setupUi(this);
+
+    obj=NULL;
+}
+
+IPv4Dialog::~IPv4Dialog()
+{
+    delete m_dialog;
+}
+
 void IPv4Dialog::loadFWObject(FWObject *o)
 {
     obj=o;
     IPv4 *s = dynamic_cast<IPv4*>(obj);
     assert(s!=NULL);
-    
+
     dnsBusy=false;
     init=true;
 
-    fillLibraries(libs,obj);
-
-    obj_name->setText( QString::fromUtf8(s->getName().c_str()) );
-    comment->setText( QString::fromUtf8(s->getComment().c_str()) );
+    m_dialog->obj_name->setText( QString::fromUtf8(s->getName().c_str()) );
+    m_dialog->comment->setText( QString::fromUtf8(s->getComment().c_str()) );
 
 /*
  * if this is an address that belongs to an interface, we can't move
@@ -74,52 +88,47 @@ void IPv4Dialog::loadFWObject(FWObject *o)
     if ( Interface::isA( obj->getParent() ) )
     {
         showNetmask=true;
-        libs->setEnabled( false );
-        netmaskLabel->show();
-        netmask->show();
+        m_dialog->netmaskLabel->show();
+        m_dialog->netmask->show();
     } else
     {
         showNetmask=false;
-        libs->setEnabled( true );
-        netmaskLabel->hide();
-        netmask->hide();
+        m_dialog->netmaskLabel->hide();
+        m_dialog->netmask->hide();
     }
 
 /* catch exceptions separately so even if we have a bad address, we
  * still can show netmask */
     try
     {
-        address->setText( s->getAddress().toString().c_str() );
+        m_dialog->address->setText( s->getAddressPtr()->toString().c_str() );
     } catch (FWException &ex) {}
 
     try
     {
         if ( Interface::isA( obj->getParent() ) )
-            netmask->setText( s->getNetmask().toString().c_str() );
+            m_dialog->netmask->setText( s->getNetmaskPtr()->toString().c_str() );
     } catch (FWException &ex) {}
 
     //apply->setEnabled( false );
 
-    obj_name->setEnabled(!o->isReadOnly());
-    setDisabledPalette(obj_name);
+    m_dialog->obj_name->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->obj_name);
 
-    libs->setEnabled(!o->isReadOnly());
-    setDisabledPalette(libs);
+    m_dialog->address->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->address);
 
-    address->setEnabled(!o->isReadOnly());
-    setDisabledPalette(address);
+    m_dialog->netmask->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->netmask);
 
-    netmask->setEnabled(!o->isReadOnly());
-    setDisabledPalette(netmask);
-
-    comment->setReadOnly(o->isReadOnly());
-    setDisabledPalette(comment);
+    m_dialog->comment->setReadOnly(o->isReadOnly());
+    setDisabledPalette(m_dialog->comment);
 
 
 
     init=false;
 }
-    
+
 void IPv4Dialog::changed()
 {
     //apply->setEnabled( true );
@@ -131,18 +140,18 @@ void IPv4Dialog::validate(bool *res)
     *res=true;
 
     if (!isTreeReadWrite(this,obj)) { *res=false; return; }
-    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
+    if (!validateName(this,obj,m_dialog->obj_name->text())) { *res=false; return; }
 
     IPv4 *s = dynamic_cast<IPv4*>(obj);
     assert(s!=NULL);
     try
     {
-        IPAddress( address->text().latin1() );
+        InetAddr( m_dialog->address->text().toLatin1().constData() );
     } catch (FWException &ex)
     {
         *res=false;
         QMessageBox::critical(this, "Firewall Builder",
-                              tr("Illegal IP address '%1'").arg(address->text()),
+                              tr("Illegal IP address '%1'").arg(m_dialog->address->text()),
                               tr("&Continue"), 0, 0,
                               0 );
     }
@@ -151,22 +160,22 @@ void IPv4Dialog::validate(bool *res)
     {
         try
         {
-            Netmask( netmask->text().latin1() );
+            InetAddr( m_dialog->netmask->text().toLatin1().constData() );
         } catch (FWException &ex)
         {
             *res=false;
             QMessageBox::critical(this, "Firewall Builder",
-                                  tr("Illegal netmask '%1'").arg(netmask->text()),
+                                  tr("Illegal netmask '%1'").arg(m_dialog->netmask->text()),
                                   tr("&Continue"), 0, 0,
                                   0 );
         }
     }
 }
 
-void IPv4Dialog::isChanged(bool *res)
+void IPv4Dialog::isChanged(bool *)
 {
     //*res=(!init && apply->isEnabled());
-    
+
 }
 
 void IPv4Dialog::libChanged()
@@ -180,36 +189,29 @@ void IPv4Dialog::applyChanges()
     assert(s!=NULL);
 
     string oldname=obj->getName();
-    obj->setName( string(obj_name->text().utf8()) );
-    obj->setComment( string(comment->text().utf8()) );
+    obj->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
+    obj->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
 
     try
     {
-        s->setAddress( address->text().latin1() );
+        s->setAddress(
+            InetAddr(m_dialog->address->text().toLatin1().constData()) );
     } catch (FWException &ex) { }
 
     if ( showNetmask )
     {
         try
         {
-            s->setNetmask( netmask->text().latin1() );
+            s->setNetmask(
+                InetAddr(m_dialog->netmask->text().toLatin1().constData()) );
         } catch (FWException &ex) { }
     } else
-        s->setNetmask( "255.255.255.255" );
+        s->setNetmask(InetAddr());
 
-    om->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
-
-    init=true;
-
-/* move to another lib if we have to */
-    if ( ! Interface::isA( obj->getParent() ) &&
-         libs->currentText() != QString(obj->getLibrary()->getName().c_str()))
-        om->moveObject(libs->currentText(), obj);
-
-    init=false;
+    mw->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
 
     //apply->setEnabled( false );
-    om->updateLastModifiedTimestampForAllFirewalls(obj);
+    mw->updateLastModifiedTimestampForAllFirewalls(obj);
 }
 
 void IPv4Dialog::discardChanges()
@@ -224,18 +226,18 @@ void IPv4Dialog::DNSlookup()
 
     if (!dnsBusy)
     {
-        QString name = obj_name->text();
-        if (fwbdebug) qDebug("IPv4Dialog::DNSlookup()  name=%s", name.ascii());
+        QString name = m_dialog->obj_name->text();
+        if (fwbdebug) qDebug("IPv4Dialog::DNSlookup()  name=%s", name.toAscii().constData());
         dnsBusy=true;
         QApplication::setOverrideCursor( QCursor( Qt::WaitCursor) );
-        QString addr = getAddrByName(name);
+        QString addr = getAddrByName(name, AF_INET);
         QApplication::restoreOverrideCursor();
         dnsBusy=false;
         if (fwbdebug) qDebug("IPv4Dialog::DNSlookup()  done");
 
         if (! addr.isEmpty())
         {
-            address->setText( addr );
+            m_dialog->address->setText( addr );
             return;
         }
 
@@ -246,27 +248,27 @@ void IPv4Dialog::DNSlookup()
             name = host->getName().c_str();
 
             if (fwbdebug) qDebug("IPv4Dialog::DNSlookup()  name=%s",
-                                 name.ascii());
+                name.toAscii().constData());
             dnsBusy=true;
             QApplication::setOverrideCursor( QCursor( Qt::WaitCursor) );
-            QString addr = getAddrByName(name);
+            QString addr = getAddrByName(name, AF_INET);
             QApplication::restoreOverrideCursor();
             dnsBusy=false;
             if (fwbdebug) qDebug("IPv4Dialog::DNSlookup()  done");
             if ( ! addr.isEmpty())
             {
-                address->setText( addr );
+                m_dialog->address->setText( addr );
                 return;
             }
             QMessageBox::warning(
-                this,"Firewall Builder", 
+                this,"Firewall Builder",
                 tr("DNS lookup failed for both names of the address object '%1' and the name of the host '%2'.")
-                .arg(obj_name->text()).arg(name),
+                .arg(m_dialog->obj_name->text()).arg(name),
                 "&Continue", QString::null,QString::null, 0, 1 );
             return;
-        } 
+        }
         QMessageBox::warning(
-            this,"Firewall Builder", 
+            this,"Firewall Builder",
             tr("DNS lookup failed for name of the address object '%1'.")
             .arg(name),
             "&Continue", QString::null,QString::null, 0, 1 );
