@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPv4Dialog.h,v 1.11 2006/05/13 06:53:05 vkurland Exp $
+  $Id: IPv4Dialog.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,14 +27,16 @@
 #ifndef __IPV4DIALOG_H_
 #define __IPV4DIALOG_H_
 
-#include "config.h"
-#include <ipv4dialog_q.h>
+#include "../../config.h"
+#include <ui_ipv4dialog_q.h>
+#include <QWidget>
 
 #include "fwbuilder/FWObject.h"
 
 class QDns;
 
-class IPv4Dialog : public IPv4Dialog_q
+class ProjectPanel;
+class IPv4Dialog : public QWidget
 {
     Q_OBJECT
 
@@ -42,10 +44,13 @@ class IPv4Dialog : public IPv4Dialog_q
     bool init;
     bool showNetmask;
     bool dnsBusy;
-    QDns                   *lookup;
+    //QDns                   *lookup;
+    Ui::IPv4Dialog_q       *m_dialog;
+    ProjectPanel *m_project;
 
  public:
-    IPv4Dialog(QWidget *parent) : IPv4Dialog_q(parent) { obj=NULL; }
+    IPv4Dialog(ProjectPanel *project, QWidget *parent);
+    ~IPv4Dialog();
     virtual void closeEvent(QCloseEvent *e);
     
 public slots:
