@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: Importer.cpp 332 2008-07-06 20:11:03Z vadim $
+  $Id: Importer.cpp 647 2008-11-14 07:03:21Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -272,9 +272,11 @@ UnidirectionalRuleSet* Importer::checkUnidirRuleSet(
     return all_rulesets[ruleset_name];
 }
 
-UnidirectionalRuleSet* Importer::getUnidirRuleSet(
-    const std::string &ruleset_name)
+UnidirectionalRuleSet* Importer::getUnidirRuleSet(const std::string &ruleset_name)
 {
+    if (fwbdebug)
+        qDebug("Importer::getUnidirRuleSet %s", ruleset_name.c_str());
+
     UnidirectionalRuleSet *rs = all_rulesets[ruleset_name];
     if (rs==NULL)
     {
@@ -288,6 +290,8 @@ UnidirectionalRuleSet* Importer::getUnidirRuleSet(
         else
             rs->ruleset = RuleSet::cast(dbroot->create(Policy::TYPENAME));
 
+        rs->ruleset->setName(ruleset_name);
+
         all_rulesets[ruleset_name] = rs;
 
         // add this ruleset to the firewall temporarily
@@ -311,6 +315,10 @@ void Importer::setInterfaceAndDirectionForRuleSet(const std::string &ruleset_nam
                                                   const std::string &_intf_name,
                                                   const std::string &_dir)
 {
+    if (fwbdebug)
+        qDebug("Importer::setInterfaceAndDirectionForRuleSet %s",
+               ruleset_name.c_str());
+
     UnidirectionalRuleSet *rs = getUnidirRuleSet(ruleset_name);
     std::string intf;
     if ( !_intf_name.empty()) intf = _intf_name;
@@ -334,8 +342,9 @@ void Importer::setInterfaceAndDirectionForRuleSet(const std::string &ruleset_nam
 
 void Importer::newUnidirRuleSet(const std::string &ruleset_name)
 {
+    if (fwbdebug) qDebug("Importer::newUnidirRuleSet %s",
+                         ruleset_name.c_str());
     current_ruleset = getUnidirRuleSet(ruleset_name);  // creates if new
-
     *logger << "Ruleset: " << ruleset_name << "\n";
 }
 
@@ -672,7 +681,8 @@ FWObject* Importer::getTagService(const std::string &tagcode)
     cstr << "Imported from " << getFirewallObject()->getName() << "\n"
          << "mark " << tagcode;
 
-    if (all_objects.count(sstr.str())!=0) return TagService::cast(all_objects[sstr.str()]);
+    if (all_objects.count(sstr.str())!=0)
+        return TagService::cast(all_objects[sstr.str()]);
 
     s = TagService::cast(createObject(TagService::TYPENAME, nstr.str()));
     assert(s!=NULL);
