@@ -2,11 +2,11 @@
 
                           Firewall Builder
 
-                 Copyright (C) 2003 NetCitadel, LLC
+                 Copyright (C) 2008 NetCitadel, LLC
 
-  Author:  Illiya Yalovoy <yalovoy@gmail.com>
+  Author:  alek@codeminders.com
 
-  $Id: InstallFirewallViewItem.h,v 1.1 2006/04/08 06:28:14 vkurland Exp $
+  $Id: InstallFirewallViewItem.h 332 2008-07-06 20:11:03Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -23,12 +23,10 @@
 
 */
 
-
-
 #ifndef  INSTALLFIREWALLVIEWITEM_H
 #define  INSTALLFIREWALLVIEWITEM_H
 
-#include <qlistview.h>
+#include <qtreewidget.h>
 
 #include <string>
 #include <map>
@@ -37,18 +35,15 @@ namespace libfwbuilder {
     class FWObject;
 }
 
-class QListViewItem;
-
-class InstallFirewallViewItem : public QListViewItem {
-
+class InstallFirewallViewItem : public QTreeWidgetItem
+{
+public:
+    InstallFirewallViewItem(QTreeWidget * parent,
+                            const QString & text, bool slt );
     
- public:
-    
-    InstallFirewallViewItem(QListView * parent, const QString & text, bool slt ) 
-        : QListViewItem(parent,text) {showLastTimes=slt; }
-
     bool showLastTimes;
-    void paintCell ( QPainter * p, const QColorGroup & cg, int column, int width, int align );
+    QVariant data (int column, int role) const;
 };
 
+
 #endif
