@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: InterfaceDialog.h,v 1.10 2006/05/13 06:53:05 vkurland Exp $
+  $Id: InterfaceDialog.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,25 +27,36 @@
 #ifndef __INTERFACEDIALOG_H_
 #define __INTERFACEDIALOG_H_
 
-#include "config.h"
-#include <interfacedialog_q.h>
+#include "../../config.h"
+#include <ui_interfacedialog_q.h>
+#include <QWidget>
 
 #include "fwbuilder/FWObject.h"
 
 #include <qmap.h>
 #include <qstring.h>
 
-class InterfaceDialog : public InterfaceDialog_q
+class ProjectPanel;
+class InterfaceDialog : public QWidget
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
     bool init;
-    QMap<QString,int> netzoneObjectIDs;
-    QMap<int,QString> netzoneObjectNos;
+
+    // netzoneObjectIDs : key - object id, value - number in the list
+    QMap<int,int> netzoneObjectIDs;
+
+    // netzoneObjectNos : key - number in the list, value - obj id
+    QMap<int,int> netzoneObjectNos;
+
+    Ui::InterfaceDialog_q *m_dialog;
+    ProjectPanel *m_project;
 
  public:
-    InterfaceDialog(QWidget *parent);
+    InterfaceDialog(ProjectPanel *project, QWidget *parent);
+    ~InterfaceDialog();
+    
     virtual void closeEvent(QCloseEvent *e);
     
 public slots:
