@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectIconViewItem.h,v 1.4 2005/09/07 16:40:50 vkurland Exp $
+  $Id: ObjectIconViewItem.h 304 2008-07-03 02:19:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,7 +28,7 @@
 #ifndef  __OBJECTICONVIEWITEM_H
 #define  __OBJECTICONVIEWITEM_H
 
-#include <qiconview.h>
+#include <qlistwidget.h>
 
 #include <qstring.h>
 #include <string>
@@ -38,28 +38,31 @@ namespace libfwbuilder {
     class FWObject;
 }
 
-class ObjectIconViewItem : public QIconViewItem {
+class ObjectIconViewItem : public QListWidgetItem {
 
     libfwbuilder::FWObject  *objptr;
     QMap<QString, QString>   props;
-    std::string                 ID;  
+    int                      ID;  
     
  public:
 
-    ObjectIconViewItem(QIconView *parent) : QIconViewItem(parent) {
+    ObjectIconViewItem(QListWidget *parent) : QListWidgetItem(parent) {
         objptr=NULL;
-        setDropEnabled(false);
-        ID="";
+//        setDropEnabled(false);
+        ID=-1;
     }
 
-    ObjectIconViewItem(QIconView *parent, const QString &text, const QPixmap &icon ) : QIconViewItem(parent,text,icon) {
+    ObjectIconViewItem(QListWidget *parent, const QString &text, const QPixmap &icon ) : QListWidgetItem(parent) 
+    {
         objptr=NULL;
-        setDropEnabled(false);
-        ID="";
+        setText(text);
+        setIcon(QIcon(icon));
+//        setDropEnabled(false);
+        ID=-1;
     }
 
     libfwbuilder::FWObject *getFWObject() { return mw->db()->getById(ID,true); }
-    std::string getFWObjectID() {return ID; }
+    int getFWObjectID() {return ID; }
     void setFWObject(libfwbuilder::FWObject *obj) {ID=obj->getId(); }
 
     QString getProperty(const QString &name) { return props[name]; }
