@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectManipulator.h,v 1.58 2007/01/08 02:11:48 vkurland Exp $
+  $Id: ObjectManipulator.h 521 2008-09-10 06:15:27Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,14 +27,16 @@
 #ifndef  __OBJECTMANIPULATOR_H_
 #define  __OBJECTMANIPULATOR_H_
 
-#include "config.h"
+
+#include "../../config.h"
 #include "global.h"
 
 #include <qdialog.h>
-#include <qlistview.h>
+#include <qtreewidget.h>
 #include <qtooltip.h>
+#include <QMenu>
 
-#include "objectmanipulator_q.h"
+#include <ui_objectmanipulator_q.h>
 
 #include "fwbuilder/FWObject.h"
 #include "fwbuilder/FWObjectDatabase.h"
@@ -46,39 +48,42 @@
 class ObjectTreeView;
 class ObjectTreeViewItem;
 class QComboBox;
-class QPopupMenu;
+class QMenu;
+class ProjectPanel;
+
 namespace libfwbuilder 
 {
     class Firewall;
     class Library;
 }
+
 class HistoryItem {
     ObjectTreeViewItem *itm;
-    QString         objId;
+    int                 objId;
 
  public:
-    HistoryItem(ObjectTreeViewItem *oi,const QString &id) { itm=oi; objId=id; }
+    HistoryItem(ObjectTreeViewItem *oi, int id) { itm=oi; objId=id; }
     ~HistoryItem();
     ObjectTreeViewItem* item() { return itm;   }
-    QString         id()   { return objId; }
+    int  id()   { return objId; }
 };
 
-class ObjToolTip : public QToolTip {
+/*class ObjToolTip : public QToolTip {
 
     ObjectTreeView *otv;
  public:
     ObjToolTip(ObjectTreeView *widget);
     virtual ~ObjToolTip() {}
     virtual void maybeTip(const QPoint &p);
-};
+};*/
 
-class ObjectManipulator : public ObjectManipulator_q {
+class ObjectManipulator : public QWidget/*ObjectManipulator_q*/ {
 
     Q_OBJECT
 
     std::vector<libfwbuilder::FWObject*>          idxToLibs;
-    std::vector<QListView*>                       idxToTrees;
-    
+    std::vector<QTreeWidget*>                     idxToTrees;
+    QSet<int> ids ;     
     std::stack<HistoryItem>                       history;
     int cacheHits;
 
@@ -94,9 +99,10 @@ class ObjectManipulator : public ObjectManipulator_q {
  * quickly locate given object in the tree and open it
  */
     std::map<libfwbuilder::FWObject*, ObjectTreeViewItem*> allItems;
-
     
-    ObjectTreeViewItem* insertObject( ObjectTreeViewItem *itm,libfwbuilder::FWObject *obj );
+
+    ObjectTreeViewItem* insertObject( ObjectTreeViewItem *itm,
+                                      libfwbuilder::FWObject *obj );
     void insertSubtree( ObjectTreeViewItem *itm,libfwbuilder::FWObject *obj );
 
     void removeObjectFromTreeView(libfwbuilder::FWObject *obj );
@@ -107,7 +113,7 @@ class ObjectManipulator : public ObjectManipulator_q {
     void showObjectInTree(ObjectTreeViewItem *otvi);
 
     int  getIdxForLib(libfwbuilder::FWObject*);
-    void addLib( libfwbuilder::FWObject *lib, QListView* otv=NULL);
+    void addLib( libfwbuilder::FWObject *lib, QTreeWidget* otv=NULL);
     void removeLib(libfwbuilder::FWObject*);
     void removeLib(int idx);
     void updateCreateObjectMenu(libfwbuilder::FWObject* lib);
@@ -117,16 +123,23 @@ class ObjectManipulator : public ObjectManipulator_q {
                                                  const QString &objType,
                                                  const QString &objName,
                                                  libfwbuilder::FWObject *copyFrom=NULL);
+
     void autorename(libfwbuilder::FWObject *obj,bool ask=true);
     void extractFirewallsFromGroup(
             libfwbuilder::ObjectGroup *gr,
             std::set<libfwbuilder::Firewall*> &fo);
 
+    int fixReferences(libfwbuilder::FWObject *obj, std::map<int,int> &map_ids);
+    
+    ProjectPanel *m_project;
+
+    
 public slots:
      virtual void libChanged(int l);
      virtual void switchingTrees(QWidget* w);
+     virtual void currentTreePageChanged(int i);
 
-     void selectionChanged();
+     void selectionChanged(QTreeWidgetItem *cur);
 
      void info();
 
@@ -143,9 +156,14 @@ public slots:
       */
      bool editObject(libfwbuilder::FWObject *obj);
 
+     /*
+      * forget about currently opened object; close editor panel if it is open
+      */
+     void closeObject();
+
      void editSelectedObject();
      
-     void contextMenu(QListViewItem *item, const QPoint &pos, int col);
+     void contextMenuRequested(const QPoint &pos);
 
      
      libfwbuilder::FWObject* createObject(const QString &objType,
@@ -157,14 +175,18 @@ public slots:
                                           const QString &objName,
                                           libfwbuilder::FWObject *copyFrom=NULL);
      
+
      void newLibrary();
      void newObject();
      void newFirewall();
      void newHost();
      void newInterface();
      void newNetwork();
+     void newNetworkIPv6(); 
      void newAddress();
+     void newAddressIPv6();
      void newInterfaceAddress();
+     void newInterfaceAddressIPv6();
      void newPhysicalAddress();
      void newAddressRange();
      void newObjectGroup();
@@ -174,16 +196,16 @@ public slots:
      void newCustom();
      void newIP();
      void newICMP();
+     void newICMP6();
      void newTCP();
      void newUDP();
      void newTagService();
+     void newUserService();
      void newServiceGroup();
      
      void newInterval();
-
-     void duplicateObj(int libid);
-     void duplicateObjUnderSameParent();
-     void moveObj(int libid);
+     void newPolicyRuleSet ();
+     void newNATRuleSet ();
      void copyObj();
      void cutObj();
      void pasteObj();
@@ -192,9 +214,12 @@ public slots:
      void compile();
      void install();
 
+     void duplicateObj(QAction*);
+     void moveObj(QAction*);
+     
      void groupObjects();
      
-     void openObject(QListViewItem *otvi);
+     void openObject(QTreeWidgetItem *otvi);
      void openObject(libfwbuilder::FWObject *obj);
      void restoreSelection(bool same_widget);
 
@@ -208,143 +233,160 @@ public slots:
      virtual void findWhereUsedSlot();
 
      
- public:
-    void filterFirewallsFromSelection(
-            std::vector<libfwbuilder::FWObject*> &so,
-            std::set<libfwbuilder::Firewall*> &fo);
-    void autorename(libfwbuilder::FWObject *obj,
-                    const std::string &objtype,
-                    const std::string &namesuffix);
+public:
+
+     void libChangedById(int id);
+     void changeFirstNotSystemLib();
+     std::vector<QTreeWidget*> getTreeWidgets() { return idxToTrees;};
+     Ui::ObjectManipulator_q *m_objectManipulator;
+     void filterFirewallsFromSelection(
+         std::vector<libfwbuilder::FWObject*> &so,
+         std::set<libfwbuilder::Firewall*> &fo);
+     void autorename(libfwbuilder::FWObject *obj,
+                     const std::string &objtype,
+                     const std::string &namesuffix);
     
-    ObjectManipulator( QWidget *parent );
-    void loadObjects();
-    void loadObjects(libfwbuilder::FWObjectDatabase *db);
-    void clearObjects();
+     ObjectManipulator( QWidget *parent);
+     ~ObjectManipulator();
+
+     void loadObjects();
+     void clearObjects();
     
-    bool validateDialog();
-    void invalidateDialog();
+     bool validateDialog();
+     void invalidateDialog();
 
-    void openObject(libfwbuilder::FWObject *obj, bool register_in_history);
-    void openObject(ObjectTreeViewItem *otvi,    bool register_in_history);
+     void reopenCurrentItemParent();
 
-    libfwbuilder::FWObject* duplicateObject(libfwbuilder::FWObject *target,
-                                            libfwbuilder::FWObject *obj,
-                                            const QString &name = QString::null,
-                                            bool  askForAutorename=true);
-    void moveObject(libfwbuilder::FWObject *target,
-                    libfwbuilder::FWObject *obj);
+     void openObject(libfwbuilder::FWObject *obj, bool register_in_history);
+     void openObject(ObjectTreeViewItem *otvi,    bool register_in_history);
 
-    void moveObject(const QString &targetLibName,
-                    libfwbuilder::FWObject *obj);
+     libfwbuilder::FWObject* duplicateObject(libfwbuilder::FWObject *target,
+                                             libfwbuilder::FWObject *obj,
+                                             const QString &name = QString::null,
+                                             bool  askForAutorename=true);
+
+     libfwbuilder::FWObject* duplicateWithDependencies(
+         libfwbuilder::FWObject *target, libfwbuilder::FWObject *obj);
+     
+     void moveObject(libfwbuilder::FWObject *target,
+                     libfwbuilder::FWObject *obj);
+
+     void moveObject(const QString &targetLibName, libfwbuilder::FWObject *obj);
     
-    libfwbuilder::FWObject* getOpened() { return currentObj; }
+     libfwbuilder::FWObject* getOpened() { return currentObj; }
 
-    void updateLibColor(libfwbuilder::FWObject *lib);
-    void updateLibName(libfwbuilder::FWObject *lib);
+     void updateLibColor(libfwbuilder::FWObject *lib);
+     void updateLibName(libfwbuilder::FWObject *lib);
 
-    void updateObjName(libfwbuilder::FWObject *obj,
-                       const QString &oldName,
-                       bool  askForAutorename=true);
-    void updateObjName(libfwbuilder::FWObject *obj,
-                       const QString &oldName,
-                       const QString &oldLabel,
-                       bool  askForAutorename=true);
+     void updateObjName(libfwbuilder::FWObject *obj,
+                        const QString &oldName,
+                        bool  askForAutorename=true);
+     void updateObjName(libfwbuilder::FWObject *obj,
+                        const QString &oldName,
+                        const QString &oldLabel,
+                        bool  askForAutorename=true);
     
-    ObjectTreeView* getCurrentObjectTree();
-    libfwbuilder::FWObject* getSelectedObject();
+     ObjectTreeView* getCurrentObjectTree();
+     libfwbuilder::FWObject* getSelectedObject();
 
-    /**
-     *  this method opens given library in the tree
-     */
-    void openLib(libfwbuilder::FWObject *lib);
+     /**
+      *  this method opens given library in the tree
+      */
+     void openLib(libfwbuilder::FWObject *lib);
 
-    /**
-     * returns pointer at a library that is currently opened in the tree
-     */
-    libfwbuilder::FWObject*  getCurrentLib();
+     /**
+      * returns pointer at a library that is currently opened in the tree
+      */
+     libfwbuilder::FWObject*  getCurrentLib();
 
-    /**
-     *  this method makes sure the system library is NOT opened in the
-     *  tree. If it is, it switches to the 'User' library. If one of
-     *  the user's libraries is already opened, it does nothing.
-     */
-    void closeSystemLib();
+     /**
+      *  this method makes sure the system library is NOT opened in the
+      *  tree. If it is, it switches to the 'User' library. If one of
+      *  the user's libraries is already opened, it does nothing.
+      */
+     void closeSystemLib();
 
-    libfwbuilder::FWObject* pasteTo(libfwbuilder::FWObject *target,
-                                    libfwbuilder::FWObject *obj,
-                                    bool openobj=true,
-                                    bool validateOnly=false);
-    void delObj(libfwbuilder::FWObject *obj,bool openobj=true);
+     libfwbuilder::FWObject* pasteTo(libfwbuilder::FWObject *target,
+                                     libfwbuilder::FWObject *obj,
+                                     bool renew_id);
 
-    /**
-     * select whatever object is current in the tree (used to restore
-     * selected state of the tree item after it was unselected)
-     */
-    void select();
+     bool validateForPaste(libfwbuilder::FWObject *target,
+                           libfwbuilder::FWObject *obj);
 
-    /**
-     * unselect whatever object is currently selected
-     */
-    void unselect();
+     void delObj(libfwbuilder::FWObject *obj,bool openobj=true);
 
-    /**
-     * returns true if anything is selected in the tree
-     */
-    bool isSelected();
+     /**
+      * select whatever object is current in the tree (used to restore
+      * selected state of the tree item after it was unselected)
+      */
+     void select();
 
-    /**
-     * controls whether "Deleted Objects" library is shown
-     */
-    void showDeletedObjects(bool f);
+     /**
+      * unselect whatever object is currently selected
+      */
+     void unselect();
+
+     /**
+      * returns true if anything is selected in the tree
+      */
+     bool isSelected();
+
+     /**
+      * controls whether "Deleted Objects" library is shown
+      */
+     void showDeletedObjects(bool f);
 
 
-    /**
-     * get boolean flags that describe state of the menu items.
-     * Can be used for both pop-up context menu and the main menu.
-     */ 
-    void getMenuState(bool haveMoveTargets,
-                      bool &dupMenuItem,
-                      bool &moveMenuItem,
-                      bool &copyMenuItem,
-                      bool &pasteMenuItem,
-                      bool &delMenuItem,
-                      bool &newMenuItem,
-                      bool &inDeletedObjects);
+     /**
+      * get boolean flags that describe state of the menu items.
+      * Can be used for both pop-up context menu and the main menu.
+      */ 
+     void getMenuState(bool haveMoveTargets,
+                       bool &dupMenuItem,
+                       bool &moveMenuItem,
+                       bool &copyMenuItem,
+                       bool &pasteMenuItem,
+                       bool &delMenuItem,
+                       bool &newMenuItem,
+                       bool &inDeletedObjects);
     
-    void updateLastModifiedTimestampForOneFirewall(libfwbuilder::FWObject *o);
-    void updateLastModifiedTimestampForAllFirewalls(libfwbuilder::FWObject *o);   
-    void updateLastInstalledTimestamp(libfwbuilder::FWObject *o);
-    void updateLastCompiledTimestamp(libfwbuilder::FWObject *o);
+     void updateLastModifiedTimestampForOneFirewall(libfwbuilder::FWObject *o);
+     void updateLastModifiedTimestampForAllFirewalls(libfwbuilder::FWObject *o);
+     void updateLastInstalledTimestamp(libfwbuilder::FWObject *o);
+     void updateLastCompiledTimestamp(libfwbuilder::FWObject *o);
     
-    std::list<libfwbuilder::Firewall * > findFirewallsForObject(libfwbuilder::FWObject *o);
-    void findAllFirewalls (std::list<libfwbuilder::Firewall *> &fws);
+     std::list<libfwbuilder::Firewall*> findFirewallsForObject(
+         libfwbuilder::FWObject *o);
+     void findAllFirewalls (std::list<libfwbuilder::Firewall *> &fws);
 
-    
- signals:
+     void loadExpandedTreeItems();
+     void saveExpandedTreeItems();
+
+signals:
 /**
  * the dialog class should have a slot that can load object's data
  * into dialog elements when ObjectManipulator emits this signal
  */
-    void loadObject_sign(libfwbuilder::FWObject *);
+     void loadObject_sign(libfwbuilder::FWObject *);
 
 /**
  * the dialog class should have a slot that can verify data entered by
  * user in the dialog elements when ObjectManipulator emits this
  * signal. The validation result is returned in variable "bool *res"
  */
-    void validate_sign(bool *res);
+     void validate_sign(bool *res);
 
 /**
  * the dialog class should have a slot that can verify if the data in
  * dialog has been edited.
  */
-    void isChanged_sign(bool *res);
+     void isChanged_sign(bool *res);
 
 /**
  * the dialog class should have a slot that applies changes made by
  * the user and saves data in the object.
  */
-    void applyChanges_sign();
+     void applyChanges_sign();
 
 };
 
