@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: PhysicalAddressDialog.h,v 1.6 2006/05/13 06:53:05 vkurland Exp $
+  $Id: PhysicalAddressDialog.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,22 +27,27 @@
 #ifndef __PHYSICALADDRESSDIALOG_H_
 #define __PHYSICALADDRESSDIALOG_H_
 
-#include "config.h"
-#include <physaddressdialog_q.h>
+#include "../../config.h"
+#include <ui_physaddressdialog_q.h>
+#include <QWidget>
 
 #include "fwbuilder/FWObject.h"
 
+class ProjectPanel;
 
-class PhysicalAddressDialog : public PhysAddressDialog_q
+class PhysicalAddressDialog : public QWidget
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
     bool init;
     bool showNetmask;
+    Ui::PhysAddressDialog_q *m_dialog;
+    ProjectPanel *m_project;
     
  public:
-    PhysicalAddressDialog(QWidget *parent) : PhysAddressDialog_q(parent) { obj=NULL; }
+     PhysicalAddressDialog(ProjectPanel *project, QWidget *parent);
+     ~PhysicalAddressDialog();
     
 public slots:
     virtual void changed();
