@@ -7,7 +7,7 @@
   Author:  alek@codeminders.com
            refactoring and bugfixes: vadim@fwbuilder.org
 
-  $Id: ProjectPanel.cpp 558 2008-09-30 09:53:45Z vadim $
+  $Id: ProjectPanel.cpp 649 2008-11-17 16:45:14Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -110,8 +110,15 @@ void ProjectPanel::initMain(FWWindow *main)
             this,SLOT(splitterMoved(int,int)));
 
     m_panel->auxiliaryPanel->hide();
-    initOE();
-    initFD();
+
+    oe  = new ObjectEditor((QWidget*)m_panel->objectEditorStack, this);
+    oe->setCloseButton(m_panel->closeObjectEditorButton);
+    oe->setApplyButton(m_panel->applyObjectEditorButton);
+    closeEditorPanel();
+    oe->hide();
+
+    fd  = new findDialog(this, this);
+    fd->hide();
 }
 
 ProjectPanel::ProjectPanel(QWidget *parent): 
@@ -157,8 +164,8 @@ ProjectPanel::~ProjectPanel()
 
 void ProjectPanel::info(FWObject *obj, bool forced)
 {
-    if (obj==NULL)
-        return ;
+    if (obj==NULL) return ;
+
     if (st->getInfoStyle()!=0 && (shownInInfo!=obj || forced))
     {
         m_panel->oi->clear();
@@ -166,16 +173,18 @@ void ProjectPanel::info(FWObject *obj, bool forced)
         QString s="";
         if (st->getInfoStyle()==2)
         {
-            s=FWObjectPropertiesFactory::getObjectPropertiesDetailed(obj)
-                + QString("<hr height=\"0\">");
+            s = FWObjectPropertiesFactory::getObjectPropertiesDetailed(obj) +
+                QString("<hr height=\"0\">");
             m_panel->oi->setText(s);
         }
 
-        s=QString::fromUtf8(obj->getComment().c_str());
+        s = QString::fromUtf8(obj->getComment().c_str());
         m_panel->oi->append(s);
         m_panel->oi->moveCursor(QTextCursor::Start);
 
         shownInInfo = obj;
+
+        m_panel->oi->repaint();
     }
 
 //    unselectRules();
@@ -272,22 +281,6 @@ void ProjectPanel::clearObjects()
     m_panel->om->clearObjects();
 }
 
-
-
-void ProjectPanel::initOE()
-{
-    oe  = new ObjectEditor((QWidget*)m_panel->objectEditorStack, this);
-    oe->setCloseButton(m_panel->closeObjectEditorButton);
-    oe->setApplyButton(m_panel->applyObjectEditorButton);
-    oe->hide();
-}
-
-void ProjectPanel::initFD()
-{
-    fd  = new findDialog(this, this);
-    fd->hide();
-}
-
 void ProjectPanel::clearFirewallTabs()
 {
     if (fwbdebug) qDebug("ProjectPanel::clearFirewallTabs");
@@ -427,13 +420,7 @@ void ProjectPanel::reopenFirewall()
         m_panel->ruleSets->removeWidget(m_panel->ruleSets->widget(i));
 
     m_panel->rulesetname->setTextFormat(Qt::RichText);
-    QString name = "<B>";
-    FWObject * p = visibleRuleSet->getParent();
-    name += p->getName().c_str();
-    name += " / ";
-    name += visibleRuleSet->getName().c_str();
-    name += "</B>";
-    m_panel->rulesetname->setText(name );
+    updateFirewallName();
 
     last_modified = db()->getTimeLastModified();
     if (fwbdebug)
@@ -485,16 +472,16 @@ int  ProjectPanel::findFirewallInList(FWObject *f)
     return -1;
 }
 
-void ProjectPanel::updateFirewallName(FWObject *, const QString &)
+void ProjectPanel::updateFirewallName()
 {
     if (visibleRuleSet==NULL)
         return ;
 
     QString name = "<B>";
     FWObject * p = visibleRuleSet->getParent();
-    name += p->getName().c_str();
+    name += QString::fromUtf8(p->getName().c_str());
     name += " / ";
-    name += visibleRuleSet->getName().c_str();
+    name += QString::fromUtf8(visibleRuleSet->getName().c_str());
     name += "</B>";
     m_panel->rulesetname->setText(name );
 }
@@ -861,11 +848,14 @@ bool ProjectPanel::isEditorModified()
 
 void ProjectPanel::showEditor()
 {
+    openEditorPanel();
+    m_panel->objectEditorStack->setCurrentIndex(oe->getCurrentDialogIndex());
     oe->show();
 }
 
 void ProjectPanel::hideEditor()
 {
+    closeEditorPanel();
     oe->hide();
 }
 
@@ -876,12 +866,20 @@ void ProjectPanel::closeEditor()
 
 void ProjectPanel::openEditor(FWObject *o)
 {
+    QSize old_size = m_panel->objectEditorStack->size();
     oe->open(o);
+    m_panel->objectEditorStack->setCurrentIndex(oe->getCurrentDialogIndex());
+    m_panel->objectEditorFrame->show();
+    m_panel->objectEditorStack->resize(old_size);
 }
 
 void ProjectPanel::openOptEditor(FWObject *o, ObjectEditor::OptType t)
 {
+    QSize old_size = m_panel->objectEditorStack->size();
     oe->openOpt(o, t);
+    m_panel->objectEditorStack->setCurrentIndex(oe->getCurrentDialogIndex());
+    m_panel->objectEditorFrame->show();
+    m_panel->objectEditorStack->resize(old_size);
 }
 
 void ProjectPanel::blankEditor()
@@ -991,7 +989,7 @@ void ProjectPanel::startupLoad()
     if (fwbdebug)
         qDebug("ProjectPanel::startupLoad: startup: load everything.");
 
-    load(NULL);
+    loadStandardObjects();
 
     QString id = st->getStr("UI/visibleFirewall");
     int i_id = FWObjectDatabase::getIntId(id.toLatin1().constData());
@@ -1064,7 +1062,8 @@ void ProjectPanel::closeEditorPanel()
 
 void ProjectPanel::openEditorPanel()
 {
-    m_panel->objectEditorFrame->adjustSize();
+//    m_panel->objectEditorStack->adjustSize();
+//    m_panel->objectEditorFrame->adjustSize();
     m_panel->objectEditorFrame->show();
 
 }
@@ -1216,9 +1215,27 @@ bool ProjectPanel::getPasteMenuState(const QString &objPath)
     return objectTreeFormat->getPasteMenuState(objPath);
 }
 
-bool ProjectPanel::getDeleteMenuState(const QString &objPath)
+bool ProjectPanel::getDeleteMenuState(FWObject *obj)
 {
-    return objectTreeFormat->getDeleteMenuState(objPath);
+    QString objPath = obj->getPath(true).c_str();
+    bool del_menu_item_state = objectTreeFormat->getDeleteMenuState(objPath);
+
+    // can't delete last policy, nat and routing child objects
+    // also can't delete "top" policy ruleset
+    if (del_menu_item_state && RuleSet::cast(obj))
+    {
+        if (dynamic_cast<RuleSet*>(obj)->isTop()) del_menu_item_state = false;
+        else
+        {
+            FWObject *fw = obj->getParent();
+            // fw can be NULL if this ruleset is in the Deleted objects
+            // library
+            if (fw==NULL) return del_menu_item_state;
+            list<FWObject*> child_objects = fw->getByType(obj->getTypeName());
+            if (child_objects.size()==1) del_menu_item_state = false;
+        }
+    }
+    return del_menu_item_state;
 }
 
 FWObject* ProjectPanel::createNewLibrary(FWObjectDatabase *db)
