@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland vadim@fwbuilder.org
 
-  $Id: RCSFilePreview.cpp 544 2008-09-17 03:47:58Z vadim $
+  $Id: RCSFilePreview.cpp 634 2008-10-25 18:56:14Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -123,7 +123,7 @@ void RCSFilePreview::selectedRevision(QTreeWidgetItem *itm)
 bool RCSFilePreview::showFileRLog( const QString &filename )
 {
     if (fwbdebug) qDebug("RCSFilePreview::showFileRLog filename=%s rcs=%p",
-                         filename.toAscii().constData(),rcs);
+                         filename.toLocal8Bit().constData(),rcs);
 
     m_widget->RCSTreeView->clear();
 
