@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: RuleSetView.h 557 2008-09-29 13:22:09Z vadim $
+  $Id: RuleSetView.h 635 2008-10-26 23:27:08Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -53,7 +53,6 @@ namespace libfwbuilder {
     class Rule;
     class RuleSet;
     class Policy;
-    class InterfacePolicy;
     class NAT;
     class Routing;
     class RuleElement;
@@ -238,6 +237,7 @@ public slots:
 public:
      
      libfwbuilder::RuleSet *ruleset;
+     QMap<QString, QString> groupColors;
      QMap<QString,int> rulesInGroup;
      QItemSelectionRange itemSelectionRange;
 
@@ -247,7 +247,8 @@ public:
                             const QRect &cr, bool selected, const QPalette &cg);
      void drawRuleGroupHandle(QPainter *p,int row, int col,
                             const QRect &cr, bool selected, const QPalette &cg);
-
+     QString getGroupColorForRule(libfwbuilder::Rule *rule);
+    
      void setName(const QString &qs);
      void setCurrentCell(const int row, const int col);
      void changeCurrentCell(const int row, const int col,
@@ -532,22 +533,6 @@ class PolicyView : public RuleSetView
     
 };
 
-class InterfacePolicyView : public RuleSetView
-{
-    virtual libfwbuilder::RuleElement* getRE(int row, int col ) ;
-    virtual libfwbuilder::RuleElement* getRE(libfwbuilder::Rule* r, int col ) ;
-
- public:
-
-    InterfacePolicyView(ProjectPanel *project,
-                        libfwbuilder::InterfacePolicy *p, QWidget *parent);
-    virtual ~InterfacePolicyView() {}
-
-    virtual void init();
-    
-
-};
-
 class NATView : public RuleSetView
 {
     virtual libfwbuilder::RuleElement* getRE(int row, int col ) ;
