@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHUnx.cpp,v 1.25 2007/12/15 23:19:04 vkurland Exp $
+  $Id: SSHUnx.cpp 469 2008-08-15 05:49:30Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,7 +17,7 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
@@ -25,7 +25,7 @@
 
 
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 #include "utils.h"
 
@@ -52,6 +52,7 @@ SSHUnx::SSHUnx(QWidget *_par,
     normal_prompt="> ";
     enable_prompt="# ";
     pwd_prompt="'s password: ";
+    thinkfinger_pwd_prompt="Password or swipe finger:";
     epwd_prompt="Password: ";
     ssh_pwd_prompt="'s password: ";
     ssoft_config_prompt="> ";
@@ -81,14 +82,18 @@ SSHUnx::~SSHUnx()
 bool SSHUnx::checkForErrors(QStringList *errptr)
 {
     if (fwbdebug)
-        qDebug(QString("SSHUnx::stateMachine:  Checking for errors. Buffer='%1'").arg(stdoutBuffer));
+        qDebug(
+            QString("SSHUnx::stateMachine:  Checking for errors. Buffer='%1'").
+            arg(stdoutBuffer).toAscii().constData());
 
     for (QStringList::const_iterator i=errptr->begin(); i!=errptr->end(); ++i)
     {
         if (fwbdebug)
-            qDebug(QString("SSHUnx::stateMachine:  error='%1'").arg(*i));
+            qDebug(
+                QString("SSHUnx::stateMachine:  error='%1'").
+                arg(*i).toAscii().constData());
 
-        if ( stdoutBuffer.findRev(QRegExp(*i),-1)!=-1 )
+        if ( stdoutBuffer.lastIndexOf(QRegExp(*i),-1)!=-1 )
         {
             if (fwbdebug)
                 qDebug("SSHUnx::stateMachine: MATCH. Error detected.");
@@ -125,21 +130,25 @@ void SSHUnx::stateMachine()
 {
     if (checkForErrors()) return;
 
+    if (fwbdebug)
+        qDebug("SSHUnx::stateMachine: state=%d",state);
+
     //entry:
     switch (state)
     {
     case NONE:
     {
-        if ( cmpPrompt(stdoutBuffer,ssh_pwd_prompt) ||
-             cmpPrompt(stdoutBuffer,putty_pwd_prompt) ||
-             stdoutBuffer.findRev(passphrase_prompt,-1)!=-1 ||
+        if ( cmpPrompt(stdoutBuffer, ssh_pwd_prompt) ||
+             cmpPrompt(stdoutBuffer, putty_pwd_prompt) ||
+             cmpPrompt(stdoutBuffer, thinkfinger_pwd_prompt) ||
+             stdoutBuffer.lastIndexOf(passphrase_prompt, -1)!=-1 ||
 
-             cmpPrompt(stdoutBuffer,sudo_pwd_prompt) ||
-             cmpPrompt(stderrBuffer,sudo_pwd_prompt) ) 
+             cmpPrompt(stdoutBuffer, sudo_pwd_prompt) ||
+             cmpPrompt(stderrBuffer, sudo_pwd_prompt) )
         {
             stdoutBuffer="";
-            proc->writeToStdin( pwd );
-            proc->writeToStdin( "\n" );
+            proc->write( pwd.toAscii() );
+            proc->write( "\n" );
             break;
         }
 /* we may get to LOGGEDIN state directly from NONE, for example when
@@ -152,21 +161,23 @@ void SSHUnx::stateMachine()
             if (!quiet) emit printStdout_sign( tr("Logged in") + "\n" );
             if (fwbdebug)
                 qDebug("SSHUnx::stateMachine logged in");
-//            proc->writeToStdin( "\n" );
+//            proc->write( "\n" );
 //            stdoutBuffer="";
             goto push_files;
         }
 
+        if (fwbdebug) qDebug(stdoutBuffer.toAscii().constData());
+
         QString fingerprint;
-        int n1,n2;
-        if (stdoutBuffer.find(newKeyOpenSSH)!=-1 ||
-            stdoutBuffer.find(newKeyPlink)!=-1   ||
-            stdoutBuffer.find(newKeyVsh)!=-1     ||
-            stdoutBuffer.find(newKeySSHComm)!=-1)
+        //int n1,n2;
+        if (stdoutBuffer.indexOf(newKeyOpenSSH)!=-1 ||
+            stdoutBuffer.indexOf(newKeyPlink)!=-1   ||
+            stdoutBuffer.indexOf(newKeyVsh)!=-1     ||
+            stdoutBuffer.indexOf(newKeySSHComm)!=-1)
         {
 /* new key */
-            bool unix_y_n = (stdoutBuffer.find(newKeyOpenSSH)!=-1 ||
-                             stdoutBuffer.find(newKeySSHComm)!=-1);
+            bool unix_y_n = (stdoutBuffer.indexOf(newKeyOpenSSH)!=-1 ||
+                             stdoutBuffer.indexOf(newKeySSHComm)!=-1);
 
             fingerprint = findKeyFingerprint(stdoutBuffer);
 
@@ -186,8 +197,8 @@ void SSHUnx::stateMachine()
             stdoutBuffer="";
             if (res==0)
             {
-                if (unix_y_n) proc->writeToStdin( "yes\n" );
-                else          proc->writeToStdin( "y\n" );
+                if (unix_y_n) proc->write( "yes\n" );
+                else          proc->write( "y\n" );
                 break;
             } else
             {
@@ -203,16 +214,16 @@ void SSHUnx::stateMachine()
 /* in this state we may need to enter sudo password */
     case PUSHING_CONFIG:
  push_files:
-        if ( cmpPrompt(stdoutBuffer,sudo_pwd_prompt) ||
-             cmpPrompt(stderrBuffer,sudo_pwd_prompt) ) 
+        if ( cmpPrompt(stdoutBuffer, sudo_pwd_prompt) ||
+             cmpPrompt(stderrBuffer, sudo_pwd_prompt) )
         {
             stdoutBuffer="";
-            proc->writeToStdin( pwd );
-            proc->writeToStdin( "\n" );
+            proc->write( pwd.toAscii() );
+            proc->write( "\n" );
             break;
         }
 /*
-        if (!quiet && !verbose) 
+        if (!quiet && !verbose)
         {
             emit printStdout_sign( stdoutBuffer );
         }
@@ -223,7 +234,7 @@ void SSHUnx::stateMachine()
         {
             if (fwbdebug) qDebug("SSHUnx::stateMachine - sending a file");
             emit updateProgressBar_sign(input.size(),true);
-            connect(proc,SIGNAL(wroteToStdin()),this,SLOT(readyToSend()));
+            connect(proc,SIGNAL(bytesWritten(qint64)),this,SLOT(readyToSend()));
             sendLine();
             break;
         }
@@ -231,7 +242,7 @@ void SSHUnx::stateMachine()
 
 /* we get to this state when previous ssh or scp command terminates */
     case FINISH:
-        if ( proc->normalExit() && proc->exitStatus()==0)
+        if ( (proc->state()==QProcess::NotRunning) && (proc->exitStatus()==QProcess::NormalExit))
         {
             emit printStdout_sign( "\n");
             emit printStdout_sign( tr("Done") );
