@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: SimpleTextView.cpp,v 1.1 2005/12/17 20:59:45 vkurland Exp $
+  $Id: SimpleTextView.cpp 332 2008-07-06 20:11:03Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,17 +17,18 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "SimpleTextView.h"
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 #include "utils.h"
 
+#include "SimpleTextView.h"
+
 #include <qvariant.h>
 #include <qframe.h>
 #include <qlabel.h>
@@ -45,17 +46,17 @@
 using namespace std;
 using namespace libfwbuilder;
 
-    
+
 void SimpleTextView::setText(QString s)
 {
-    textview->setText(s);
-    
+    m_dialog->textview->setText(s);
+
 }
 
 void SimpleTextView::setName(QString s)
 {
-    objectname->setText(s);
-    
+    m_dialog->objectname->setText(s);
+
 }
 
 
