@@ -1,4 +1,4 @@
-/* 
+/*
 
                           Firewall Builder
 
@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: TagServiceDialog.cpp,v 1.5 2007/04/14 00:18:43 vkurland Exp $
+  $Id: TagServiceDialog.cpp 332 2008-07-06 20:11:03Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -17,18 +17,19 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   To get a copy of the GNU General Public License, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 */
 
-#include "config.h"
+#include "../../config.h"
 #include "global.h"
 #include "utils.h"
 
 #include "TagServiceDialog.h"
-#include "ObjectManipulator.h"
+#include "ProjectPanel.h"
+#include "FWWindow.h"
 
 #include "fwbuilder/Library.h"
 #include "fwbuilder/TagService.h"
@@ -48,45 +49,53 @@
 #include <qcursor.h>
 
 #include <iostream>
+#include "FWBSettings.h"
 
 using namespace std;
 using namespace libfwbuilder;
 
+TagServiceDialog::~TagServiceDialog()
+{
+    delete m_dialog;
+}
+
+TagServiceDialog::TagServiceDialog(ProjectPanel *project, QWidget *parent) : QWidget(parent), m_project(project)
+{
+    m_dialog = new Ui::TagServiceDialog_q;
+    m_dialog->setupUi(this);
+    obj=NULL;
+}
+
 void TagServiceDialog::loadFWObject(FWObject *o)
 {
     obj=o;
     TagService *s = dynamic_cast<TagService*>(obj);
     assert(s!=NULL);
-    
-    
+
+
     init=true;
 
-    fillLibraries(libs,obj);
+    m_dialog->obj_name->setText( QString::fromUtf8(s->getName().c_str()) );
+    m_dialog->comment->setText( QString::fromUtf8(s->getComment().c_str()) );
 
-    obj_name->setText( QString::fromUtf8(s->getName().c_str()) );
-    comment->setText( QString::fromUtf8(s->getComment().c_str()) );
+    m_dialog->tagcode->setText( s->getCode().c_str() );
 
-    tagcode->setText( s->getCode().c_str() );
-    
     //apply->setEnabled( false );
 
-    obj_name->setEnabled(!o->isReadOnly());
-    setDisabledPalette(obj_name);
+    m_dialog->obj_name->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->obj_name);
 
-    libs->setEnabled(!o->isReadOnly());
-    setDisabledPalette(libs);
+    m_dialog->tagcode->setEnabled(!o->isReadOnly());
+    setDisabledPalette(m_dialog->tagcode);
 
-    tagcode->setEnabled(!o->isReadOnly());
-    setDisabledPalette(tagcode);
-
-    comment->setReadOnly(o->isReadOnly());
-    setDisabledPalette(comment);
+    m_dialog->comment->setReadOnly(o->isReadOnly());
+    setDisabledPalette(m_dialog->comment);
 
 
 
     init=false;
 }
-    
+
 void TagServiceDialog::changed()
 {
     //apply->setEnabled( true );
@@ -100,10 +109,10 @@ void TagServiceDialog::validate(bool *res)
     assert(s!=NULL);
 
     if (!isTreeReadWrite(this,obj)) { *res=false; return; }
-    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
+    if (!validateName(this,obj,m_dialog->obj_name->text())) { *res=false; return; }
 }
 
-void TagServiceDialog::isChanged(bool *res)
+void TagServiceDialog::isChanged(bool*)
 {
     //*res=(!init && apply->isEnabled());
 }
@@ -119,24 +128,15 @@ void TagServiceDialog::applyChanges()
     assert(s!=NULL);
 
     string oldname=obj->getName();
-    obj->setName( string(obj_name->text().utf8()) );
-    obj->setComment( string(comment->text().utf8()) );
+    obj->setName( string(m_dialog->obj_name->text().toUtf8().constData()) );
+    obj->setComment( string(m_dialog->comment->toPlainText().toUtf8().constData()) );
 
-    s->setCode( tagcode->text().latin1() );
+    s->setCode( m_dialog->tagcode->text().toLatin1().constData() );
 
-    om->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
-
-    init=true;
-
-/* move to another lib if we have to */
-    if ( ! Interface::isA( obj->getParent() ) &&
-         libs->currentText() != QString(obj->getLibrary()->getName().c_str()))
-        om->moveObject(libs->currentText(), obj);
-
-    init=false;
+    mw->updateObjName(obj,QString::fromUtf8(oldname.c_str()));
 
     //apply->setEnabled( false );
-    om->updateLastModifiedTimestampForAllFirewalls(obj);
+    mw->updateLastModifiedTimestampForAllFirewalls(obj);
 }
 
 void TagServiceDialog::discardChanges()
