@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: TimeDialog.h,v 1.6 2007/03/14 05:08:11 vkurland Exp $
+  $Id: TimeDialog.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,23 +27,28 @@
 #ifndef __TIMEDIALOG_H_
 #define __TIMEDIALOG_H_
 
-#include "config.h"
-#include <timedialog_q.h>
+#include "../../config.h"
+#include <ui_timedialog_q.h>
+#include <QWidget>
 
 #include "fwbuilder/FWObject.h"
 
+class ProjectPanel;
 
-class TimeDialog : public TimeDialog_q
+class TimeDialog : public QWidget
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
     bool init;
+    Ui::TimeDialog_q *m_dialog;
 
     void enableAllWidgets();
     
+    ProjectPanel *m_project;
  public:
-    TimeDialog(QWidget *parent) : TimeDialog_q(parent) { obj=NULL; }
+    TimeDialog(ProjectPanel *project, QWidget *parent);
+    ~TimeDialog();
     
 public slots:
     virtual void changed();
