@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: findDialog.h,v 1.4 2005/04/17 21:58:55 vkurland Exp $
+  $Id: findDialog.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,13 +27,13 @@
 #ifndef __FINDDIALOG_H_
 #define __FINDDIALOG_H_
 
-#include "config.h"
-#include <finddialog_q.h>
+#include "../../config.h"
+#include <ui_finddialog_q.h>
 
 #include "fwbuilder/FWObject.h"
+class ProjectPanel;
 
-
-class findDialog : public findDialog_q
+class findDialog : public QDialog
 {
     Q_OBJECT
 
@@ -44,11 +44,13 @@ class findDialog : public findDialog_q
 
     bool matchName(const QString &name);
     bool matchAttr(libfwbuilder::FWObject* obj);
-    
+    ProjectPanel *m_project;
  public:
-    findDialog(QWidget *p);
+    Ui::findDialog_q *m_dialog;
+    findDialog(QWidget *p, ProjectPanel *project);
 
-    void setObject(libfwbuilder::FWObject *o);
+    void setObject(libfwbuilder::FWObject *o); 
+    ~findDialog() { delete m_dialog; };
 
 public slots:
     virtual void find();
