@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: global.h,v 1.25 2006/06/14 03:46:38 vkurland Exp $
+  $Id: global.h 565 2008-10-04 14:34:24Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -26,30 +26,17 @@
 #ifndef __GLOBAL_DEFS_
 #define __GLOBAL_DEFS_
 
+#include "../../VERSION.h"
 #include <string>
 
 class  QApplication;
 class  FWWindow;
-class  ObjectManipulator;
-class  ObjectEditor;
-class  ObjectInfo;
-class  QTextEdit;
 class  FWBSettings;
-class  findDialog;
 class  listOfLibraries;
-class  ActionsDialog;
 
 extern QApplication      *app;
 extern FWWindow          *mw;
-extern ObjectManipulator *om;
-extern ObjectEditor      *oe;
-extern ActionsDialog     *ap;
-extern QTextEdit         *oi;
 extern FWBSettings       *st;
-extern findDialog        *fd;
-    
-extern listOfLibraries   *addOnLibs;
-
 
 extern std::string     appRootDir;
 extern std::string     userDataDir;
@@ -64,11 +51,7 @@ extern int             fwbdebug;
 extern bool            registered;
 extern bool            gui_experiment1;
 
-#define STANDARD_LIB "syslib000"
-#define USER_LIB     "syslib001"
-#define TEMPLATE_LIB "syslib100"
-#define DELETED_LIB  "sysid99"
-
+#define SETTINGS_PATH_PREFIX  "/3.0"
 
 #ifdef NDEBUG
 #  undef NDEBUG
