@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: instBatchOptionsDialog.h,v 1.3 2007/05/11 02:14:29 vkurland Exp $
+  $Id: instBatchOptionsDialog.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,8 +27,9 @@
 #ifndef __INSTBATCHOPTIONSDIALOG_H_
 #define __INSTBATCHOPTIONSDIALOG_H_
 
-#include "config.h"
-#include <instOptionsDialog.h>
+#include "../../config.h"
+
+#include "instOptionsDialog.h"
 
 class instConf;
 
