@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instConf.cpp 332 2008-07-06 20:11:03Z vadim $
+  $Id: instConf.cpp 585 2008-10-09 05:08:41Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -46,22 +46,7 @@ using namespace libfwbuilder;
 
 instConf::instConf()
 {
-    quiet=false;
-    verbose=false;
-    debug=0;
-    incremental=false;
-    dry_run=false;
-    saveStandby=false;
-    save_diff=false;
-    diff_pgm="";
-    no_gui=false;
-    backup=false;
-    backup_file="";
-    wdir="./";
-    fwobj=NULL;
-    maddr="";
-    user="";
-    batchInstall=false;
+    clear();
 }
 
 QString instConf::getCmdFromResource(const QString &resource_name)
@@ -87,3 +72,25 @@ QString instConf::getCmdFromResource(const QString &resource_name)
     return cmd;
 }
 
+void instConf::clear()
+{
+    quiet = false;
+    verbose = false;
+    debug = 0;
+    incremental = false;
+    dry_run = false;
+    saveStandby = false;
+    save_diff = false;
+    diff_pgm = "";
+    no_gui = false;
+    backup = false;
+    backup_file = "";
+    wdir = "./";
+    fwobj = NULL;
+    maddr = "";
+    user = "";
+    batchInstall = false;
+    sshArgs = "";
+    scpArgs = "";
+}
+
