@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: iosAdvancedDialog.h,v 1.1 2007/05/09 04:18:18 vkurland Exp $
+  $Id: iosAdvancedDialog.h 304 2008-07-03 02:19:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,22 +28,24 @@
 #ifndef __IOSADVANCEDDIALOG_H_
 #define __IOSADVANCEDDIALOG_H_
 
-#include "iosadvanceddialog_q.h"
+#include <ui_iosadvanceddialog_q.h>
 #include "DialogData.h"
 
 namespace libfwbuilder {
     class FWObject;
 };
 
-class iosAdvancedDialog : public iosAdvancedDialog_q
+class iosAdvancedDialog : public QDialog
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
     DialogData             data;
+    Ui::iosAdvancedDialog_q*m_dialog;
 
  public:
     iosAdvancedDialog(QWidget *parent,libfwbuilder::FWObject *o);
+    ~iosAdvancedDialog();
 
 protected slots:
 
