@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ipfwAdvancedDialog.h,v 1.2 2004/10/18 05:06:55 vkurland Exp $
+  $Id: ipfwAdvancedDialog.h 304 2008-07-03 02:19:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,22 +27,25 @@
 #ifndef __IPFWADVANCEDDIALOG_H_
 #define __IPFWADVANCEDDIALOG_H_
 
-#include "ipfwadvanceddialog_q.h"
+#include <ui_ipfwadvanceddialog_q.h>
 #include "DialogData.h"
+#include <QDialog>
 
 namespace libfwbuilder {
     class FWObject;
 };
 
-class ipfwAdvancedDialog : public ipfwAdvancedDialog_q
+class ipfwAdvancedDialog : public QDialog
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
     DialogData                       data;
+    Ui::ipfwAdvancedDialog_q        *m_dialog;
 
  public:
     ipfwAdvancedDialog(QWidget *parent,libfwbuilder::FWObject *o);
+    ~ipfwAdvancedDialog();
 
 protected slots:
 
