@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: iptAdvancedDialog.cpp 454 2008-08-06 15:50:49Z vadim $
+  $Id: iptAdvancedDialog.cpp 585 2008-10-09 05:08:41Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -79,91 +79,95 @@ iptAdvancedDialog::iptAdvancedDialog(QWidget *parent,FWObject *o)
     }
 
     //QString s = fwoptions->getStr("ipv4_6_order")
-    data.registerOption(m_dialog->ipv4before,    fwoptions, "ipv4_6_order", QStringList() <<  "IPv4 before IPv6" <<"ipv4_first" << "IPv6 before IPv4" << "ipv6_first"      );
+    data.registerOption(m_dialog->ipv4before, fwoptions, "ipv4_6_order", QStringList() <<  "IPv4 before IPv6" <<"ipv4_first" << "IPv6 before IPv4" << "ipv6_first");
 
-    data.registerOption(m_dialog->logTCPseq,    fwoptions, "log_tcp_seq"               );
-    data.registerOption(m_dialog->logTCPopt,    fwoptions, "log_tcp_opt"               );
-    data.registerOption(m_dialog->logIPopt,     fwoptions, "log_ip_opt"                );
-    data.registerOption(m_dialog->logNumsyslog, fwoptions, "use_numeric_log_levels"    );
+    data.registerOption(m_dialog->logTCPseq, fwoptions, "log_tcp_seq");
+    data.registerOption(m_dialog->logTCPopt, fwoptions, "log_tcp_opt");
+    data.registerOption(m_dialog->logIPopt, fwoptions, "log_ip_opt");
+    data.registerOption(m_dialog->logNumsyslog, fwoptions,
+                        "use_numeric_log_levels");
 
-    slm = getLogLevels( obj->getStr("platform").c_str() );
+    slm = getLogLevels( obj->getStr("platform").c_str());
     m_dialog->logLevel->clear();
     m_dialog->logLevel->addItems( getScreenNames(slm));
-    data.registerOption(m_dialog-> logLevel,   fwoptions,  "log_level", slm);
+    data.registerOption(m_dialog-> logLevel, fwoptions, "log_level", slm);
 
-    data.registerOption(m_dialog->useULOG,    fwoptions, "use_ULOG"        );
-    data.registerOption(m_dialog->cprange,    fwoptions, "ulog_cprange"    );
-    data.registerOption(m_dialog->qthreshold, fwoptions, "ulog_qthreshold" );
-    data.registerOption(m_dialog->nlgroup,    fwoptions, "ulog_nlgroup"    );
-    data.registerOption(m_dialog->logprefix,  fwoptions, "log_prefix"      );
+    data.registerOption(m_dialog->useULOG, fwoptions, "use_ULOG");
+    data.registerOption(m_dialog->cprange, fwoptions, "ulog_cprange");
+    data.registerOption(m_dialog->qthreshold, fwoptions, "ulog_qthreshold");
+    data.registerOption(m_dialog->nlgroup, fwoptions, "ulog_nlgroup");
+    data.registerOption(m_dialog->logprefix, fwoptions, "log_prefix");
 
-    slm=getLimitSuffixes( obj->getStr("platform").c_str() );
+    slm=getLimitSuffixes( obj->getStr("platform").c_str());
     m_dialog->logLimitSuffix->clear();
     m_dialog->logLimitSuffix->addItems(getScreenNames(slm));
-    data.registerOption(m_dialog-> logLimitSuffix,   fwoptions,  "limit_suffix", slm);
+    data.registerOption(m_dialog-> logLimitSuffix, fwoptions,
+                        "limit_suffix", slm);
 
-    data.registerOption(m_dialog->logLimitVal,          fwoptions, "limit_value");
-    data.registerOption(m_dialog->logAll,               fwoptions, "log_all");
-    data.registerOption(m_dialog->compiler,             fwoptions, "compiler");
-    data.registerOption(m_dialog->compilerArgs,         fwoptions, "cmdline");
-    data.registerOption(m_dialog->outputFileName,       fwoptions, "output_file");
+    data.registerOption(m_dialog->logLimitVal, fwoptions, "limit_value");
+    data.registerOption(m_dialog->logAll, fwoptions, "log_all");
+    data.registerOption(m_dialog->compiler, fwoptions, "compiler");
+    data.registerOption(m_dialog->compilerArgs, fwoptions, "cmdline");
+    data.registerOption(m_dialog->outputFileName, fwoptions, "output_file");
     data.registerOption(m_dialog->assumeFwIsPartOfAny,
                         fwoptions, "firewall_is_part_of_any_and_networks");
     data.registerOption(m_dialog->acceptSessions,
                         fwoptions, "accept_new_tcp_with_no_syn");
-    data.registerOption(m_dialog->dropInvalid,          fwoptions, "drop_invalid");
-    data.registerOption(m_dialog->logInvalid,           fwoptions, "log_invalid");
-    data.registerOption(m_dialog->acceptESTBeforeFirst, fwoptions, "accept_established");
-    data.registerOption(m_dialog->bridge,               fwoptions, "bridging_fw");
-    data.registerOption(m_dialog->shadowing,            fwoptions, "check_shading");
-    data.registerOption(m_dialog->emptyGroups,          fwoptions, "ignore_empty_groups");
-    data.registerOption(m_dialog->localNAT,             fwoptions, "local_nat");
-    data.registerOption(m_dialog->clampMSStoMTU,        fwoptions, "clamp_mss_to_mtu");
+    data.registerOption(m_dialog->dropInvalid, fwoptions, "drop_invalid");
+    data.registerOption(m_dialog->logInvalid, fwoptions, "log_invalid");
+    data.registerOption(m_dialog->acceptESTBeforeFirst, fwoptions,
+                        "accept_established");
+    data.registerOption(m_dialog->bridge, fwoptions, "bridging_fw");
+    data.registerOption(m_dialog->shadowing, fwoptions, "check_shading");
+    data.registerOption(m_dialog->emptyGroups, fwoptions,
+                        "ignore_empty_groups");
+    data.registerOption(m_dialog->localNAT, fwoptions, "local_nat");
+    data.registerOption(m_dialog->clampMSStoMTU, fwoptions, "clamp_mss_to_mtu");
     data.registerOption(m_dialog->makeTagClassifyTerminating,
                         fwoptions, "classify_mark_terminating");
-    slm=getActionsOnReject( obj->getStr("platform").c_str() );
+    slm=getActionsOnReject( obj->getStr("platform").c_str());
     m_dialog->actionOnReject->clear();
     m_dialog->actionOnReject->addItems(getScreenNames(slm));
     data.registerOption(m_dialog-> actionOnReject,
                          fwoptions,"action_on_reject", slm);
 
-    data.registerOption(m_dialog->mgmt_ssh,             fwoptions, "mgmt_ssh"    );
-    data.registerOption(m_dialog->mgmt_addr,            fwoptions, "mgmt_addr"    );
+    data.registerOption(m_dialog->mgmt_ssh, fwoptions, "mgmt_ssh");
+    data.registerOption(m_dialog->mgmt_addr, fwoptions, "mgmt_addr");
     data.registerOption(m_dialog->addVirtualsforNAT,
-                        fwoptions, "manage_virtual_addr"    );
+                        fwoptions, "manage_virtual_addr");
     data.registerOption(m_dialog->configureInterfaces,
-                        fwoptions, "configure_interfaces"    );
-    data.registerOption(m_dialog->iptDebug,             fwoptions, "debug"    );
-    data.registerOption(m_dialog->verifyInterfaces,     fwoptions, "verify_interfaces"    );
-    data.registerOption(m_dialog->loadModules,          fwoptions, "load_modules"    );
+                        fwoptions, "configure_interfaces");
+    data.registerOption(m_dialog->iptDebug, fwoptions, "debug");
+    data.registerOption(m_dialog->verifyInterfaces, fwoptions, "verify_interfaces");
+    data.registerOption(m_dialog->loadModules, fwoptions, "load_modules");
     data.registerOption(m_dialog->iptablesRestoreActivation,
-                        fwoptions, "use_iptables_restore"    );
-    data.registerOption(m_dialog->ipt_fw_dir,           fwoptions, "firewall_dir"    );
-    data.registerOption(m_dialog->ipt_user,             fwoptions, "admUser"    );
-    data.registerOption(m_dialog->altAddress,           fwoptions, "altAddress"    );
-    data.registerOption(m_dialog->sshArgs,              fwoptions, "sshArgs"    );
-    data.registerOption(m_dialog->activationCmd,        fwoptions, "activationCmd"    );
-
+                        fwoptions, "use_iptables_restore");
+    data.registerOption(m_dialog->ipt_fw_dir, fwoptions, "firewall_dir");
+    data.registerOption(m_dialog->ipt_user, fwoptions, "admUser");
+    data.registerOption(m_dialog->altAddress, fwoptions, "altAddress");
+    data.registerOption(m_dialog->sshArgs, fwoptions, "sshArgs");
+    data.registerOption( m_dialog->scpArgs, fwoptions, "scpArgs");
+    data.registerOption(m_dialog->activationCmd, fwoptions, "activationCmd");
 
     PolicyInstallScript *pis   = mgmt->getPolicyInstallScript();
 
-    m_dialog->installScript->setText(     pis->getCommand().c_str() );
-    m_dialog->installScriptArgs->setText( pis->getArguments().c_str() );
+    m_dialog->installScript->setText(     pis->getCommand().c_str());
+    m_dialog->installScriptArgs->setText( pis->getArguments().c_str());
 
 
     /* page "Prolog/Epilog" */
 
     data.registerOption(m_dialog->prolog_script, fwoptions,
-                        "prolog_script"    );
+                        "prolog_script");
 
-    slm = getPrologPlaces( obj->getStr("platform").c_str() );
+    slm = getPrologPlaces( obj->getStr("platform").c_str());
     m_dialog->prologPlace->clear();
     m_dialog->prologPlace->addItems(getScreenNames(slm));
     data.registerOption(m_dialog-> prologPlace, fwoptions,
                         "prolog_place", slm);
 
     data.registerOption(m_dialog->epilog_script, fwoptions,
-                        "epilog_script"    );
+                        "epilog_script");
 
     data.loadAll();
     switchLOG_ULOG();
@@ -199,8 +203,8 @@ void iptAdvancedDialog::accept()
     if (mgmt_addr)
         mgmt->setAddress(*mgmt_addr);
 
-    pis->setCommand( m_dialog->installScript->text().toLatin1().constData() );
-    pis->setArguments( m_dialog->installScriptArgs->text().toLatin1().constData() );
+    pis->setCommand( m_dialog->installScript->text().toLatin1().constData());
+    pis->setArguments( m_dialog->installScriptArgs->text().toLatin1().constData());
 
     mw->updateLastModifiedTimestampForAllFirewalls(obj);
     QDialog::accept();
@@ -215,18 +219,18 @@ void iptAdvancedDialog::editProlog()
 {
     SimpleTextEditor edt(this,
                          m_dialog->prolog_script->toPlainText(),
-                          true, tr( "Script Editor" ) );
+                          true, tr( "Script Editor" ));
     if ( edt.exec() == QDialog::Accepted )
-        m_dialog->prolog_script->setText( edt.text() );
+        m_dialog->prolog_script->setText( edt.text());
 }
 
 void iptAdvancedDialog::editEpilog()
 {
     SimpleTextEditor edt(this,
                          m_dialog->epilog_script->toPlainText(),
-                          true, tr( "Script Editor" ) );
+                          true, tr( "Script Editor" ));
     if ( edt.exec() == QDialog::Accepted )
-        m_dialog->epilog_script->setText( edt.text() );
+        m_dialog->epilog_script->setText( edt.text());
 }
 
 void iptAdvancedDialog::help()
