@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: linux24AdvancedDialog.h,v 1.1 2004/05/11 04:45:38 vkurland Exp $
+  $Id: linux24AdvancedDialog.h 438 2008-08-02 20:33:06Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,27 +27,31 @@
 #ifndef __LINUX24ADVANCEDDIALOG_H_
 #define __LINUX24ADVANCEDDIALOG_H_
 
-#include "linux24advanceddialog_q.h"
+#include <ui_linux24advanceddialog_q.h>
 #include "DialogData.h"
+#include <QDialog>
 
 namespace libfwbuilder {
     class FWObject;
 };
 
-class linux24AdvancedDialog : public linux24AdvancedDialog_q
+class linux24AdvancedDialog : public QDialog
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
     DialogData                       data;
+    Ui::linux24AdvancedDialog_q     *m_dialog;
 
  public:
     linux24AdvancedDialog(QWidget *parent,libfwbuilder::FWObject *o);
+    ~linux24AdvancedDialog();
 
 protected slots:
 
     virtual void accept();
     virtual void reject();
+    virtual void help();
 
 
 };
