@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: main.cpp 565 2008-10-04 14:34:24Z vadim $
+  $Id: main.cpp 660 2008-11-23 03:19:04Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -68,6 +68,7 @@
 #include "ObjectEditor.h"
 #include "findDialog.h"
 #include "ProjectPanel.h"
+#include "StartTipDialog.h"
 
 #include "fwbuilder/FWObject.h"
 #include "fwbuilder/Tools.h"
@@ -340,9 +341,10 @@ int main( int argc, char *argv[] )
 {
 
 
-    bool        ssh_wrapper=false;
+    bool ssh_wrapper = false;
+    bool scp_wrapper = false;
     const char *arg[64];
-    int         i, j;
+    int i, j;
 
     filename = "";
     print_output_file_name = "";
@@ -376,14 +378,16 @@ int main( int argc, char *argv[] )
     {
         if (strncmp(argv[i], "-X", 2)==0) { ssh_wrapper=true; continue; }
         else
-            if (strncmp(argv[i], "-d", 2)==0) { fwbdebug++; continue; }
+            if (strncmp(argv[i], "-Y", 2)==0) { scp_wrapper=true; continue; }
             else
-                arg[j] = strdup(argv[i]);
+                if (strncmp(argv[i], "-d", 2)==0) { fwbdebug++; continue; }
+                else
+                    arg[j] = strdup(argv[i]);
         j++;
     }
     arg[j] = NULL;
 
-    if (ssh_wrapper)
+    if (ssh_wrapper || scp_wrapper)
     {
 
 /* need to create and initialize settings to be able to use ssh/scp
@@ -394,15 +398,23 @@ int main( int argc, char *argv[] )
 /* initialize preferences */
         st->init();
 
-        QString sshcmd=st->getSSHPath();
+        if (ssh_wrapper)
+        {
+            QString sshcmd = st->getSSHPath();
+            if (sshcmd.isEmpty()) sshcmd = "ssh";
+            arg[0] = strdup( sshcmd.toLatin1().constData() );
+        }
 
-        if (sshcmd.isEmpty()) sshcmd="ssh";
-
-        arg[0]=strdup( sshcmd.toLatin1().constData() );
+        if (scp_wrapper)
+        {
+            QString scpcmd = st->getSCPPath();
+            if (scpcmd.isEmpty()) scpcmd = "scp";
+            arg[0] = strdup( scpcmd.toLatin1().constData() );
+        }
 
         if (fwbdebug)
         {
-            qDebug("cmd: %s",arg[0]);
+            qDebug("cmd: %s", arg[0]);
             qDebug("Arguments:");
             for (const char **cptr = arg; *cptr!=NULL; cptr++)
             {
@@ -419,7 +431,7 @@ int main( int argc, char *argv[] )
         char  slave_name[64];
 //        char  *pgm;
 
-        pid=forkpty(&mfd,slave_name,NULL,NULL);
+        pid = forkpty(&mfd,slave_name,NULL,NULL);
         if (pid<0)
         {
             qDebug("Fork failed: %s", strerror(errno));
@@ -463,7 +475,7 @@ int main( int argc, char *argv[] )
             tv.tv_usec = 0;
 
             FD_ZERO(&rfds);
-            FD_SET(mfd,            &rfds);
+            FD_SET(mfd,  &rfds);
             if (!endOfStream)  FD_SET(STDIN_FILENO  , &rfds);
 
             retval = select( max(STDIN_FILENO,mfd)+1 , &rfds, NULL, NULL, &tv);
@@ -579,8 +591,8 @@ int main( int argc, char *argv[] )
     if ( (argc-1)==optind)
         filename = strdup( argv[optind++] );
 
-    try
-    {
+//    try
+//    {
         if (fwbdebug) qDebug("Initializing ...");
 
         if (fwbdebug) qDebug("Creating app ...");
@@ -611,6 +623,26 @@ int main( int argc, char *argv[] )
                            "3.0",
                            true, true, fwbdebug);
 #endif
+
+        string full_res_path = respath + FS_SEPARATOR + "resources.xml";
+
+        if (fwbdebug)
+        {
+            qDebug("reading resources from '%s' ...", full_res_path.c_str());
+        }
+
+        //respath = RES_DIR;
+        new Resources(full_res_path);
+        if (fwbdebug) qDebug("done");
+
+        vector<std::string> platforms = Resources::getListOfPlatforms();
+        if (platforms.empty() || (
+                platforms.size()==1 && platforms.front()=="unknown" ))
+        {
+            qDebug("Failed to load list of supported platforms");
+            exit(1);
+        }
+
         if (cli_print)
         {
             if (fwbdebug) qDebug("Print from command line");
@@ -620,24 +652,6 @@ int main( int argc, char *argv[] )
             return 0;
         }
 
-        string full_res_path = respath + FS_SEPARATOR + "resources.xml";
-
-        if (fwbdebug)
-        {
-            qDebug("reading resources from '%s' ...",full_res_path.c_str());
-        }
-
-        //respath = RES_DIR;
-        new Resources(full_res_path);
-        if (fwbdebug) qDebug("done");
-
-        vector<std::string> platforms=Resources::getListOfPlatforms();
-        if (platforms.empty() || (
-                platforms.size()==1 && platforms.front()=="unknown" ))
-        {
-            qDebug("Failed to load list of supported platforms");
-            exit(1);
-        }
 
         if (fwbdebug) qDebug("creating widgets ...");
 
@@ -682,6 +696,13 @@ int main( int argc, char *argv[] )
         // setup single shot timer to call startupLoad()
         QTimer::singleShot(0.5, mw, SLOT(startupLoad()));
 
+        if (! st->getBool("UI/NoStartTip"))
+        {
+            StartTipDialog *stdlg = new StartTipDialog();
+            stdlg->show();
+            stdlg->raise();
+        }
+
         app->exec();
 
         mw->hide();  // must do this before settings object is destroyed
@@ -707,11 +728,11 @@ int main( int argc, char *argv[] )
 
         st->save();
         delete st;
-    }
-    catch (FWException &ex)
-    {
-        qDebug("Exception: %s",ex.toString().c_str());
-    }
+//    }
+//    catch (FWException &ex)
+//    {
+//        qDebug("Exception: %s",ex.toString().c_str());
+//    }
 }
 
 
