@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: openbsdAdvancedDialog.h,v 1.1 2004/05/11 04:45:39 vkurland Exp $
+  $Id: openbsdAdvancedDialog.h 304 2008-07-03 02:19:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,22 +27,25 @@
 #ifndef __OPENBSDADVANCEDDIALOG_H_
 #define __OPENBSDADVANCEDDIALOG_H_
 
-#include "openbsdadvanceddialog_q.h"
+#include <ui_openbsdadvanceddialog_q.h>
 #include "DialogData.h"
+#include <QDialog>
 
 namespace libfwbuilder {
     class FWObject;
 };
 
-class openbsdAdvancedDialog : public openbsdAdvancedDialog_q
+class openbsdAdvancedDialog : public QDialog
 {
     Q_OBJECT
 
     libfwbuilder::FWObject *obj;
     DialogData                       data;
+    Ui::openbsdAdvancedDialog_q     *m_dialog;
 
  public:
     openbsdAdvancedDialog(QWidget *parent,libfwbuilder::FWObject *o);
+    ~openbsdAdvancedDialog();
 
 protected slots:
 
