@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: platforms.cpp 332 2008-07-06 20:11:03Z vadim $
+  $Id: platforms.cpp 654 2008-11-20 06:58:15Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -368,7 +368,7 @@ bool isDefaultRoutingRuleOptions(FWOptions *opt)
     return res;
 }
 
-QString getVersionString(const QString &platform,const QString &version)
+QString getVersionString(const QString &platform, const QString &version)
 {
     list<QStringPair> vl = getVersionsForPlatform(platform);
     list<QStringPair>::iterator li =
@@ -399,8 +399,9 @@ list<QStringPair> getVersionsForPlatform(const QString &platform)
     {
         if (platform=="pix" || platform=="fwsm" || platform=="iosacl")
         {
-            QString lst=Resources::platform_res[platform.toAscii().constData()]->getResourceStr(
-                "/FWBuilderResources/Target/versions").c_str();
+            QString lst = Resources::platform_res[
+                platform.toAscii().constData()]->getResourceStr(
+                    "/FWBuilderResources/Target/versions").c_str();
 
             QStringList ll=lst.split(',');
 
