@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: platforms.h,v 1.13 2007/12/15 20:32:16 vkurland Exp $
+  $Id: platforms.h 353 2008-07-13 01:26:39Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -26,7 +26,7 @@
 #ifndef _PLATFORMS_HH
 #define _PLATFORMS_HH
 
-#include "config.h"
+#include "../../config.h"
 
 // among other things, utils.h defines list<QStringPair> which we need here
 #include "utils.h"
