@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: utils.h,v 1.32 2007/05/23 03:05:51 vkurland Exp $
+  $Id: utils.h 373 2008-07-17 15:40:16Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -31,12 +31,13 @@
 #include <string>
 #include <list>
 #include <functional>
+#include <QMenu>
 
 class QObject;
 class QWidget;
-class QPopupMenu;
+class QMenu;
 class QComboBox;
-class QListBox;
+class QListWidget;
 
 #include <qkeysequence.h>
 #include <qstring.h>
@@ -68,8 +69,8 @@ class findSecondInQStringPair {
 
 
 
-extern int addPopupMenuItem(QObject *res,
-                            QPopupMenu* menu,
+extern QAction* addPopupMenuItem(QObject *res,
+                            QMenu* menu, //it was a Q3PopupMenu object
                             const QString &resourceIconPath,
                             const QString itemName,
                             const char* member,
@@ -77,7 +78,7 @@ extern int addPopupMenuItem(QObject *res,
 
 extern void fillLibraries(QComboBox *libs, libfwbuilder::FWObject *obj,
                           bool rw=false);
-extern void fillLibraries(QListBox *libs, libfwbuilder::FWObject *obj,
+extern void fillLibraries(QListWidget *libs, libfwbuilder::FWObject *obj,
                           bool rw=false);
 
 
@@ -125,7 +126,7 @@ extern void setHostOS(QComboBox *hostOS,const QString &os);
 
 extern void setDisabledPalette(QWidget *w);
 
-extern QString getAddrByName(const QString &name);
+extern QString getAddrByName(const QString &name, int af_type);
 extern QString getNameByAddr(const QString &addr);
 extern QString wordWrap(const QString& ,int);
 
