@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: ipfw.cpp 545 2008-09-19 20:27:58Z vadim $
+  $Id: ipfw.cpp 585 2008-10-09 05:08:41Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -98,9 +98,33 @@ static int              verbose        = 0;
 static bool             test_mode      = false;
 static bool             ipv4_run       = true;
 static bool             ipv6_run       = true;
+static bool             fw_by_id       = false;
 
 FWObjectDatabase       *objdb = NULL;
 
+#ifdef _WIN32
+string fs_separator = "\\";
+#else
+string fs_separator = "/";
+#endif
+
+string getFileName(const string &file_path)
+{
+    string::size_type n = file_path.rfind(fs_separator);
+    string res = file_path;
+    res.erase(0, n+1);
+    return res;
+}
+
+string getDir(const string &file_path)
+{
+    string::size_type n = file_path.rfind(fs_separator);
+    string res = file_path;
+    if (n==string::npos) return "";
+    else res.erase(n);
+    return res;
+}
+
 class UpgradePredicate: public XMLTools::UpgradePredicate
 {
     public:
@@ -168,10 +192,13 @@ int main(int argc, char * const *argv)
 
     int   opt;
 
-    while( (opt=getopt(argc,argv,"x:vVf:d:r:o:46")) != EOF )
+    while( (opt=getopt(argc,argv,"x:ivVf:d:r:o:46")) != EOF )
     {
         switch(opt)
         {
+        case 'i':
+            fw_by_id = true;
+            break;
         case '4':
             ipv4_run = true;
             ipv6_run = false;
@@ -228,11 +255,6 @@ int main(int argc, char * const *argv)
 
     fwobjectname = strdup( argv[optind++] );
 
-    if (fw_file_name.empty())
-    {
-        fw_file_name=string(fwobjectname)+".fw";
-    }
-
     if (wdir==0) 	wdir="./";
 
     if (
@@ -276,7 +298,21 @@ int main(int argc, char * const *argv)
         if (slib && slib->isReadOnly()) slib->setReadOnly(false);
 
 	/* Review firewall and OS options and generate commands */
-	Firewall*  fw=objdb->findFirewallByName(fwobjectname);
+	Firewall* fw;
+        if (fw_by_id)
+        {
+            // fwobjectname is actually object id
+            fw = Firewall::cast(
+                objdb->findInIndex(objdb->getIntId(fwobjectname)));
+            fwobjectname = fw->getName().c_str();
+        }
+        else
+            fw = objdb->findFirewallByName(fwobjectname);
+
+        if (fw_file_name.empty())
+        {
+            fw_file_name=string(fwobjectname)+".fw";
+        }
 
         /* some initial sanity checks */
         list<FWObject*> l2=fw->getByType(Interface::TYPENAME);
@@ -551,7 +587,7 @@ int main(int argc, char * const *argv)
 #  Generated ") << timestr << " " << tzname[stm->tm_isdst] << _(" by ") 
                << user_name << "\n#\n";
 
-        fw_file << MANIFEST_MARKER << "* " << fw_file_name << endl;
+        fw_file << MANIFEST_MARKER << "* " << getFileName(fw_file_name) << endl;
         fw_file << "#" << endl;
         fw_file << "#" << endl;
 
