@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: MangleTableCompiler_ipt.cpp 312 2008-07-05 17:40:12Z vadim $
+  $Id: MangleTableCompiler_ipt.cpp 614 2008-10-14 05:34:42Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -34,6 +34,9 @@
 #include "fwbuilder/Rule.h"
 
 #include <iostream>
+#include <list>
+#include <algorithm>
+#include <iterator>
 
 using namespace libfwbuilder;
 using namespace fwcompiler;
@@ -41,6 +44,7 @@ using namespace std;
 
 string MangleTableCompiler_ipt::myPlatformName() { return "iptables"; }
 
+
 int MangleTableCompiler_ipt::prolog()
 {
     return PolicyCompiler_ipt::prolog();
@@ -51,58 +55,72 @@ int MangleTableCompiler_ipt::prolog()
         i!=combined_ruleset->end(); i++)
     {
 	PolicyRule *r = PolicyRule::cast( *i );
+        FWOptions *ruleopt = r->getOptionsObject();
 	if (r->isDisabled()) continue;
         if (r->getAction() == PolicyRule::Tag ||
             r->getAction() == PolicyRule::Classify) n++;
+        if (r->getAction() == PolicyRule::Branch &&
+            ruleopt->getBool("ipt_branch_in_mangle")) n++;
     }
     return n;
 }
 
 bool MangleTableCompiler_ipt::keepMangleTableRules::processNext()
 {
-    PolicyRule *rule=getNext(); if (rule==NULL) return false;
-    FWOptions *ruleopt =rule->getOptionsObject();
+    PolicyRule *rule = getNext(); if (rule==NULL) return false;
+    FWOptions *ruleopt = rule->getOptionsObject();
+    PolicyCompiler_ipt *ipt_comp = dynamic_cast<PolicyCompiler_ipt*>(compiler);
 
-    if (rule->getAction() == PolicyRule::Branch &&
-        ruleopt->getBool("ipt_branch_in_mangle"))
-    {
-        PolicyRule* r;
-        
-        // this is a branching rule for mangle table. Need to put it
-        // into PREROUTING and POSTROUTING chains as well because some
-        // targets that work with mangle table can only go into these
-        // chains, yet we do not know what kind of rules will user
-        // place in the branch
-
-        if (rule->getDirection()==PolicyRule::Undefined ||
-            rule->getDirection()==PolicyRule::Both ||
-            rule->getDirection()==PolicyRule::Inbound)
-        {
-            r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME));
-            compiler->temp_ruleset->add(r);
-            r->duplicate(rule);
-            r->setStr("ipt_chain","PREROUTING");
-            tmp_queue.push_back(r);
-        }
-
-        if (rule->getDirection()==PolicyRule::Undefined ||
-            rule->getDirection()==PolicyRule::Both ||
-            rule->getDirection()==PolicyRule::Outbound)
-        {
-            r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME));
-            compiler->temp_ruleset->add(r);
-            r->duplicate(rule);
-            r->setStr("ipt_chain","POSTROUTING");
-            tmp_queue.push_back(r);
-        }
+    string ruleset_name = compiler->getRuleSetName();
 
+    if (ipt_comp->isMangleOnlyRuleSet(ruleset_name))
         tmp_queue.push_back(rule);
-    }
+    else
+    {
+        if (rule->getAction() == PolicyRule::Branch &&
+            ruleopt->getBool("ipt_branch_in_mangle"))
+        {
+            PolicyRule* r;
+        
+            // this is a branching rule for mangle table. Need to put it
+            // into PREROUTING and POSTROUTING chains as well because some
+            // targets that work with mangle table can only go into these
+            // chains, yet we do not know what kind of rules will user
+            // place in the branch
 
-    if (rule->getAction() == PolicyRule::Tag ||
-        rule->getAction() == PolicyRule::Route ||
-        rule->getAction() == PolicyRule::Classify ||
-        ruleopt->getBool("put_in_mangle_table")) tmp_queue.push_back(rule);
+            if (rule->getDirection()==PolicyRule::Undefined ||
+                rule->getDirection()==PolicyRule::Both ||
+                rule->getDirection()==PolicyRule::Inbound)
+            {
+                r= PolicyRule::cast(
+                    compiler->dbcopy->create(PolicyRule::TYPENAME));
+                compiler->temp_ruleset->add(r);
+                r->duplicate(rule);
+                r->setStr("ipt_chain","PREROUTING");
+                tmp_queue.push_back(r);
+            }
+
+            if (rule->getDirection()==PolicyRule::Undefined ||
+                rule->getDirection()==PolicyRule::Both ||
+                rule->getDirection()==PolicyRule::Outbound)
+            {
+                r= PolicyRule::cast(
+                    compiler->dbcopy->create(PolicyRule::TYPENAME));
+                compiler->temp_ruleset->add(r);
+                r->duplicate(rule);
+                r->setStr("ipt_chain","POSTROUTING");
+                tmp_queue.push_back(r);
+            }
+
+            tmp_queue.push_back(rule);
+            return true;
+        }
+
+        if (rule->getAction() == PolicyRule::Tag ||
+            rule->getAction() == PolicyRule::Route ||
+            rule->getAction() == PolicyRule::Classify ||
+            ruleopt->getBool("put_in_mangle_table")) tmp_queue.push_back(rule);
+    }
 
     return true;
 }
@@ -114,6 +132,14 @@ void MangleTableCompiler_ipt::addRuleFilter()
 }
 
 string MangleTableCompiler_ipt::flushAndSetDefaultPolicy()
+{
+    return printAutomaticRulesForMangleTable(have_connmark,
+                                             have_connmark_in_output);
+}
+
+
+string MangleTableCompiler_ipt::printAutomaticRulesForMangleTable(
+    bool have_connmark, bool have_connmark_in_output)
 {
     ostringstream res;
 
