@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: MangleTableCompiler_ipt.h 474 2008-08-18 03:05:45Z vadim $
+  $Id: MangleTableCompiler_ipt.h 611 2008-10-12 04:03:22Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -41,6 +41,7 @@ namespace fwcompiler {
          * this processor drops all rules except for those that require mangle table
          */
         DECLARE_POLICY_RULE_PROCESSOR(keepMangleTableRules);
+        friend class keepMangleTableRules;
 
 	public:
 
@@ -59,6 +60,9 @@ namespace fwcompiler {
         virtual void addRuleFilter();
 	
         virtual std::string flushAndSetDefaultPolicy();
+
+        std::string printAutomaticRulesForMangleTable(
+            bool have_connmark, bool have_connmark_in_output);
     };
 }
 
