@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_PrintRuleIptRstEcho.cpp,v 1.2 2006/06/05 04:53:21 vkurland Exp $
+  $Id: NATCompiler_PrintRuleIptRstEcho.cpp 474 2008-08-18 03:05:45Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -59,10 +59,14 @@ using namespace std;
 string NATCompiler_ipt::PrintRuleIptRstEcho::_createChain(const string &chain)
 {
     string res;
-    if ( ! chains[chain] )
+    NATCompiler_ipt *ipt_comp = dynamic_cast<NATCompiler_ipt*>(compiler);
+
+    if (!minus_n_tracker_initialized) InitializeMinusNTracker();
+
+    if ( ipt_comp->minus_n_commands->count(chain)==0 )
     {
 	res = "echo \":" + chain + " - [0:0]\"\n";
-	chains[chain]=true;
+	(*(ipt_comp->minus_n_commands))[chain] = true;
     }
     return res;
 }
