@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSConfigurator_linux24.cpp,v 1.43 2007/12/16 01:07:09 vkurland Exp $
+  $Id: OSConfigurator_linux24.cpp 468 2008-08-14 02:07:36Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,6 +28,8 @@
 
 #include "OSConfigurator_linux24.h"
 
+#include "fwbuilder/InetAddr.h"
+
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/FWOptions.h"
 #include "fwbuilder/Interface.h"
@@ -59,12 +61,13 @@ using namespace std;
 string OSConfigurator_linux24::myPlatformName() { return "Linux24"; }
 
 OSConfigurator_linux24::OSConfigurator_linux24(FWObjectDatabase *_db,
-                                               const string &fwname) : 
-    OSConfigurator(_db,fwname) , os_data(fw->getStr("host_OS"))
+                                               const string &fwname,
+                                               bool ipv6_policy) : 
+    OSConfigurator(_db, fwname, ipv6_policy) , os_data(fw->getStr("host_OS"))
 {
 }
 
-string OSConfigurator_linux24::getInterfaceVarName(FWObject *iface)
+string OSConfigurator_linux24::getInterfaceVarName(FWObject *iface, bool v6)
 {
     ostringstream  ostr;
     string iname=iface->getName();
@@ -72,10 +75,10 @@ string OSConfigurator_linux24::getInterfaceVarName(FWObject *iface)
     while ( (p1=iname.find("."))!=string::npos)
         iname=iname.replace(p1,1,"_");
     ostr << "i_" << iname;
+    if (v6) ostr << "_v6";
     return ostr.str();
 }
 
-
 void OSConfigurator_linux24::processFirewallOptions() 
 {
     FWOptions* options=fw->getOptionsObject();
@@ -199,29 +202,25 @@ void OSConfigurator_linux24::addVirtualAddressForNAT(const Network *nw)
     if ( options->getBool("manage_virtual_addr") ) 
     {
         if (virtual_addresses.empty() || 
-            find(virtual_addresses.begin(),virtual_addresses.end(),nw->getAddress())==virtual_addresses.end()) 
+            find(virtual_addresses.begin(),virtual_addresses.end(),
+                 *(nw->getAddressPtr())) == virtual_addresses.end())
         {
             Interface *iface=findInterfaceFor( nw, fw );
             if (iface!=NULL)
             {
-                IPNetwork n( nw->getAddress() , nw->getNetmask() );
-
-                IPAddress a;
+                const InetAddr *a = nw->getAddressPtr();
                 string str, subnet, first, last;
 
-                a=nw->getAddress() +1;
-                first  = a.toString();
-                        
-                a      = n.getBroadcastAddress() -1;
-                last   = a.toString();
+                first  = (*a + 1).toString();
+                last   = (*(nw->getBroadcastAddressPtr()) -1).toString();
 
                 ostr                                       << endl;
 
                 ostr << "a=\"" << first << "\""            << endl;
                 ostr << "while test \"$a\" != \"" << last << "\"; do" << endl;
 
-                ostr << "  add_addr ${a} " << nw->getNetmask().getLength() << " "
-                       << iface->getName() << endl;
+                ostr << "  add_addr ${a} " << nw->getNetmaskPtr()->getLength()
+                     << " " << iface->getName() << endl;
 
                 ostr                                       << endl;
                 ostr << "  OIFS=$IFS"                      << endl;
@@ -236,10 +235,11 @@ void OSConfigurator_linux24::addVirtualAddressForNAT(const Network *nw)
                 ostr << "  a=$a4\".\"$a3\".\"$a2\".\"$a1"  << endl;
 
                 ostr << "done" << endl << endl;
-                virtual_addresses.push_back(nw->getAddress());
+                virtual_addresses.push_back( *(nw->getAddressPtr()) );
                 registerVirtualAddressForNat();
             } else
-                warning(_("Can not add virtual address ") + nw->getAddress().toString() +
+                warning(_("Can not add virtual address ") +
+                        nw->getAddressPtr()->toString() +
                         _(" (object ") + nw->getName() + ")" );
         }
         commands_to_add_virtual_addresses.push_back(ostr.str());
@@ -254,22 +254,33 @@ void OSConfigurator_linux24::addVirtualAddressForNAT(const Address *addr)
     if ( options->getBool("manage_virtual_addr") ) 
     {
         if (virtual_addresses.empty() || 
-            find(virtual_addresses.begin(),virtual_addresses.end(),addr->getAddress())==virtual_addresses.end()) 
+            find(virtual_addresses.begin(),virtual_addresses.end(),
+                 *(addr->getAddressPtr())) == virtual_addresses.end()) 
         {
-            IPv4 *iaddr=IPv4::cast( findAddressFor(addr, fw ) );
-            if (iaddr!=NULL)
+            FWObject *vaddr = findAddressFor(addr, fw );
+            if (vaddr!=NULL)
             {
-                Interface *iface=Interface::cast(iaddr->getParent());
+                Interface *iface = Interface::cast(vaddr->getParent());
                 assert(iface!=NULL);
 
-                ostr << "add_addr " << addr->getAddress().toString() << " "
-                       << iaddr->getNetmask().getLength() <<  " "
-                       << iface->getName() << endl;
+                const InetAddr *vaddr_netm =
+                    Address::cast(vaddr)->getNetmaskPtr();
+
+//                const InetAddrMask *vaddr_addr = Address::cast(
+//                    vaddr)->getAddressObjectInetAddrMask();
+//                assert(vaddr_addr!=NULL);
+
+                ostr << "add_addr " << addr->getAddressPtr()->toString()
+                     << " "
+                     << vaddr_netm->getLength()
+                     <<  " "
+                     << iface->getName() << endl;
         
-                virtual_addresses.push_back(addr->getAddress());
+                virtual_addresses.push_back(*(addr->getAddressPtr()));
                 registerVirtualAddressForNat();
             } else
-                warning(_("Can not add virtual address ") + addr->getAddress().toString() +
+                warning(_("Can not add virtual address ") + 
+                        addr->getAddressPtr()->toString() +
                         _(" (object ") + addr->getName() + ")" );
         }
         commands_to_add_virtual_addresses.push_back(ostr.str());
@@ -358,14 +369,20 @@ void OSConfigurator_linux24::configureInterfaces()
             FWObjectTypedChildIterator j=iface->findByType(IPv4::TYPENAME);
             for ( ; j!=j.end(); ++j ) 
             {
-                IPv4 *iaddr=IPv4::cast(*j);
+                //const InetAddrMask *iaddr = Address::cast(*j)->getAddressObjectInetAddrMask();
+                const InetAddr *iaddr_addr =
+                    Address::cast(*j)->getAddressPtr();
+                const InetAddr *iaddr_netm =
+                    Address::cast(*j)->getNetmaskPtr();
 
-                output << "add_addr " << iaddr->getAddress().toString() << " "
-                       << iaddr->getNetmask().getLength() << " "
+                output << "add_addr " << iaddr_addr->toString()
+                       << " "
+                       << iaddr_netm->getLength()
+                       << " "
                        << iface->getName() << endl;
 // add to the table of virtual addresses so we won't generate code to
 // configure the same address if it is needed for NAT
-                virtual_addresses.push_back(iaddr->getAddress());
+                virtual_addresses.push_back(*iaddr_addr);
             }
             output << "$IP link set " << iface->getName() << " up" << endl;
         }
@@ -385,11 +402,18 @@ void OSConfigurator_linux24::configureInterfaces()
 /* if interface name ends with '*', this is a wildcard interface. Do
  * not get its address at this time. */
             if (iface->getName().find("*")==string::npos)
+            {
                 output << "getaddr "
                        << iface->getName()
                        << "  "
-                       << getInterfaceVarName(iface)
+                       << getInterfaceVarName(iface, false)
                        << endl;
+                output << "getaddr6 "
+                       << iface->getName()
+                       << "  "
+                       << getInterfaceVarName(iface, true)
+                       << endl;
+            }
         }
     }
     output << endl;
@@ -477,10 +501,12 @@ void  OSConfigurator_linux24::printShellFunctions()
     output << "  fi"                                        << endl;
     output << "}"                                           << endl;
     output << endl;
+
     output << "getInterfaceVarName() {"                     << endl;
     output << "  echo $1 | sed 's/\\./_/'"                  << endl;
     output << "}"                                           << endl;
     output << endl;
+
     output << "getaddr() {"                                 << endl;
     output << "  dev=$1"                                    << endl;
     output << "  name=$2"                                   << endl;
@@ -497,7 +523,8 @@ void  OSConfigurator_linux24::printShellFunctions()
  *  support for regular expressions. Using "grep -v :" seems to be an
  *  easy way to filter out secondary addresses without using regex
  */
-    output << "  L=`$IP -4 addr show dev $dev | grep inet | grep -v :`"   << endl;
+    output << "  L=`$IP -4 addr show dev $dev | grep inet | grep -v :`"
+           << endl;
     output << "  test -z \"$L\" && { "                      << endl;
     output << "    eval \"$name=''\""                       << endl;
     output << "    return"                                  << endl;
@@ -509,6 +536,25 @@ void  OSConfigurator_linux24::printShellFunctions()
     output << "  IFS=$OIFS"                                 << endl;
     output << "}"                                           << endl;
     output << endl;
+
+
+    output << "getaddr6() {"                                 << endl;
+    output << "  dev=$1"                                    << endl;
+    output << "  name=$2"                                   << endl;
+    output << "  L=`$IP -6 addr show dev $dev | grep inet6 | grep -v :`"
+           << endl;
+    output << "  test -z \"$L\" && { "                      << endl;
+    output << "    eval \"$name=''\""                       << endl;
+    output << "    return"                                  << endl;
+    output << "  }"                                         << endl;
+    output << "  OIFS=$IFS"                                 << endl;
+    output << "  IFS=\" /\""                                << endl;
+    output << "  set $L"                                    << endl;
+    output << "  eval \"$name=$2\""                         << endl;
+    output << "  IFS=$OIFS"                                 << endl;
+    output << "}"                                           << endl;
+    output << endl;
+
     output << endl;
 
 /* we use function getinterfaces to process wildcard interfaces */
@@ -570,7 +616,8 @@ string  OSConfigurator_linux24::printPathForAllTools(const string &os)
 
     FWOptions* options=fw->getOptionsObject();
     
-    string s, path_lsmod, path_modprobe, path_iptables, path_iptables_restore, path_ip, path_logger;
+    string s, path_lsmod, path_modprobe, path_iptables, path_ip6tables;
+    string path_iptables_restore, path_ip6tables_restore, path_ip, path_logger;
 
     s=options->getStr("linux24_path_lsmod");
     if (!s.empty()) path_lsmod=s;
@@ -584,10 +631,18 @@ string  OSConfigurator_linux24::printPathForAllTools(const string &os)
     if (!s.empty()) path_iptables=s;
     else            path_iptables=os_data.getPathForTool(os,OSData::IPTABLES);
 
+    s=options->getStr("linux24_path_ip6tables");
+    if (!s.empty()) path_ip6tables=s;
+    else            path_ip6tables=os_data.getPathForTool(os,OSData::IP6TABLES);
+
     s=options->getStr("linux24_path_iptables_restore");
     if (!s.empty()) path_iptables_restore=s;
     else            path_iptables_restore=os_data.getPathForTool(os,OSData::IPTABLES_RESTORE);
 
+    s=options->getStr("linux24_path_ip6tables_restore");
+    if (!s.empty()) path_ip6tables_restore=s;
+    else            path_ip6tables_restore=os_data.getPathForTool(os,OSData::IP6TABLES_RESTORE);
+
     s=options->getStr("linux24_path_ip");
     if (!s.empty()) path_ip=s;
     else            path_ip=os_data.getPathForTool(os,OSData::IP);
@@ -600,7 +655,9 @@ string  OSConfigurator_linux24::printPathForAllTools(const string &os)
     res += "LSMOD=\""   +path_lsmod+"\"\n";
     res += "MODPROBE=\""+path_modprobe+"\"\n";
     res += "IPTABLES=\""+path_iptables+"\"\n";
+    res += "IP6TABLES=\""+path_ip6tables+"\"\n";
     res += "IPTABLES_RESTORE=\""+path_iptables_restore+"\"\n";
+    res += "IP6TABLES_RESTORE=\""+path_ip6tables_restore+"\"\n";
     res += "IP=\""      +path_ip+"\"\n";
     res += "LOGGER=\""  +path_logger+"\"\n";
     res += "\n";
@@ -638,7 +695,8 @@ void OSConfigurator_linux24::generateCodeForProtocolHandlers(bool have_nat)
 }
 
 string  OSConfigurator_linux24::printRunTimeWrappers(FWObject *rule,
-                                                     const string &command)
+                                                     const string &command,
+                                                     bool ipv6)
 {
     string command_line = command;
     ostringstream  ext_command_line;
@@ -682,6 +740,9 @@ string  OSConfigurator_linux24::printRunTimeWrappers(FWObject *rule,
  */
     if (command_line.find("$i_")==string::npos) return command_line;
 
+    string getaddr_function_name = "getaddr";
+    if (ipv6) getaddr_function_name = "getaddr6";
+
     ostringstream  res;
     bool wildcard_interfaces = false;
     p1=0;
@@ -704,7 +765,7 @@ string  OSConfigurator_linux24::printRunTimeWrappers(FWObject *rule,
             string iface_family_name=iface_name.substr(0,p4);
             res << "getinterfaces " << iface_family_name << " | while read I; do" << endl;
             res << "  ivar=`getInterfaceVarName $I`" << endl;
-            res << "  getaddr $I $ivar" << endl;
+            res << "  " << getaddr_function_name << " $I $ivar" << endl;
             res << "  cmd=\"$\"$ivar"   << endl;
             res << "  eval \"addr=$cmd\""          << endl;
             cmdline.replace(p1,p2-p1,"$addr");
@@ -739,7 +800,7 @@ string  OSConfigurator_linux24::printRunTimeWrappers(FWObject *rule,
 
 void OSConfigurator_linux24::epilog()
 {
-    FWOptions* options=fw->getOptionsObject();
+    FWOptions* options = fw->getOptionsObject();
 
     try {
 	output << "#" << endl;
@@ -747,13 +808,24 @@ void OSConfigurator_linux24::epilog()
 
 /* Turn on packet forwarding if we have to */
 
-        string s=options->getStr("linux24_ip_forward");
+        string s = options->getStr("linux24_ip_forward");
         if (!s.empty())
         {
             if (s=="1" || s=="On" || s=="on") s="1";
             else                              s="0";
-            output << "echo " << s << " > /proc/sys/net/ipv4/ip_forward\n\n";
+            output << "echo " << s
+                   << " > /proc/sys/net/ipv4/ip_forward\n\n";
         }
+
+        s = options->getStr("linux24_ipv6_forward");
+        if (!s.empty())
+        {
+            if (s=="1" || s=="On" || s=="on") s="1";
+            else                              s="0";
+            output << "echo " << s
+                   << " > /proc/sys/net/ipv6/conf/all/forwarding\n\n";
+        }
+
 //        else
 //            output << "echo \"$FWD\" > /proc/sys/net/ipv4/ip_forward\n\n";
 
