@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSData.h,v 1.3 2004/10/25 04:23:14 vkurland Exp $
+  $Id: OSData.h 312 2008-07-05 17:40:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -40,7 +40,14 @@ class OSData {
 
     OSData(const std::string &ho) { host_os=ho; }
     
-    typedef enum { LSMOD, MODPROBE , IPTABLES , IPTABLES_RESTORE , IP , LOGGER } tools;
+    typedef enum { LSMOD,
+                   MODPROBE,
+                   IPTABLES,
+                   IP6TABLES,
+                   IPTABLES_RESTORE,
+                   IP6TABLES_RESTORE,
+                   IP,
+                   LOGGER } tools;
 
     std::string  getPathForTool(const std::string &distro,tools t);
 };
