@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_PrintRule.cpp 561 2008-10-02 11:31:03Z vadim $
+  $Id: PolicyCompiler_PrintRule.cpp 657 2008-11-21 06:40:07Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -407,7 +407,8 @@ string PolicyCompiler_ipt::PrintRule::_printDirectionAndInterface(PolicyRule *ru
         compiler->getCachedFwInterface(rule->getInterfaceId());
 
     if (rule_iface && rule_iface->isBridgePort() &&
-        XMLTools::version_compare(version, "1.3.0")>=0)
+        (version.empty() ||
+         XMLTools::version_compare(version, "1.3.0")>=0))
     {
         if (rule->getDirection()==PolicyRule::Inbound)   
             ostr << " -m physdev --physdev-in "  << iface_name; 
@@ -483,7 +484,7 @@ string PolicyCompiler_ipt::PrintRule::_printActionOnReject(libfwbuilder::PolicyR
                         str << " --reject-with icmp-net-prohibited";
                     if (s.find("host")!=string::npos)
                         str << " --reject-with icmp-host-prohibited";
-                    if (ipt_comp->newIptables(version) &&
+                    if (XMLTools::version_compare(version, "1.2.9")>=0 &&
                         s.find("admin")!=string::npos)
                         str << " --reject-with icmp-admin-prohibited";
                 }
@@ -503,38 +504,46 @@ string PolicyCompiler_ipt::PrintRule::_printLogPrefix(const string &rule_num,
 						      const string &action,
 						      const string &interf,
 						      const string &chain,
+                                                      const string &ruleset,
 						      const string &rule_label,
 						      const string &prefix)
 {
-    string s=prefix;
+    string s = prefix;
 
 /* deal with our logging macros:
  * %N - rule number  ('2', or '2/3' for rule in a branch)
  * %A - action
  * %I - interface name
  * %C - chain name
+ * %R - ruleset name
  */
     string::size_type n;
     if ((n=s.find("%N"))!=string::npos ) 
     {
-      s.replace(n,2,rule_num);
+      s.replace(n, 2, rule_num);
     }
     if ((n=s.find("%A"))!=string::npos ) 
     {
-      s.replace(n,2,action);
+      s.replace(n, 2, action);
     }
     if ((n=s.find("%I"))!=string::npos ) 
     {
-      s.replace(n,2,interf);
+      s.replace(n, 2, interf);
     }
     if ((n=s.find("%C"))!=string::npos ) 
     {
-      s.replace(n,2,chain);
+      s.replace(n, 2, chain);
+    }
+    if ((n=s.find("%R"))!=string::npos ) 
+    {
+      s.replace(n, 2, ruleset);
     }
 
     if (s.length()>29)
     {
-        compiler->warning(_("Log prefix has been truncated to 29 characters in rule ")+rule_label);
+        compiler->warning(
+            "Log prefix has been truncated to 29 characters in rule " + 
+            rule_label);
         s=s.substr(0,29);
     }
 
@@ -544,28 +553,31 @@ string PolicyCompiler_ipt::PrintRule::_printLogPrefix(const string &rule_num,
 string PolicyCompiler_ipt::PrintRule::_printLogPrefix(PolicyRule *rule,
                                                       const string &prefix)
 {
-  char action[64];
-  strncpy(action,rule->getStr("stored_action").c_str(),sizeof(action));
-  for (char *cptr=action; *cptr; cptr++)  *cptr=toupper(*cptr);
+    FWObject *ruleset = rule->getParent();
 
-  string rule_iface =  rule->getInterfaceStr();
-  if (rule_iface=="")  rule_iface = "global";
+    char action[64];
+    strncpy(action,rule->getStr("stored_action").c_str(),sizeof(action));
+    for (char *cptr=action; *cptr; cptr++)  *cptr=toupper(*cptr);
 
-  std::ostringstream s1;
-  int pos=rule->getPosition();
-  // parent_rule_num is set by processor "Branching" for branch rules
-  string ppos = rule->getStr("parent_rule_num");
+    string rule_iface =  rule->getInterfaceStr();
+    if (rule_iface=="")  rule_iface = "global";
 
-  if (ppos != "")
-      s1 << ppos << "/";
-  s1 << pos;
+    std::ostringstream s1;
+    int pos=rule->getPosition();
+    // parent_rule_num is set by processor "Branching" for branch rules
+    string ppos = rule->getStr("parent_rule_num");
 
-  return _printLogPrefix(s1.str(),
-			 action,
-			 rule_iface,
-			 rule->getStr("ipt_chain"),
-			 rule->getLabel(),
-			 prefix);
+    if (ppos != "")
+        s1 << ppos << "/";
+    s1 << pos;
+
+    return _printLogPrefix(s1.str(),
+                           action,
+                           rule_iface,
+                           rule->getStr("ipt_chain"),
+                           ruleset->getName(),
+                           rule->getLabel(),
+                           prefix);
 }
 
 string PolicyCompiler_ipt::PrintRule::_printLogParameters(PolicyRule *rule)
@@ -590,7 +602,7 @@ string PolicyCompiler_ipt::PrintRule::_printLogParameters(PolicyRule *rule)
         s=ruleopt->getStr("log_prefix");
         if (s.empty())  s=compiler->getCachedFwOpt()->getStr("log_prefix");
         if (!s.empty()) 
-            str << " --ulog-prefix " << _printLogPrefix(rule,s);
+            str << " --ulog-prefix " << _printLogPrefix(rule, s);
 
         int r=compiler->getCachedFwOpt()->getInt("ulog_cprange");
         if (r!=0)  str << " --ulog-cprange " << r << " ";
@@ -620,7 +632,7 @@ string PolicyCompiler_ipt::PrintRule::_printLogParameters(PolicyRule *rule)
         s=ruleopt->getStr("log_prefix");
         if (s.empty())  s=compiler->getCachedFwOpt()->getStr("log_prefix");
         if (!s.empty())
-            str << " --log-prefix " << _printLogPrefix(rule,s);
+            str << " --log-prefix " << _printLogPrefix(rule, s);
 
         if (ruleopt->getBool("log_tcp_seq") || compiler->getCachedFwOpt()->getBool("log_tcp_seq"))  
             str << " --log-tcp-sequence ";
@@ -682,7 +694,9 @@ string PolicyCompiler_ipt::PrintRule::_printProtocol(libfwbuilder::Service *srv)
             {
                 s = "-p ipv6-icmp ";
                 if (srv->getInt("type")!=-1 &&
-                    ipt_comp->newIptables(version)) s += " -m icmp6";
+                    (version.empty() ||
+                     XMLTools::version_compare(version, "1.3.0")>=0))
+                    s += " -m icmp6";
             } else
             {
                 // ip6tables issues warning for commands using "-p all"
@@ -701,7 +715,9 @@ string PolicyCompiler_ipt::PrintRule::_printProtocol(libfwbuilder::Service *srv)
             if (ICMPService::isA(srv))
             {
                 s = "-p icmp ";
-                if (ipt_comp->newIptables(version)) s += " -m icmp ";
+                if (version.empty() ||
+                    XMLTools::version_compare(version, "1.2.9")>=0)
+                    s += " -m icmp ";
             } else
             {
                 s = "-p " + pn + " ";
@@ -880,8 +896,11 @@ string PolicyCompiler_ipt::PrintRule::_printSrcService(RuleElementSrv  *rel)
     Service *srv= Service::cast(o);
 
 
-    if (rel->size()==1) {
-	if (UDPService::isA(srv) || TCPService::isA(srv)) {
+    if (rel->size()==1)
+    {
+	if (UDPService::isA(srv) || TCPService::isA(srv) ||
+            TagService::isA(srv))
+        {
 	    string str=_printSrcPorts( srv );
 	    if (! str.empty() ) 
             {
@@ -889,7 +908,8 @@ string PolicyCompiler_ipt::PrintRule::_printSrcService(RuleElementSrv  *rel)
                 ostr  << _printSingleObjectNegation(rel) << str << " ";
             }
 	}
-    } else {
+    } else
+    {
 /* use multiport */
 
 	string str;
@@ -933,7 +953,7 @@ string PolicyCompiler_ipt::PrintRule::_printDstService(RuleElementSrv  *rel)
 
     if (rel->size()==1) 
     {
-	if (UDPService::isA(srv) || TCPService::isA(srv)) 
+	if (UDPService::isA(srv) || TCPService::isA(srv))
         {
 	    string str=_printDstPorts( srv );
 	    if (! str.empty() )
@@ -960,7 +980,9 @@ string PolicyCompiler_ipt::PrintRule::_printDstService(RuleElementSrv  *rel)
 	    if (str.empty() ) 
             {
                 // module icmp6 does not like "--icmp6-type any"
-                if (ipt_comp->newIptables(version) && !ipt_comp->ipv6)
+                if ((version.empty() ||
+                     XMLTools::version_compare(version, "1.2.6")>0) &&
+                    !ipt_comp->ipv6)
                     ostr << icmp_type_str << " any ";
             } else
             {
@@ -986,12 +1008,16 @@ string PolicyCompiler_ipt::PrintRule::_printDstService(RuleElementSrv  *rel)
 	}
         if (TagService::isA(srv))
         {
-	    ostr << "-m mark --mark "
+	    ostr << "-m mark "
+                 << _printSingleObjectNegation(rel) 
+                 << "--mark "
                  << TagService::constcast(srv)->getCode() << " ";
         }
         if (UserService::isA(srv))
         {
-	    ostr << "-m owner --uid-owner "
+	    ostr << "-m owner "
+                 << _printSingleObjectNegation(rel)
+                 << "--uid-owner "
                  << UserService::cast(srv)->getUserId() << " ";
         }
     } else 
@@ -1091,7 +1117,8 @@ string PolicyCompiler_ipt::PrintRule::_printAddr(Address  *o)
 }
 
 
-string PolicyCompiler_ipt::PrintRule::_printSingleObjectNegation(RuleElement *rel)
+string PolicyCompiler_ipt::PrintRule::_printSingleObjectNegation(
+    RuleElement *rel)
 {
     if (rel->getBool("single_object_negation"))   return "! ";
     else return "";
@@ -1120,7 +1147,7 @@ string PolicyCompiler_ipt::PrintRule::_printTimeInterval(PolicyRule *r)
     int emin, ehour, eday, emonth, eyear, edayofweek;
     string days_of_week;
 
-    Interval *interval=compiler->getFirstWhen(r);
+    Interval *interval = compiler->getFirstWhen(r);
     assert(interval!=NULL);
 
     interval->getStartTime( &smin, &shour, &sday, &smonth, &syear, &sdayofweek);
@@ -1133,15 +1160,12 @@ string PolicyCompiler_ipt::PrintRule::_printTimeInterval(PolicyRule *r)
     if (ehour<0) ehour=23;
     if (emin<0)  emin=59;
 
-
     ostr << "-m time ";
 
     bool use_timestart_timestop = true;
 
+    string version = compiler->fw->getStr("version");
 
-    string version=compiler->fw->getStr("version");
-
-//    if (version == "1.4.0")
     if (XMLTools::version_compare(version, "1.4.0")>=0)
     {
         // in 1.4.0 date format has changed, it is now ISO 8601
@@ -1169,11 +1193,12 @@ string PolicyCompiler_ipt::PrintRule::_printTimeInterval(PolicyRule *r)
             use_timestart_timestop = false;
         }
 
-        if (use_timestart_timestop )
+        if (use_timestart_timestop)
         {
             ostr << " --timestart "
                  << setw(2) << setfill('0') << shour << ":"
                  << setw(2) << setfill('0') << smin  << " ";
+
             ostr << " --timestop "
                  << setw(2) << setfill('0') << ehour << ":"
                  << setw(2) << setfill('0') << emin  << " ";
@@ -1198,65 +1223,42 @@ string PolicyCompiler_ipt::PrintRule::_printTimeInterval(PolicyRule *r)
 
     } else
     {
-        if (sday>0 && smonth>0 && syear>0)
+        /* "old" iptables time module
+
+TIME v1.2.11 options:
+ --timestart value --timestop value --days listofdays
+          timestart value : HH:MM
+          timestop  value : HH:MM
+          listofdays value: a list of days to apply -> ie. Mon,Tue,Wed,Thu,Fri.
+          Case sensitive
+
+         */
+
+        ostr << " --timestart "
+             << setw(2) << setfill('0') << shour << ":"
+             << setw(2) << setfill('0') << smin  << " ";
+
+        ostr << " --timestop "
+             << setw(2) << setfill('0') << ehour << ":"
+             << setw(2) << setfill('0') << emin  << " ";
+
+        if (!days_of_week.empty() && days_of_week != "0,1,2,3,4,5,6")
         {
-            ostr << "--datestart " 
-                 << setw(2) << setfill('0') << syear << ":" 
-                 << setw(2) << setfill('0') << smonth << ":" 
-                 << setw(2) << setfill('0') << sday  << ":"
-                 << setw(2) << setfill('0') << shour << ":"
-                 << setw(2) << setfill('0') << smin << ":00 ";
-            use_timestart_timestop = false;
-        }
-
-        if (eday>0 && emonth>0 && eyear>0)
-        {
-            ostr << "--datestop "
-                 << setw(2) << setfill('0') << eyear << ":"
-                 << setw(2) << setfill('0') << emonth << ":"
-                 << setw(2) << setfill('0') << eday  << ":"
-                 << setw(2) << setfill('0') << ehour << ":"
-                 << setw(2) << setfill('0') << emin << ":00 ";
-            use_timestart_timestop = false;
-        }
-
-
-        if (use_timestart_timestop )
-        {
-            ostr << " --timestart "
-                 << setw(2) << setfill('0') << shour << ":"
-                 << setw(2) << setfill('0') << smin  << " ";
-            ostr << " --timestop "
-                 << setw(2) << setfill('0') << ehour << ":"
-                 << setw(2) << setfill('0') << emin  << " ";
-
-            if (sdayofweek<0) sdayofweek=0;
-            if (sdayofweek>6) sdayofweek=6;
-
-            // if both start and end day are -1, need to
-            // generate "sun,mon,tue,wed,thu,fri,sat"
-            if (edayofweek<0) edayofweek=6;
-            if (edayofweek>6) edayofweek=6;
-
             ostr << " --days ";
-            first=true;
-
-            bool inside_interval = false;
-            int  day=0;
-            while (1)
+            istringstream istr(days_of_week);
+            bool first= true;
+            while (!istr.eof())
             {
-                if (!inside_interval && day==sdayofweek) inside_interval=true;
-                if (inside_interval)
-                {
-                    if (!first) ostr << ",";
-                    first=false;
-                    ostr << daysofweek[day];
-                    // if sdayofweek==edayofweek print one day
-                    if (day==edayofweek)  break;
-                }
-                if (++day>6) day=0;
+                if (!first) ostr << ',';
+                first = false;
+                int d;
+                istr >> d;
+                ostr << daysofweek[d];
+                char sep;
+                istr >> sep;
             }
         }
+
     }
     return ostr.str();
 }
@@ -1686,9 +1688,16 @@ string PolicyCompiler_ipt::PrintRule::_printOptionalGlobalRules()
 	    if (s.empty())
 	        s = "INVALID state -- DENY ";
 
-	    res << _printLogPrefix("-1", "DENY","global","drop_invalid","BLOCK INVALID",s)
+	    res << _printLogPrefix("-1",
+                                   "DENY",
+                                   "global",
+                                   "drop_invalid",
+                                   "Policy",
+                                   "BLOCK INVALID",
+                                   s)
 	        << _endRuleLine()
-                << _startRuleLine() << "drop_invalid  -j DROP" << _endRuleLine();
+                << _startRuleLine() << "drop_invalid  -j DROP"
+                << _endRuleLine();
  
 	}
         res << endl;
