@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipt.h 474 2008-08-18 03:05:45Z vadim $
+  $Id: PolicyCompiler_ipt.h 657 2008-11-21 06:40:07Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -75,10 +75,14 @@ namespace fwcompiler {
         bool                           have_connmark;
         bool                           have_connmark_in_output;
         std::string                    my_table;
+        std::list<std::string>         mangle_only_rulesets;
 
         std::map<std::string, int>     tmp_chain_no;
         std::map<std::string, int>     chain_usage_counter;
 
+        typedef std::list<std::string> chain_list;
+        std::map<std::string, chain_list*> chains;
+
         // use minus_n_commands map to track creation of chains.
         // Using external map object for this to be able to track
         // new chains across different compiler runs (used to process
@@ -86,7 +90,17 @@ namespace fwcompiler {
         std::map<const std::string, bool> *minus_n_commands;
 
         static const std::list<std::string>& getStandardChains();
-        
+
+        void registerChain(const std::string &chain_name);
+        void insertUpstreamChain(const std::string &chain_name,
+                                 const std::string &before_chain);
+        std::string findUpstreamChain(const std::string &chain_name);
+        void setChain(libfwbuilder::PolicyRule *rule,
+                      const std::string &chain_name);
+        std::string printChains(libfwbuilder::PolicyRule *rule);
+        bool isChainDescendantOfOutput(const std::string &chain_name);
+        bool isChainDescendantOfInput(const std::string &chain_name);
+
         PolicyCompiler_ipt::PrintRule* createPrintRuleProcessor();
 
         std::string getInterfaceVarName(libfwbuilder::FWObject *iface,
@@ -120,6 +134,19 @@ namespace fwcompiler {
          */
         virtual std::string debugPrintRule(libfwbuilder::Rule *rule);
 
+        /**
+         * trivial rule processor - just prints contents of src, dst, srv
+         */ 
+        class printRuleElements : public PolicyRuleProcessor
+        {
+            std::string printRE(libfwbuilder::RuleElement *re);
+            public:
+            printRuleElements(const std::string &name) : PolicyRuleProcessor(name) 
+            {}
+            virtual bool processNext();
+        };
+        friend class printRuleElements;
+        
         /**
          * this processor drops all rules that require mangle table
          */
@@ -706,6 +733,8 @@ namespace fwcompiler {
 	 */
         DECLARE_POLICY_RULE_PROCESSOR(separatePortRanges);
 
+        DECLARE_POLICY_RULE_PROCESSOR(separateUserServices);
+        
 	/**
 	 * separate TCP/UDP services that specify source port (can
 	 * not be used in combination with destination port with
@@ -873,6 +902,7 @@ namespace fwcompiler {
 						const std::string &action,
 						const std::string &interf,
 						const std::string &chain,
+                                                const std::string &ruleset,
 						const std::string &rule_label,
 						const std::string &prefix);
             virtual std::string _printLogPrefix(libfwbuilder::PolicyRule *r,
@@ -994,6 +1024,10 @@ namespace fwcompiler {
 	std::string getNewTmpChainName(libfwbuilder::PolicyRule *rule);
 	std::string getNewChainName(libfwbuilder::PolicyRule *rule,libfwbuilder::Interface *rule_iface);
 
+        bool haveConnMarkRules() { return have_connmark; }
+        bool haveConnMarkRulesInOutput() { return have_connmark_in_output; }
+
+        bool isMangleOnlyRuleSet(const std::string &rule_set_name);
     };
 
 
