@@ -6,22 +6,25 @@
 
   Author:  Tidei Maurizio     <fwbuilder-routing at compal.de>
   
-  Permission is hereby granted, free of charge, to any person obtaining a copy
-  of this software and associated documentation files (the "Software"), to deal
-  in the Software without restriction, including without limitation the rights
-  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
-  of the Software, and to permit persons to whom the Software is furnished to do
-  so, subject to the following conditions: 
+  Permission is hereby granted, free of charge, to any person
+  obtaining a copy of this software and associated documentation files
+  (the "Software"), to deal in the Software without restriction,
+  including without limitation the rights to use, copy, modify, merge,
+  publish, distribute, sublicense, and/or sell copies of the Software,
+  and to permit persons to whom the Software is furnished to do so,
+  subject to the following conditions:
 
-  The above copyright notice and this permission notice shall be included in all
-  copies or substantial portions of the Software. 
+  The above copyright notice and this permission notice shall be
+  included in all copies or substantial portions of the Software.
 
-  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
-  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
-  PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
-  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
-  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
+  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
+  BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
+  ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+  SOFTWARE.
 
 */
 
@@ -78,15 +81,12 @@ string RoutingCompiler_ipt::PrintRule::_printAddr(Address  *o)
         return ostr.str();
     }
 
-    IPAddress addr;
-    Netmask   mask;
-    try {
-        addr=o->getAddress();
+    const InetAddr *addr;
+    const InetAddr *mask;
+    addr = o->getAddressPtr();
+    mask = o->getNetmaskPtr();
 
-        if (Interface::cast(o)!=NULL || IPv4::cast(o)!=NULL) mask=Netmask("255.255.255.255");
-        else            mask=o->getNetmask();
-    }
-    catch (FWException ex)  
+    if (addr==NULL)
     {
         FWObject *obj=o;
 /*
@@ -100,20 +100,22 @@ string RoutingCompiler_ipt::PrintRule::_printAddr(Address  *o)
                !Firewall::isA(obj)  && 
                !Network::isA(obj))  obj=obj->getParent();
 
-        compiler->error(_("Problem with address or netmask in the object or one of its interfaces: '")+obj->getName()+"'");
-        throw;
+        compiler->abort(_("Problem with address or netmask in the object or one of its interfaces: '")+obj->getName()+"'");
     }
 
 
-    if (addr.toString()=="0.0.0.0" && mask.toString()=="0.0.0.0") 
+    if (addr->isAny() && mask->isAny()) 
     {
         ostr << "default ";
     } else 
     {
-        ostr << addr.toString();
-        if (mask.toString()!="255.255.255.255") 
+        ostr << addr->toString();
+
+        if (Interface::cast(o)==NULL &&
+            Address::cast(o)->dimension() > 1 &&
+            !mask->isHostMask())
         {
-            ostr << "/" << mask.getLength();
+            ostr << "/" << mask->getLength();
         }
         ostr << " ";
     }
@@ -161,7 +163,7 @@ bool RoutingCompiler_ipt::PrintRule::processNext()
         compiler->output << "oldRoutes=$($IP route show | sort -k 2)" << endl << endl;
         
         compiler->output << "echo \"Deleting routing rules previously set by user space processes...\"" << endl;
-        compiler->output << "$IP route show | grep -v ' proto kernel ' | while read route ; do $IP route del $route ; done\n" << endl;
+        compiler->output << "$IP route show | grep -v '\\( proto kernel \\)\\|\\(default via \\)'  | while read route ; do $IP route del $route ; done\n" << endl;
         
         compiler->output << "echo \"Activating non-ecmp routing rules...\"" << endl << endl;
                 
@@ -307,7 +309,7 @@ string RoutingCompiler_ipt::PrintRule::_printRItf(RoutingRule *rule)
     ref=itfrel->front();
     Interface *itf=Interface::cast(FWReference::cast(ref)->getPointer());
     
-    if(itf != NULL) return "dev " + itf->getStr("name") + " ";
+    if(itf != NULL) return "dev " + itf->getName() + " ";
     else return "";
 }
 
