@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland <vadim@vk.crocodile.org>
 
-  $Id: combinedAddress.h,v 1.2 2006/09/11 00:41:09 vkurland Exp $
+  $Id: combinedAddress.h 312 2008-07-05 17:40:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -48,6 +48,10 @@ class combinedAddress : public IPv4
     combinedAddress(const FWObject *root,bool prepopulate);
     virtual ~combinedAddress();
 
+    virtual FWObject& shallowDuplicate(const FWObject *obj,
+                                       bool preserve_id = true)
+        throw(FWException);
+    
     std::string getPhysAddress() const;
     void setPhysAddress(const std::string &s);
 
