@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: ipt.cpp 482 2008-08-22 15:13:00Z vadim $
+  $Id: ipt.cpp 674 2008-11-28 18:05:31Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -71,6 +71,13 @@
 #include "fwbuilder/IPv4.h"
 #include "fwbuilder/IPv6.h"
 
+#include <QApplication>
+#include <QStringList>
+#include <QFileInfo>
+#include <QFile>
+#include <QTextStream>
+#include <QTextCodec>
+
 #ifdef HAVE_GETOPT_H
   #include <getopt.h>
 #else
@@ -89,10 +96,10 @@ using namespace fwcompiler;
 
 int fwbdebug = 0;
 
-static const char      *filename       = NULL;
-static const char      *wdir           = NULL;
-static const char      *fwobjectname   = NULL;
-static string           fw_file_name   = "";
+static string           filename;
+static string           wdir;
+static QString          fwobjectname;
+static QString          fw_file_name;
 static int              dl             = 0;
 static int              drp            = -1;
 static bool             omit_timestamp = false;
@@ -102,17 +109,31 @@ static bool             have_dynamic_interfaces = false;
 static bool             test_mode      = false;
 static bool             ipv4_run       = true;
 static bool             ipv6_run       = true;
+static bool             fw_by_id       = false;
 
-FWObjectDatabase       *objdb = NULL;
+FWObjectDatabase *objdb = NULL;
 
 static map<string,RuleSet*> branches;
 
+QTextStream& operator<< (QTextStream &text_stream, const string &str)
+{
+    text_stream << str.c_str();
+    return text_stream;
+}
+
+
+#ifdef _WIN32
+string fs_separator = "\\";
+#else
+string fs_separator = "/";
+#endif
+
 class UpgradePredicate: public XMLTools::UpgradePredicate
 {
     public:
     virtual bool operator()(const string&) const 
     { 
-	cout << _("Data file has been created in the old version of Firewall Builder. Use fwbuilder GUI to convert it.") << endl;
+	cout << _("Data file has been created in the old version of Firewall Builder. Use fwbuilder GUI to convert it.") << std::endl;
 	return false;
     }
 };
@@ -238,21 +259,35 @@ string dumpScript(bool nocomm, Firewall *fw,
                 nocomm, fw->getOptionsObject()->getStr("prolog_script"));
         }
 
-        if (!filter_script.empty())  script << filter_script;
-        if (!mangle_script.empty()) script << mangle_script;
-        if (!nat_script.empty()) script << nat_script;
+        if (!filter_script.empty())
+        {
+            script << filter_script;
+            script << "echo COMMIT\n";
+        }
+
+        if (!mangle_script.empty())
+        {
+            script << mangle_script;
+            script << "echo COMMIT\n";
+        }
+
+        if (!nat_script.empty())
+        {
+            script << nat_script;
+            script << "echo COMMIT\n";
+        }
 
         if (script.tellp() > 0)
         {
-            res << "(" << endl;
+            res << "(" << "\n";
             res << script.str();
-            res << "#" << endl;
+            res << "#" << "\n";
             if (ipv6_policy)
                 res << ") | $IP6TABLES_RESTORE; IPTABLES_RESTORE_RES=$?"
-                    << endl;
+                    << "\n";
             else
                 res << ") | $IPTABLES_RESTORE; IPTABLES_RESTORE_RES=$?"
-                    << endl;
+                    << "\n";
         }
         return res.str();
     } else
@@ -272,6 +307,148 @@ string dumpScript(bool nocomm, Firewall *fw,
 
     return res.str();
 }
+ 
+bool processPolicyRuleSet(
+    const QString &fwobjectname,
+    FWObject *ruleset,
+    ostringstream &filter_table_stream,
+    ostringstream &mangle_table_stream,
+    ostringstream &reset_rules_stream,
+    OSConfigurator_linux24 *oscnf,
+    bool ipv6_policy,
+    std::map<const std::string, bool> &minus_n_commands_filter,
+    std::map<const std::string, bool> &minus_n_commands_mangle)
+{
+    int policy_rules_count  = 0;
+    int mangle_rules_count  = 0;
+    bool have_connmark = false;
+    bool have_connmark_in_output = false;
+    bool empty_output = true;
+
+    Policy *policy = Policy::cast(ruleset);
+    assignRuleSetChain(policy);
+    string branch_name = policy->getName();
+
+    if (policy->isV6()!=ipv6_policy) return true;
+
+    MangleTableCompiler_ipt m(
+        objdb , fwobjectname.toUtf8().constData(),
+        ipv6_policy , oscnf,
+        &minus_n_commands_mangle );
+
+    if (!policy->isTop())
+        m.registerRuleSetChain(branch_name);
+
+    m.setSourceRuleSet( policy );
+    m.setRuleSetName(branch_name);
+
+    m.setDebugLevel( dl );
+    m.setDebugRule(  drp );
+    m.setVerbose( (bool)(verbose) );
+    m.setHaveDynamicInterfaces(have_dynamic_interfaces);
+    if (test_mode) m.setTestMode();
+
+    if ( (mangle_rules_count = m.prolog()) > 0 )
+    {
+        m.compile();
+        m.epilog();
+
+        // We need to generate automatic rules in mangle
+        // table (-j CONNMARK --restore-mark) if CONNMARK
+        // target is present in any ruleset, not only in
+        // the top-level ruleset. So we keep global
+        // boolean flags for this condition which will
+        // become true if any ruleset has such
+        // rules. We'll call
+        // MangleTableCompiler_ipt::flushAndSetDefaultPolicy
+        // later if either of these flags is true after
+        // all rulesets have been processed.
+
+        have_connmark |= m.haveConnMarkRules();
+        have_connmark_in_output |= m.haveConnMarkRulesInOutput();
+
+        long m_str_pos = mangle_table_stream.tellp();
+
+        if (policy->isTop())
+        {
+            mangle_table_stream << "# ================ Table 'mangle', ";
+            mangle_table_stream << "automatic rules";
+            mangle_table_stream << "\n";
+            mangle_table_stream << m.flushAndSetDefaultPolicy();
+        }
+
+        if (m.getCompiledScriptLength() > 0)
+        {
+            mangle_table_stream << "# ================ Table 'mangle', rule set "
+                  << branch_name << "\n";
+            if (m.haveErrorsAndWarnings())
+            {
+                mangle_table_stream << "# Policy compiler errors and warnings:"
+                      << "\n";
+                mangle_table_stream << m.getErrors("# ");
+            }
+
+            mangle_table_stream << m.getCompiledScript();
+        }
+
+        if (m_str_pos!=mangle_table_stream.tellp())
+        {
+            //mangle_table_stream << m.commit();
+            mangle_table_stream << "\n";
+            empty_output = false;
+        }
+    }
+
+    PolicyCompiler_ipt c(
+        objdb,fwobjectname.toUtf8().constData(), ipv6_policy, oscnf,
+        &minus_n_commands_filter);
+
+    if (!policy->isTop())
+        c.registerRuleSetChain(branch_name);
+
+    c.setSourceRuleSet( policy );
+    c.setRuleSetName(branch_name);
+
+    c.setDebugLevel( dl );
+    c.setDebugRule(  drp );
+    c.setVerbose( (bool)(verbose) );
+    c.setHaveDynamicInterfaces(have_dynamic_interfaces);
+    if (test_mode) c.setTestMode();
+
+    if ( (policy_rules_count=c.prolog()) > 0 )
+    {
+        c.compile();
+        c.epilog();
+
+        if (c.getCompiledScriptLength() > 0)
+        {
+            filter_table_stream << "# ================ Table 'filter', rule set "
+                  << branch_name << "\n";
+            if (c.haveErrorsAndWarnings())
+            {
+                filter_table_stream << "# Policy compiler errors and warnings:"
+                      << "\n";
+                filter_table_stream << c.getErrors("# ");
+            }
+            filter_table_stream << c.getCompiledScript();
+            //filter_table_stream << c.commit();
+            filter_table_stream << "\n";
+            empty_output = false;
+        }
+    }
+
+    if (policy->isTop())
+    {
+        reset_rules_stream
+            << "# ================ Table 'filter', automatic rules"
+            << "\n";
+        reset_rules_stream << c.flushAndSetDefaultPolicy();
+        empty_output = false;
+    }
+
+    return empty_output;
+}
+
 
 void usage(const char *name)
 {
@@ -283,102 +460,126 @@ void usage(const char *name)
             "[-m] [-4|-6] firewall_object_name" << endl;
 }
 
-int main(int argc, char * const *argv)
+int main(int argc, char **argv)
 {   
+    QApplication app(argc, argv, false);
 
-#ifdef ENABLE_NLS
-    setlocale (LC_ALL, "");
+    // compilers always write file names into manifest in Utf8
+    QTextCodec::setCodecForCStrings(QTextCodec::codecForName("Utf8"));
+    QTextCodec::setCodecForLocale(QTextCodec::codecForName("Utf8"));
 
-    bindtextdomain (PACKAGE, LOCALEDIR);
-    textdomain (PACKAGE);
-#else
-#  ifdef HAVE_SETLOCALE
-    setlocale (LC_ALL, "");
-#  endif
-#endif
-    
+    QStringList args = app.arguments();
 
-    if (argc<=1)
+    if (args.size()<=1)
     {
         usage(argv[0]);
         exit(1);
     }
 
-    int   opt;
+    QString last_arg;
 
-    while( (opt=getopt(argc,argv,"x:vVqf:d:r:o:46")) != EOF )
+    for (int idx=0; idx < args.size(); idx++)
     {
-        switch(opt)
+        QString arg = args.at(idx);
+
+        last_arg = arg;
+        if (arg == "-i")
+        {
+            fw_by_id = true;
+            continue;
+        }
+        if (arg == "-v")
         {
-        case '4':
-            ipv4_run = true;
-            ipv6_run = false;
-            break;
-        case '6':
-            ipv4_run = false;
-            ipv6_run = true;
-            break;
-        case 'd':
-            wdir = strdup(optarg);
-            break;
-        case 'r':
-            respath = string(optarg);
-            break;
-        case 'f':
-            filename = strdup(optarg);
-            break;
-        case 'o':
-            fw_file_name = string(optarg);
-            break;
-        case 'x':
-            if (*optarg=='t') {
-                test_mode = true;
-            } else if (*optarg=='p') {
-                ++optarg;
-                drp  = atoi(optarg);
-            } else {
-                if (*optarg=='n') {
-                    ++optarg;
-                    drn  = atoi(optarg);
-                } else {
-                    if (isdigit(*optarg))  dl=atoi(optarg);  // increase debug level
-                    else {
-                        usage(argv[0]);
-                        exit(1);
-                    }
-                }
-            }
-            break;
-        case 'v':
             verbose++;
-            break;
-        case 'V':
+            continue;
+        }
+        if (arg == "-V")
+        {
             usage(argv[0]);
             exit(1);
-        case 'q':
+        }
+        if (arg == "-q")
+        {
             omit_timestamp = true;
-            break;
+            continue;
+        }
+
+        if (arg == "-4")
+        {
+            ipv4_run = true;
+            ipv6_run = false;
+            continue;
+        }
+        if (arg == "-6")
+        {
+            ipv4_run = false;
+            ipv6_run = true;
+            continue;
+        }
+        if (arg == "-d")
+        {
+            idx++;
+            wdir = string(args.at(idx).toLatin1().constData());
+            continue;
+        }
+        if (arg == "-f")
+        {
+            idx++;
+            filename = string(args.at(idx).toLatin1().constData());
+            continue;
+        }
+        if (arg == "-r")
+        {
+            idx++;
+            respath = string(args.at(idx).toLatin1().constData());
+            continue;
+        }
+        if (arg == "-o")
+        {
+            idx++;
+            fw_file_name = args.at(idx);
+            continue;
+        }
+        if (arg == "-xt")
+        {
+            test_mode = true;
+            continue;
+        }
+        if (arg == "-xp")
+        {
+            idx++;
+            bool ok = false;
+            drp = args.at(idx).toInt(&ok);
+            if (!ok)
+            {
+                usage(argv[0]);
+                exit(1);
+            }
+            continue;
+        }
+        if (arg == "-xn")
+        {
+            idx++;
+            bool ok = false;
+            drn = args.at(idx).toInt(&ok);
+            if (!ok)
+            {
+                usage(argv[0]);
+                exit(1);
+            }
+            continue;
         }
     }
-    
-    if((argc-1) != optind)
-    {
-        usage(argv[0]);
-        exit(1);
-    }
 
-    fwobjectname = strdup( argv[optind++] );
+    fwobjectname = last_arg;
 
-    if (fw_file_name.empty())
-        fw_file_name=string(fwobjectname)+".fw";
-
-    if (wdir==0) 	wdir="./";
+    if (wdir.empty()) wdir="./";
 
     if (
 #ifdef _WIN32
-    _chdir(wdir)
+        _chdir(wdir.c_str())
 #else
-    chdir(wdir)
+        chdir(wdir.c_str())
 #endif
     ) {
 	cerr << _("Can't change to: ") << wdir << endl;
@@ -418,10 +619,25 @@ int main(int argc, char * const *argv)
         if (slib && slib->isReadOnly()) slib->setReadOnly(false);
 
 	/* Review firewall and OS options and generate commands */
-	Firewall*  fw = objdb->findFirewallByName(fwobjectname);
+
+	Firewall* fw;
+        if (fw_by_id)
+        {
+            // fwobjectname is actually object id
+            fw = Firewall::cast(
+                objdb->findInIndex(
+                    objdb->getIntId(fwobjectname.toAscii().constData())));
+            fwobjectname = fw->getName().c_str();
+        }
+        else
+            fw = objdb->findFirewallByName(fwobjectname.toUtf8().constData());
+
 	FWOptions* options = fw->getOptionsObject();
 	string s;
 
+        if (fw_file_name.isEmpty())
+            fw_file_name = fwobjectname + ".fw";
+
         /* some initial sanity checks */
 
         list<FWObject*> l2 = fw->getByType(Interface::TYPENAME);
@@ -546,7 +762,8 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
         if (fw_version.empty()) fw_version = "(any version)";
 
         if ( family=="linux24" )
-            oscnf = new OSConfigurator_linux24(objdb , fwobjectname, false);
+            oscnf = new OSConfigurator_linux24(
+                objdb , fwobjectname.toUtf8().constData(), false);
 
 	if (oscnf==NULL)
 	    throw FWException(_("Unrecognized host OS ")+fw->getStr("host_OS")+"  (family "+family+")");
@@ -562,8 +779,6 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
         list<FWObject*> all_policies = fw->getByType(Policy::TYPENAME);
         list<FWObject*> all_nat = fw->getByType(NAT::TYPENAME);
 
-        int policy_rules_count  = 0;
-        int mangle_rules_count  = 0;
         int nat_rules_count     = 0;
         int routing_rules_count = 0;
         bool have_nat = false;
@@ -635,6 +850,8 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
                 if (nat->isV6()==ipv6_policy) nat_count++;
             }
 
+            
+
             for (list<FWObject*>::iterator p=all_policies.begin();
                  p!=all_policies.end(); ++p)
             {
@@ -645,7 +862,7 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
             if (nat_count || policy_count)
             {
                 Preprocessor* prep = new Preprocessor(
-                    objdb , fwobjectname, ipv6_policy);
+                    objdb , fwobjectname.toUtf8().constData(), ipv6_policy);
                 if (test_mode) prep->setTestMode();
                 prep->compile();
             }
@@ -655,6 +872,7 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
             ostringstream m_str;
             ostringstream n_str;
             bool empty_output = true;
+            //MangleTableCompiler_ipt *top_level_mangle_compiler = NULL;
 
             for (list<FWObject*>::iterator p=all_nat.begin();
                  p!=all_nat.end(); ++p )
@@ -668,8 +886,9 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
                 // compile NAT rules before policy rules because policy
                 // compiler needs to know the number of virtual addresses
                 // being created for NAT
-                NATCompiler_ipt n(objdb, fwobjectname, ipv6_policy, oscnf,
-                                  &minus_n_commands_nat);
+                NATCompiler_ipt n(
+                    objdb, fwobjectname.toUtf8().constData(), ipv6_policy, oscnf,
+                    &minus_n_commands_nat);
                 n.setSourceRuleSet( nat );
                 n.setRuleSetName(branch_name);
 
@@ -690,12 +909,12 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
                 if (n.getCompiledScriptLength() > 0)
                 {
                     n_str << "# ================ Table 'nat', rule set "
-                          << branch_name << endl;
+                          << branch_name << "\n";
 
                     if (n.haveErrorsAndWarnings())
                     {
                         n_str << "# NAT compiler errors and warnings:"
-                              << endl;
+                              << "\n";
                         n_str << n.getErrors("# ");
                     }
 
@@ -703,8 +922,8 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
                         n_str << n.flushAndSetDefaultPolicy();
 
                     n_str << n.getCompiledScript();
-                    n_str << n.commit();
-                    n_str << endl;
+                    //n_str << n.commit();
+                    n_str << "\n";
                     empty_output = false;
                 }
             }
@@ -712,112 +931,18 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
             for (list<FWObject*>::iterator p=all_policies.begin();
                  p!=all_policies.end(); ++p )
             {
-                Policy *policy = Policy::cast(*p);
-                assignRuleSetChain(policy);
-                string branch_name = policy->getName();
-
-                if (policy->isV6()!=ipv6_policy) continue;
-
-                MangleTableCompiler_ipt m(
-                    objdb , fwobjectname, ipv6_policy , oscnf,
-                    &minus_n_commands_mangle );
-
-                if (!policy->isTop())
-                    m.registerRuleSetChain(branch_name);
-
-                m.setSourceRuleSet( policy );
-                m.setRuleSetName(branch_name);
-
-                m.setDebugLevel( dl );
-                m.setDebugRule(  drp );
-                m.setVerbose( (bool)(verbose) );
-                m.setHaveDynamicInterfaces(have_dynamic_interfaces);
-                if (test_mode) m.setTestMode();
-
-                if ( (mangle_rules_count=m.prolog()) > 0 )
-                {
-                    m.compile();
-                    m.epilog();
-
-                    long m_str_pos = m_str.tellp();
-
-                    if (policy->isTop())
-                    {
-                        m_str << "# ================ Table 'mangle', "
-                              << "automatic rules"
-                              << endl;
-                        m_str << m.flushAndSetDefaultPolicy();
-                    }
-
-                    if (m.getCompiledScriptLength() > 0)
-                    {
-                        m_str << "# ================ Table 'mangle', rule set "
-                              << branch_name << endl;
-                        if (m.haveErrorsAndWarnings())
-                        {
-                            m_str << "# Policy compiler errors and warnings:"
-                                  << endl;
-                            m_str << m.getErrors("# ");
-                        }
-
-                        m_str << m.getCompiledScript();
-                    }
-
-                    if (m_str_pos!=m_str.tellp())
-                    {
-                        m_str << m.commit();
-                        m_str << endl;
-                        empty_output = false;
-                    }
-                }
-
-
-                PolicyCompiler_ipt c(objdb, fwobjectname, ipv6_policy, oscnf,
-                                     &minus_n_commands_filter);
-
-                if (!policy->isTop())
-                    c.registerRuleSetChain(branch_name);
-
-                c.setSourceRuleSet( policy );
-                c.setRuleSetName(branch_name);
-
-                c.setDebugLevel( dl );
-                c.setDebugRule(  drp );
-                c.setVerbose( (bool)(verbose) );
-                c.setHaveDynamicInterfaces(have_dynamic_interfaces);
-                if (test_mode) c.setTestMode();
-
-                if ( (policy_rules_count=c.prolog()) > 0 )
-                {
-                    c.compile();
-                    c.epilog();
-
-                    if (c.getCompiledScriptLength() > 0)
-                    {
-                        c_str << "# ================ Table 'filter', rule set "
-                              << branch_name << endl;
-                        if (c.haveErrorsAndWarnings())
-                        {
-                            c_str << "# Policy compiler errors and warnings:"
-                                  << endl;
-                            c_str << c.getErrors("# ");
-                        }
-                        c_str << c.getCompiledScript();
-                        c_str << c.commit();
-                        c_str << endl;
-                        empty_output = false;
-                    }
-                }
-
-                if (policy->isTop())
-                {
-                    reset_rules
-                        << "# ================ Table 'filter', automatic rules"
-                        << endl;
-                    reset_rules << c.flushAndSetDefaultPolicy();
-                    empty_output = false;
-                }
+                bool empty_policy = processPolicyRuleSet(
+                    fwobjectname,
+                    *p,
+                    c_str,
+                    m_str,
+                    reset_rules,
+                    oscnf,
+                    ipv6_policy,
+                    minus_n_commands_filter,
+                    minus_n_commands_mangle);
 
+                if (!empty_policy) empty_output = false;
             }
 
             if (!empty_output)
@@ -843,7 +968,8 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
                                            ipv6_policy);
         }
 
-        RoutingCompiler_ipt r( objdb , fwobjectname , false, oscnf );
+        RoutingCompiler_ipt r(
+            objdb , fwobjectname.toUtf8().constData() , false, oscnf );
 
 	r.setDebugLevel( dl );
 	r.setDebugRule(  drp );
@@ -897,10 +1023,10 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
  * assemble the script and then perhaps post-process it if it should
  * run on Linksys device with sveasoft firmware
  */
+        QString script_buffer;
+        QTextStream script(&script_buffer, QIODevice::WriteOnly);
 
-        ostringstream script;
-
-	script << "#!/bin/sh "  << endl;
+	script << "#!/bin/sh "  << "\n";
 
         script << _("#\n\
 #  This is automatically generated file. DO NOT MODIFY !\n\
@@ -914,11 +1040,13 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
                << user_name << "\n#\n";
         }
 
-        script << MANIFEST_MARKER << "* " << fw_file_name << endl;
-        script << "#" << endl;
-        script << "#" << endl;
-        script << "# Compiled for iptables " << fw_version << endl;
-        script << "#" << endl;
+        QFileInfo fw_file_info(fw_file_name);
+        script << MANIFEST_MARKER << "* "
+               << fw_file_info.fileName() << "\n";
+        script << "#" << "\n";
+        script << "#" << "\n";
+        script << "# Compiled for iptables " << fw_version << "\n";
+        script << "#" << "\n";
         if ( !nocomm )
         {
             string fwcomment=fw->getComment();
@@ -926,19 +1054,19 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
             n1=n2=0;
             while ( (n2=fwcomment.find("\n",n1))!=string::npos )
             {
-                script << "#  " << fwcomment.substr(n1,n2-n1) << endl;
+                script << "#  " << fwcomment.substr(n1,n2-n1) << "\n";
                 n1=n2+1;
             }
-            script << "#  " << fwcomment.substr(n1) << endl;
+            script << "#  " << fwcomment.substr(n1) << "\n";
             script << "#\n#\n#\n";
         }
 
-        script << shell_dbg << endl;
-        script << endl;
+        script << shell_dbg << "\n";
+        script << "\n";
 
-        script << "PATH=\"/sbin:/usr/sbin:/bin:/usr/bin:${PATH}\"" << endl;
-        script << "export PATH" << endl;
-        script << endl;
+        script << "PATH=\"/sbin:/usr/sbin:/bin:/usr/bin:${PATH}\"" << "\n";
+        script << "export PATH" << "\n";
+        script << "\n";
 
 /*
  * print definitions for variables IPTABLES, IP, LOGGER. Some day we may
@@ -960,7 +1088,7 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
 
 	script << oscnf->getCompiledScript();
 
-        script << endl;
+        script << "\n";
 
         if (prolog_place == "after_interfaces")
         {
@@ -987,9 +1115,9 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
                << user_name;
         }
 
-        script << "'" << endl;
+        script << "'" << "\n";
 
-	script << endl;
+	script << "\n";
 
         script << generated_script;
 
@@ -1000,73 +1128,64 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
 
         if ( !nocomm )
         {
-            script << endl;
-            script << "#" << endl;
-            script << "# Epilog script" << endl;
-            script << "#" << endl;
+            script << "\n";
+            script << "#" << "\n";
+            script << "# Epilog script" << "\n";
+            script << "#" << "\n";
         }
 
         string post_hook= fw->getOptionsObject()->getStr("epilog_script");
-        script << post_hook << endl;
+        script << post_hook << "\n";
 
         if ( !nocomm )
         {
-            script << endl;
-            script << "# End of epilog script" << endl;
-            script << "#" << endl;
+            script << "\n";
+            script << "# End of epilog script" << "\n";
+            script << "#" << "\n";
         }
 
-        script << endl;
+        script << "\n";
 
         if (options->getBool("use_iptables_restore"))
             script << "exit $IPTABLES_RESTORE_RES";
 
-	script << endl;
+	script << "\n";
 
-        string sbuf = script.str();
+        QFile fw_file(fw_file_name);
+        if (fw_file.open(QIODevice::WriteOnly))
+        {
+            QTextStream fw_str(&fw_file);
+            fw_str << script_buffer;
+            fw_file.close();
+            fw_file.setPermissions(QFile::ReadOwner | QFile::WriteOwner |
+                                   QFile::ReadGroup | QFile::ReadOther);
+        }
 
-	ofstream fw_file;
-        fw_file.exceptions(ofstream::eofbit|ofstream::failbit|ofstream::badbit);
-
-#ifdef _WIN32
-        fw_file.open(fw_file_name.c_str(), ios::out|ios::binary);
-#else
-        fw_file.open(fw_file_name.c_str());
-#endif
-
-        fw_file << sbuf << endl;
-	fw_file.close();
-
-#ifdef _WIN32
-        _chmod(fw_file_name.c_str(),_S_IREAD|_S_IWRITE);
-#else
-        chmod(fw_file_name.c_str(),S_IXUSR|S_IRUSR|S_IWUSR|S_IRGRP);
-#endif
-
-        cout << _(" Compiled successfully") << endl << flush;
+        cout << _(" Compiled successfully") << std::endl << flush;
         
         return 0;
 
     } catch(const FWException &ex)  {
-	cerr << "Error: " << ex.toString() << endl;
+	cerr << "Error: " << ex.toString() << std::endl;
         return 1;
 #if __GNUC__ >= 3
 /* need to check version because std::ios::failure does not seem to be
  * supported in gcc 2.9.5 on FreeBSD 4.10 */
     } catch (const std::ios::failure &e) {
-        cerr << "Error while opening or writing to the output file" << endl;
+        cerr << "Error while opening or writing to the output file"
+             << std::endl;
         return 1;
 #endif
 
     } catch (const std::string &s) {
-	cerr << s << endl;
+	cerr << s << std::endl;
         return 1;
     } catch (const std::exception &ex) {
-	cerr << ex.what() << endl;
+	cerr << ex.what() << std::endl;
         return 1;
     }
     catch (...) {
-	cerr << _("Unsupported exception") << endl;
+	cerr << _("Unsupported exception") << std::endl;
         return 1;
     }
 
