@@ -80,55 +80,57 @@ struct CUSTOM_API IPTCfgParserTokenTypes {
 		MATCH_LIMIT = 69,
 		MATCH_LIMIT_BURST = 70,
 		M_MPORT = 71,
-		MATCH_SRC_MULTIPORT = 72,
-		MATCH_SRC_MULTIPORT_SHORT = 73,
-		MATCH_DST_MULTIPORT = 74,
-		MATCH_DST_MULTIPORT_SHORT = 75,
-		MATCH_ICMP_TYPE = 76,
-		MATCH_SRC_PORT = 77,
-		MATCH_SRC_PORT_SHORT = 78,
-		MATCH_DST_PORT = 79,
-		MATCH_DST_PORT_SHORT = 80,
-		MATCH_SYN = 81,
-		SYN = 82,
-		ACK = 83,
-		FIN = 84,
-		RST = 85,
-		URG = 86,
-		PSH = 87,
-		ALL = 88,
-		NONE = 89,
-		MATCH_TCP_FLAGS = 90,
-		MATCH_TCP_OPTION = 91,
-		NUMBER = 92,
-		Whitespace = 93,
-		NEG_INT_CONST = 94,
-		HEXDIGIT = 95,
-		SECONDS = 96,
-		SET = 97,
-		RSOURCE = 98,
-		ULOG_QTHR = 99,
-		ULOG_NLG = 100,
-		ULOG_CPR = 101,
-		NUMBER_SIGN = 102,
-		PERCENT = 103,
-		AMPERSAND = 104,
-		APOSTROPHE = 105,
-		OPENING_PAREN = 106,
-		CLOSING_PAREN = 107,
-		PLUS = 108,
-		DOT = 109,
-		SEMICOLON = 110,
-		LESS_THAN = 111,
-		EQUALS = 112,
-		GREATER_THAN = 113,
-		QUESTION = 114,
-		COMMERCIAL_AT = 115,
-		CARET = 116,
-		UNDERLINE = 117,
-		OPENING_BRACE = 118,
-		CLOSING_BRACE = 119,
-		TILDE = 120,
+		M_COMMENT = 72,
+		MATCH_COMMENT = 73,
+		MATCH_SRC_MULTIPORT = 74,
+		MATCH_SRC_MULTIPORT_SHORT = 75,
+		MATCH_DST_MULTIPORT = 76,
+		MATCH_DST_MULTIPORT_SHORT = 77,
+		MATCH_ICMP_TYPE = 78,
+		MATCH_SRC_PORT = 79,
+		MATCH_SRC_PORT_SHORT = 80,
+		MATCH_DST_PORT = 81,
+		MATCH_DST_PORT_SHORT = 82,
+		MATCH_SYN = 83,
+		SYN = 84,
+		ACK = 85,
+		FIN = 86,
+		RST = 87,
+		URG = 88,
+		PSH = 89,
+		ALL = 90,
+		NONE = 91,
+		MATCH_TCP_FLAGS = 92,
+		MATCH_TCP_OPTION = 93,
+		NUMBER = 94,
+		Whitespace = 95,
+		NEG_INT_CONST = 96,
+		HEXDIGIT = 97,
+		SECONDS = 98,
+		SET = 99,
+		RSOURCE = 100,
+		ULOG_QTHR = 101,
+		ULOG_NLG = 102,
+		ULOG_CPR = 103,
+		NUMBER_SIGN = 104,
+		PERCENT = 105,
+		AMPERSAND = 106,
+		APOSTROPHE = 107,
+		OPENING_PAREN = 108,
+		CLOSING_PAREN = 109,
+		PLUS = 110,
+		DOT = 111,
+		SEMICOLON = 112,
+		LESS_THAN = 113,
+		EQUALS = 114,
+		GREATER_THAN = 115,
+		QUESTION = 116,
+		COMMERCIAL_AT = 117,
+		CARET = 118,
+		UNDERLINE = 119,
+		OPENING_BRACE = 120,
+		CLOSING_BRACE = 121,
+		TILDE = 122,
 		NULL_TREE_LOOKAHEAD = 3
 	};
 #ifdef __cplusplus
