@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipf.h,v 1.7 2007/10/07 01:21:07 vkurland Exp $
+  $Id: NATCompiler_ipf.h 312 2008-07-05 17:40:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -186,7 +186,9 @@ namespace fwcompiler {
 
 	NATCompiler_ipf(libfwbuilder::FWObjectDatabase *_db,
 			const std::string &fwname,
-			fwcompiler::OSConfigurator *_oscnf) : NATCompiler_pf(_db,fwname,_oscnf) {}
+                        bool ipv6_policy,
+			fwcompiler::OSConfigurator *_oscnf) :
+        NATCompiler_pf(_db, fwname, ipv6_policy, _oscnf) {}
 
 
 	virtual int  prolog();
