@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_pf.h,v 1.9 2007/06/21 03:25:45 vkurland Exp $
+  $Id: NATCompiler_pf.h 312 2008-07-05 17:40:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -59,12 +59,12 @@ namespace fwcompiler {
 
         struct redirectRuleInfo {
             std::string            natrule_label;
-            libfwbuilder::Address *old_tdst;
-            libfwbuilder::Address *new_tdst;
+            libfwbuilder::FWObject *old_tdst;
+            libfwbuilder::FWObject *new_tdst;
             libfwbuilder::Service *tsrv;
             redirectRuleInfo(const std::string &rl,
-                             libfwbuilder::Address *oa,
-                             libfwbuilder::Address *na,
+                             libfwbuilder::FWObject *oa,
+                             libfwbuilder::FWObject *na,
                              libfwbuilder::Service *s) 
             {  natrule_label=rl; old_tdst=oa; new_tdst=na; tsrv=s; }
         };
@@ -72,7 +72,7 @@ namespace fwcompiler {
 
 	protected:
 
-	libfwbuilder::IPv4  *loopback_address;
+	libfwbuilder::FWObject *loopback_address;
         TableFactory   *tables;
 
 
@@ -198,31 +198,32 @@ namespace fwcompiler {
                 eliminateDuplicatesInRE(n,libfwbuilder::RuleElementOSrv::TYPENAME) {}
         };
 
-        friend class checkForDynamicInterfacesOfOtherObjects;
         class checkForDynamicInterfacesOfOtherObjects : public NATRuleProcessor
         {
             void findDynamicInterfaces(libfwbuilder::RuleElement *re,
                                        libfwbuilder::Rule        *rule);
             public:
-            checkForDynamicInterfacesOfOtherObjects(const std::string &name) : NATRuleProcessor(name) {}
+            checkForDynamicInterfacesOfOtherObjects(const std::string &name) :
+              NATRuleProcessor(name) {}
             virtual bool processNext();
         };
+        friend class checkForDynamicInterfacesOfOtherObjects;
 
         /**
          * like standard processor swapMultiAddressObjectsInRE, but
          * swaps compile-time address tables. See comment for this
          * rule processor in PolicyCompiler_pf
          */
-        class swapAddressTableObjectsInRE : public PolicyRuleProcessor
+        class swapAddressTableObjectsInRE : public NATRuleProcessor
         {
             std::string re_type;
             public:
             swapAddressTableObjectsInRE(const std::string &name,
-                      const std::string &t) : PolicyRuleProcessor(name)
+                      const std::string &t) : NATRuleProcessor(name)
             { re_type=t; }
             virtual bool processNext();
         };
-
+        friend class swapAddressTableObjectsInRE;
 
         class swapAddressTableObjectsInOSrc : public swapAddressTableObjectsInRE
         {
@@ -231,6 +232,7 @@ namespace fwcompiler {
                 swapAddressTableObjectsInRE(n,
                                   libfwbuilder::RuleElementOSrc::TYPENAME) {}
         };
+        friend class swapAddressTableObjectsInOSrc;
 
         class swapAddressTableObjectsInODst : public swapAddressTableObjectsInRE
         {
@@ -239,6 +241,7 @@ namespace fwcompiler {
                 swapAddressTableObjectsInRE(n,
                                   libfwbuilder::RuleElementODst::TYPENAME) {}
         };
+        friend class swapAddressTableObjectsInODst;
             
         class swapAddressTableObjectsInTDst : public swapAddressTableObjectsInRE
         {
@@ -365,8 +368,10 @@ namespace fwcompiler {
 
 	NATCompiler_pf(libfwbuilder::FWObjectDatabase *_db,
 		       const std::string &fwname,
+                       bool ipv6_policy,
 		       fwcompiler::OSConfigurator *_oscnf,
-                       TableFactory *tbf = NULL) : NATCompiler(_db,fwname,_oscnf)
+                       TableFactory *tbf = NULL) :
+        NATCompiler(_db, fwname, ipv6_policy, _oscnf)
         {
             tables = tbf;
         }
