@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_pf_writers.cpp,v 1.12 2006/06/22 05:04:16 vkurland Exp $
+  $Id: NATCompiler_pf_writers.cpp 312 2008-07-05 17:40:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -236,11 +236,11 @@ void NATCompiler_pf::PrintRule::_printProtocol(Service *srv)
     }
 }
 
-void NATCompiler_pf::PrintRule::_printPort(Service *srv,bool print_range_end)
+void NATCompiler_pf::PrintRule::_printPort(Service *srv, bool print_range_end)
 {
     if (TCPService::isA(srv) || UDPService::isA(srv)) {
-	int drs=srv->getInt("dst_range_start");
-	int dre=srv->getInt("dst_range_end");
+	int drs=TCPUDPService::cast(srv)->getDstRangeStart();
+	int dre=TCPUDPService::cast(srv)->getDstRangeEnd();
 	if (drs!=0)
         {
             compiler->output << "port " << drs;
@@ -256,7 +256,7 @@ void NATCompiler_pf::PrintRule::_printPort(Service *srv,bool print_range_end)
     }
     if (TagService::isA(srv)) 
     {
-	compiler->output << "tagged " << TagService::cast(srv)->getCode() << " ";
+	compiler->output << "tagged " << TagService::constcast(srv)->getCode() << " ";
     }
 }
 
@@ -291,7 +291,7 @@ void NATCompiler_pf::PrintRule::_printREAddr(RuleElement *rel)
 }
 
 
-void NATCompiler_pf::PrintRule::_printAddrList(FWObject  *grp,bool negflag)
+void NATCompiler_pf::PrintRule::_printAddrList(FWObject  *grp,bool )
 {
     compiler->output << "{ ";
     for (FWObject::iterator i=grp->begin(); i!=grp->end(); i++)
@@ -324,34 +324,39 @@ void NATCompiler_pf::PrintRule::_printAddr(FWObject *o)
         assert(atrt==NULL);
     }
 
-    Address *a = Address::cast(o);
-    IPAddress addr=a->getAddress();
-    Netmask   mask=a->getNetmask();
-
     if (Interface::cast(o)!=NULL)
     {
-        Interface *interface_=Interface::cast(o);
-        if (interface_->isDyn())
+        Interface *iface=Interface::cast(o);
+        if (iface->isDyn())
         {
-            compiler->output << "(" << interface_->getName() << ") ";
+            compiler->output << "(" << iface->getName() << ") ";
             return;
         }
-
-        mask=Netmask("255.255.255.255");
     }
 
-    if (IPv4::cast(o)!=NULL) {
-        mask=Netmask("255.255.255.255");
-    }
+    Address *a = Address::cast(o);
+    const InetAddr *addr = a->getAddressPtr();
+    if (addr)
+    {
+        InetAddr mask = *(a->getNetmaskPtr());
 
-    if (addr.toString()=="0.0.0.0" && mask.toString()=="0.0.0.0") {
-        compiler->output << "any ";
-    } else {
-        compiler->output << addr.toString();
-        if (mask.toString()!="255.255.255.255") {
-            compiler->output << "/" << mask.getLength();
+        if (Interface::cast(o)!=NULL || Address::cast(o)->dimension()==1)
+        {
+            mask = InetAddr(InetAddr::getAllOnes());
+        }
+
+        if (addr->isAny() && mask.isAny())
+        {
+            compiler->output << "any ";
+        } else
+        {
+            compiler->output << addr->toString();
+            if (!mask.isHostMask())
+            {
+                compiler->output << "/" << mask.getLength();
+            }
+            compiler->output  << " ";
         }
-        compiler->output  << " ";
     }
 }
 
