@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSConfigurator_freebsd.h,v 1.2 2005/03/30 07:33:18 vkurland Exp $
+  $Id: OSConfigurator_freebsd.h 312 2008-07-05 17:40:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -38,7 +38,7 @@ namespace fwcompiler {
 
         OSData   os_data;
 
-	std::vector<libfwbuilder::IPAddress> virtual_addresses;
+	std::vector<libfwbuilder::InetAddr> virtual_addresses;
 
         std::string getInterfaceVarName(libfwbuilder::FWObject *iface);
         
@@ -46,8 +46,9 @@ namespace fwcompiler {
 
 	virtual ~OSConfigurator_freebsd() {};
 	OSConfigurator_freebsd(libfwbuilder::FWObjectDatabase *_db,
-			      const std::string &fwname) : 
-	    OSConfigurator(_db,fwname) , os_data() {}
+                               const std::string &fwname,
+                               bool ipv6_policy) : 
+        OSConfigurator(_db, fwname, ipv6_policy) , os_data() {}
 
         virtual int prolog();
 
