@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipf.cpp,v 1.12 2007/05/08 02:11:39 vkurland Exp $
+  $Id: PolicyCompiler_ipf.cpp 312 2008-07-05 17:40:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -52,34 +52,27 @@ int PolicyCompiler_ipf::prolog()
 {
     int n= PolicyCompiler_pf::prolog();
 
-//    FWObject    *grp;
     anytcp=TCPService::cast(dbcopy->create(TCPService::TYPENAME) );
-    anytcp->setId(ANY_TCP_OBJ_ID);
-//    grp=dbcopy->getById( dbcopy->std.TCPServicesId , true );
-//    assert(grp!=NULL);
+    anytcp->setId(FWObjectDatabase::generateUniqueId()); //ANY_TCP_OBJ_ID);
     dbcopy->add(anytcp,false);
     cacheObj(anytcp); // to keep cache consistent
 
     anyudp=UDPService::cast(dbcopy->create(UDPService::TYPENAME) );
-    anyudp->setId(ANY_UDP_OBJ_ID);
-//    grp=dbcopy->getById( dbcopy->std.UDPServicesId , true );
-//    assert(grp!=NULL);
+    anyudp->setId(FWObjectDatabase::generateUniqueId()); //ANY_UDP_OBJ_ID);
     dbcopy->add(anyudp,false);
     cacheObj(anyudp); // to keep cache consistent
 
     anyicmp=ICMPService::cast(dbcopy->create(ICMPService::TYPENAME) );
-    anyicmp->setId(ANY_ICMP_OBJ_ID);
-//    grp=dbcopy->getById( dbcopy->std.ICMPServicesId , true );
-//    assert(grp!=NULL);
+    anyicmp->setId(FWObjectDatabase::generateUniqueId()); //ANY_ICMP_OBJ_ID);
     dbcopy->add(anyicmp,false);
     cacheObj(anyicmp); // to keep cache consistent
 
-
     return n;
 }
 
 bool PolicyCompiler_ipf::expandAnyService::processNext()
 {
+    PolicyCompiler_ipf *pcomp=dynamic_cast<PolicyCompiler_ipf*>(compiler);
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
 
     RuleElementSrv *srv=rule->getSrv();
@@ -93,7 +86,7 @@ bool PolicyCompiler_ipf::expandAnyService::processNext()
 	r->duplicate(rule);
 	RuleElementSrv *nsrv=r->getSrv();
 	nsrv->clearChildren();
-	nsrv->addRef(compiler->dbcopy->findInIndex(ANY_ICMP_OBJ_ID));
+	nsrv->addRef(pcomp->anyicmp); //compiler->dbcopy->findInIndex(ANY_ICMP_OBJ_ID));
 	tmp_queue.push_back(r);
 
 	r= PolicyRule::cast(
@@ -102,7 +95,7 @@ bool PolicyCompiler_ipf::expandAnyService::processNext()
 	r->duplicate(rule);
 	nsrv=r->getSrv();
 	nsrv->clearChildren();
-	nsrv->addRef(compiler->dbcopy->findInIndex(ANY_TCP_OBJ_ID));
+	nsrv->addRef(pcomp->anytcp); //compiler->dbcopy->findInIndex(ANY_TCP_OBJ_ID));
 	tmp_queue.push_back(r);
 
 	r= PolicyRule::cast(
@@ -111,7 +104,7 @@ bool PolicyCompiler_ipf::expandAnyService::processNext()
 	r->duplicate(rule);
 	nsrv=r->getSrv();
 	nsrv->clearChildren();
-	nsrv->addRef(compiler->dbcopy->findInIndex(ANY_UDP_OBJ_ID));
+	nsrv->addRef(pcomp->anyudp); //compiler->dbcopy->findInIndex(ANY_UDP_OBJ_ID));
 	tmp_queue.push_back(r);
 
 	r= PolicyRule::cast(
@@ -404,30 +397,35 @@ void PolicyCompiler_ipf::compile()
 
         if ( fw->getOptionsObject()->getBool ("check_shading") ) 
         {
-            add( new Begin                       ("Detecting rule shadowing"              ) );
-            add( new printTotalNumberOfRules     (                                         ) );
+            add( new Begin ("Detecting rule shadowing"              ) );
+            add( new printTotalNumberOfRules( ) );
 
-            add( new ItfNegation(            "process negation in Itf"  ) );
-            add( new InterfacePolicyRules("process interface policy rules and store interface ids") );
+            add( new ItfNegation("process negation in Itf"  ) );
+            add( new InterfacePolicyRules(
+                     "process interface policy rules and store interface ids"));
 
-            add( new recursiveGroupsInSrc(       "check for recursive groups in SRC"     ) );
-            add( new recursiveGroupsInDst(       "check for recursive groups in DST"     ) );
-            add( new recursiveGroupsInSrv(       "check for recursive groups in SRV"     ) );
+            add( new recursiveGroupsInSrc("check for recursive groups in SRC"));
+            add( new recursiveGroupsInDst("check for recursive groups in DST"));
+            add( new recursiveGroupsInSrv("check for recursive groups in SRV"));
             check_for_recursive_groups=false;
 
-            add( new ExpandGroups                ("expand groups"                          ) );
-            add( new eliminateDuplicatesInSRC    ("eliminate duplicates in SRC"            ) );
-            add( new eliminateDuplicatesInDST    ("eliminate duplicates in DST"            ) );
-            add( new eliminateDuplicatesInSRV    ("eliminate duplicates in SRV"            ) );
+            add( new ExpandGroups("expand groups") );
+            add( new eliminateDuplicatesInSRC("eliminate duplicates in SRC") );
+            add( new eliminateDuplicatesInDST("eliminate duplicates in DST") );
+            add( new eliminateDuplicatesInSRV("eliminate duplicates in SRV") );
 
-            add( new swapMultiAddressObjectsInSrc(" swap MultiAddress -> MultiAddressRunTime in Src") );
-            add( new swapMultiAddressObjectsInDst(" swap MultiAddress -> MultiAddressRunTime in Dst") );
+            add( new swapMultiAddressObjectsInSrc(
+                     " swap MultiAddress -> MultiAddressRunTime in Src") );
+            add( new swapMultiAddressObjectsInDst(
+                     " swap MultiAddress -> MultiAddressRunTime in Dst") );
 
-            add( new ExpandMultipleAddressesInSRC("expand objects with multiple addresses in SRC" ) );
-            add( new ExpandMultipleAddressesInDST("expand objects with multiple addresses in DST" ) );
-            add( new ConvertToAtomic             ("convert to atomic rules"                ) );
-            add( new DetectShadowing             ("Detect shadowing"                         ) );
-            add( new simplePrintProgress         (                                         ) );
+            add( new ExpandMultipleAddressesInSRC(
+                     "expand objects with multiple addresses in SRC" ) );
+            add( new ExpandMultipleAddressesInDST(
+                     "expand objects with multiple addresses in DST" ) );
+            add( new ConvertToAtomic("convert to atomic rules" ) );
+            add( new DetectShadowing("Detect shadowing" ) );
+            add( new simplePrintProgress() );
 
             runRuleProcessors();
             deleteRuleProcessors();
@@ -437,76 +435,87 @@ void PolicyCompiler_ipf::compile()
         add( new Begin());
         add( new printTotalNumberOfRules() );
 //        add( new MACFiltering(                "verify for MAC address filtering"                ) );
-        add( new setQuickFlag(                "set 'quick' flag"                                ) );
+        add( new setQuickFlag("set 'quick' flag") );
 
         if (check_for_recursive_groups)
         {
-            add( new recursiveGroupsInSrc(   "check for recursive groups in SRC"     ) );
-            add( new recursiveGroupsInDst(   "check for recursive groups in DST"     ) );
-            add( new recursiveGroupsInSrv(   "check for recursive groups in SRV"     ) );
+            add( new recursiveGroupsInSrc("check for recursive groups in SRC"));
+            add( new recursiveGroupsInDst("check for recursive groups in DST"));
+            add( new recursiveGroupsInSrv("check for recursive groups in SRV"));
         }
 
-        add( new emptyGroupsInSrc(           "check for empty groups in SRC"         ) );
-        add( new emptyGroupsInDst(           "check for empty groups in DST"         ) );
-        add( new emptyGroupsInSrv(           "check for empty groups in SRV"         ) );
+        add( new emptyGroupsInSrc("check for empty groups in SRC") );
+        add( new emptyGroupsInDst("check for empty groups in DST") );
+        add( new emptyGroupsInSrv("check for empty groups in SRV") );
 
-        add( new ItfNegation(            "process negation in Itf"  ) );
-        add( new InterfacePolicyRules("process interface policy rules and store interface ids") );
+        add( new ItfNegation("process negation in Itf"  ) );
+        add( new InterfacePolicyRules(
+                 "process interface policy rules and store interface ids") );
 
-        add( new doSrcNegation(               "process negation in Src"                         ) );
-        add( new doDstNegation(               "process negation in Dst"                         ) );
-        add( new doSrvNegation(               "process negation in Srv"                         ) );
-        add( new ExpandGroups(                "expand groups"                                   ) );
+        add( new doSrcNegation("process negation in Src") );
+        add( new doDstNegation("process negation in Dst") );
+        add( new doSrvNegation("process negation in Srv") );
+        add( new ExpandGroups( "expand groups") );
 
-        add( new CheckForTCPEstablished("check for TCPService objects with flag \"established\"") );
+        add( new CheckForTCPEstablished(
+                 "check for TCPService objects with flag \"established\"") );
+        add( new CheckForUnsupportedUserService("check for user service") );
             
-        add( new eliminateDuplicatesInSRC(    "eliminate duplicates in SRC"                     ) );
-        add( new eliminateDuplicatesInDST(    "eliminate duplicates in DST"                     ) );
-        add( new eliminateDuplicatesInSRV(    "eliminate duplicates in SRV"                     ) );
+        add( new eliminateDuplicatesInSRC("eliminate duplicates in SRC") );
+        add( new eliminateDuplicatesInDST("eliminate duplicates in DST") );
+        add( new eliminateDuplicatesInSRV("eliminate duplicates in SRV") );
 
-        add( new swapMultiAddressObjectsInSrc(" swap MultiAddress -> MultiAddressRunTime in Src") );
-        add( new swapMultiAddressObjectsInDst(" swap MultiAddress -> MultiAddressRunTime in Dst") );
+        add( new swapMultiAddressObjectsInSrc(
+                 " swap MultiAddress -> MultiAddressRunTime in Src") );
+        add( new swapMultiAddressObjectsInDst(
+                 " swap MultiAddress -> MultiAddressRunTime in Dst") );
 
-        add( new processMultiAddressObjectsInSrc("process MultiAddress objects in Src") );
-        add( new processMultiAddressObjectsInDst("process MultiAddress objects in Dst") );
+        add( new processMultiAddressObjectsInSrc(
+                 "process MultiAddress objects in Src") );
+        add( new processMultiAddressObjectsInDst(
+                 "process MultiAddress objects in Dst") );
 
-        add( new splitIfFirewallInSrc(        "split rule if firewall is in Src"                ) );
-        add( new splitIfFirewallInDst(        "split rule if firewall is in Dst"                ) );
-        add( new fillDirection(               "determine directions"                            ) );
-        add( new SplitDirection(              "split rules with direction 'both'"               ) );
-        add( new ExpandMultipleAddresses(     "expand objects with multiple addresses"          ) );
-        add( new checkForDynamicInterfacesOfOtherObjects( "check for dynamic interfaces of other hosts and firewalls" ) );
-        add( new MACFiltering(                "verify for MAC address filtering"                ) );
-        add( new checkForUnnumbered(          "check for unnumbered interfaces"                 ) );
-        add( new specialCaseWithDynInterface( "check for a special cases with dynamic interface") );
-        add( new addressRanges(               "expand address range objects"                    ) );
-        add( new splitServices(               "split rules with different protocols"            ) );
-        add( new separateTCPWithFlags(        "separate TCP services with flags"                ) );
+        add( new splitIfFirewallInSrc("split rule if firewall is in Src") );
+        add( new splitIfFirewallInDst("split rule if firewall is in Dst") );
+        add( new fillDirection("determine directions") );
+        add( new SplitDirection("split rules with direction 'both'" ) );
+        add( new ExpandMultipleAddresses(
+                 "expand objects with multiple addresses") );
+        add( new checkForDynamicInterfacesOfOtherObjects(
+                 "check for dynamic interfaces of other hosts and firewalls" ));
+        add( new MACFiltering("verify for MAC address filtering" ) );
+        add( new checkForUnnumbered("check for unnumbered interfaces") );
+        add( new specialCaseWithDynInterface(
+                 "check for a special cases with dynamic interface") );
+        add( new addressRanges("expand address range objects") );
+        add( new splitServices("split rules with different protocols") );
+        add( new separateTCPWithFlags("separate TCP services with flags" ) );
         add( new separateSrcPort("split on TCP and UDP with source ports"));
-        add( new verifyCustomServices(        "verify custom services for this platform"        ) );
-        add( new SpecialServices(             "check for special services"                      ) );
-        add( new expandAnyService(            "expand ANY service for stateful rules"           ) );
+        add( new verifyCustomServices(
+                 "verify custom services for this platform") );
+        add( new SpecialServices("check for special services" ) );
+        add( new expandAnyService("expand ANY service for stateful rules") );
 /*
  * it may make sense to do optimization even before we expand groups
  * (before ExpandGroups). Need to test this idea.
  */
         if ( fw->getOptionsObject()->getBool ("optimize") )
         {
-            add( new optimizeSrc(                  "optimization in SRC"                ) );
-            add( new optimizeDst(                  "optimization in DST"                ) );
-            add( new optimizeSrv(                  "optimization in SRV"                ) );
+            add( new optimizeSrc("optimization in SRC") );
+            add( new optimizeDst("optimization in DST") );
+            add( new optimizeSrv("optimization in SRV") );
         }
 
-        add( new ConvertToAtomic(             "convert to atomic rules"                         ) );
-        add( new checkForZeroAddr(            "check for zero addresses"                        ) );
+        add( new ConvertToAtomic("convert to atomic rules") );
+        add( new checkForZeroAddr("check for zero addresses" ) );
 
         if ( fw->getOptionsObject()->getBool ("eliminate_duplicates") ) 
-            add( new eliminateDuplicateRules(     "eliminate duplicate rules"                       ) );
+            add( new eliminateDuplicateRules("eliminate duplicate rules" ) );
 
-	add( new calculateSkip(               "calculate argument for skip"                     ) );
-        add( new checkForKeepState(           "check for 'keep state'"                          ) );
-        add( new convertInterfaceIdToStr(    "prepare interface assignments"         ) );
-        add( new PrintRule(                   "generate ipf code"                               ) );
+	add( new calculateSkip("calculate argument for skip") );
+        add( new checkForKeepState("check for 'keep state'") );
+        add( new convertInterfaceIdToStr("prepare interface assignments") );
+        add( new PrintRule("generate ipf code") );
         add( new simplePrintProgress() );
 
         runRuleProcessors();
@@ -523,13 +532,19 @@ string PolicyCompiler_ipf::debugPrintRule(Rule *r)
     PolicyRule *rule=PolicyRule::cast(r);
 //    FWOptions  *ruleopt =rule->getOptionsObject();
 
-    string  iface = rule->getInterfaceId();
-    if (iface!="") {
-	Interface *rule_iface = getCachedFwInterface( iface );
-        iface=" intf: "+rule_iface->getName();
-    }
     ostringstream s;
-    s << PolicyCompiler::debugPrintRule(rule)+" "+iface;
+    s << PolicyCompiler::debugPrintRule(rule) << " ";
+
+    int iface_id = rule->getInterfaceId();
+    if (iface_id > -1)
+    {
+	Interface *rule_iface = getCachedFwInterface( iface_id );
+        s << " intf: "+rule_iface->getName();
+    } else
+        s << iface_id;
+
+    s << " ";
+
     if (r->getBool("skip_check_for_duplicates")) s << "skip_check_for_duplicates ";
     if (r->getStr("skip_label")!="")             s << "skip_label: " << r->getStr("skip_label") << " ";
     if (r->getStr("skip_to")!="")                s << "skip_to: "    << r->getStr("skip_to")    << " ";
