@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipf_optimizer.cpp,v 1.2 2006/09/09 05:05:02 vkurland Exp $
+  $Id: PolicyCompiler_ipf_optimizer.cpp 312 2008-07-05 17:40:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -49,11 +49,10 @@ using namespace std;
 static map<string,bool> skip_targets;
 
 
-void PolicyCompiler_ipf::optimize1::optimizeForRuleElement(PolicyRule         *rule, 
-                                                           const std::string  &re_type)
+void PolicyCompiler_ipf::optimize1::optimizeForRuleElement(PolicyRule *rule, 
+                                                  const std::string  &re_type)
 {
     RuleElement    *re=RuleElement::cast(rule->getFirstByType(re_type));
-    int nre=re->size();
 
     PolicyRule     *r;
 
@@ -65,11 +64,12 @@ void PolicyCompiler_ipf::optimize1::optimizeForRuleElement(PolicyRule         *r
  * "skip_label". That's why I set skip_label after I create a copy of the rule
  */
 
-    string skip_target=rule->getId();
+    string skip_target = FWObjectDatabase::getStringId(rule->getId());
     while (skip_targets[skip_target]) skip_target+=".A";
     skip_targets[skip_target]=true;
 
-    rule->setStr("skip_label",skip_target);  // just need a unique label, and ID is unique
+    // just need a unique label, and ID is unique
+    rule->setStr("skip_label", skip_target);
 
     for (FWObject::iterator i=r->begin(); i!=r->end(); ++i)
     {
