@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipfw.cpp,v 1.13 2007/05/08 00:22:58 vkurland Exp $
+  $Id: PolicyCompiler_ipfw.cpp 545 2008-09-19 20:27:58Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -53,17 +53,17 @@ int PolicyCompiler_ipfw::prolog()
     int n= PolicyCompiler_pf::prolog();
 
     anytcp=TCPService::cast(dbcopy->create(TCPService::TYPENAME) );
-    anytcp->setId(ANY_TCP_OBJ_ID);
+    anytcp->setId(FWObjectDatabase::generateUniqueId()); // ANY_TCP_OBJ_ID);
     dbcopy->add(anytcp,false);
     cacheObj(anytcp); // to keep cache consistent
 
     anyudp=UDPService::cast(dbcopy->create(UDPService::TYPENAME) );
-    anyudp->setId(ANY_UDP_OBJ_ID);
+    anyudp->setId(FWObjectDatabase::generateUniqueId()); //ANY_UDP_OBJ_ID);
     dbcopy->add(anyudp,false);
     cacheObj(anyudp); // to keep cache consistent
 
     anyicmp=ICMPService::cast(dbcopy->create(ICMPService::TYPENAME) );
-    anyicmp->setId(ANY_ICMP_OBJ_ID);
+    anyicmp->setId(FWObjectDatabase::generateUniqueId()); //ANY_ICMP_OBJ_ID);
     dbcopy->add(anyicmp,false);
     cacheObj(anyicmp); // to keep cache consistent
 
@@ -92,6 +92,7 @@ void PolicyCompiler_ipfw::_expandAddr(Rule *rule,FWObject *s)
 
 bool PolicyCompiler_ipfw::expandAnyService::processNext()
 {
+    PolicyCompiler_ipfw *pcomp=dynamic_cast<PolicyCompiler_ipfw*>(compiler);
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
 
     RuleElementSrv *srv=rule->getSrv();
@@ -105,7 +106,7 @@ bool PolicyCompiler_ipfw::expandAnyService::processNext()
 	r->duplicate(rule);
 	RuleElementSrv *nsrv=r->getSrv();
 	nsrv->clearChildren();
-	nsrv->addRef(compiler->dbcopy->findInIndex(ANY_ICMP_OBJ_ID));
+	nsrv->addRef(pcomp->anyicmp); //compiler->dbcopy->findInIndex(ANY_ICMP_OBJ_ID));
 	tmp_queue.push_back(r);
 
 	r= PolicyRule::cast(
@@ -114,7 +115,7 @@ bool PolicyCompiler_ipfw::expandAnyService::processNext()
 	r->duplicate(rule);
 	nsrv=r->getSrv();
 	nsrv->clearChildren();
-	nsrv->addRef(compiler->dbcopy->findInIndex(ANY_TCP_OBJ_ID));
+	nsrv->addRef(pcomp->anytcp); //compiler->dbcopy->findInIndex(ANY_TCP_OBJ_ID));
 	tmp_queue.push_back(r);
 
 	r= PolicyRule::cast(
@@ -123,7 +124,7 @@ bool PolicyCompiler_ipfw::expandAnyService::processNext()
 	r->duplicate(rule);
 	nsrv=r->getSrv();
 	nsrv->clearChildren();
-	nsrv->addRef(compiler->dbcopy->findInIndex(ANY_UDP_OBJ_ID));
+	nsrv->addRef(pcomp->anyudp); //compiler->dbcopy->findInIndex(ANY_UDP_OBJ_ID));
 	tmp_queue.push_back(r);
 
 	r= PolicyRule::cast(
@@ -270,10 +271,10 @@ bool PolicyCompiler_ipfw::separatePortRanges::processNext()
 
 	if ( TCPService::isA(s) || UDPService::isA(s) ) 
         {
-            unsigned srs=s->getInt("src_range_start");
-            unsigned sre=s->getInt("src_range_end");
-            unsigned drs=s->getInt("dst_range_start");
-            unsigned dre=s->getInt("dst_range_end");
+            unsigned srs=TCPUDPService::cast(s)->getSrcRangeStart();
+            unsigned sre=TCPUDPService::cast(s)->getSrcRangeEnd();
+            unsigned drs=TCPUDPService::cast(s)->getDstRangeStart();
+            unsigned dre=TCPUDPService::cast(s)->getDstRangeEnd();
 
             if (srs!=0 && sre==0) sre=srs;
             if (drs!=0 && dre==0) dre=drs;
@@ -343,10 +344,10 @@ bool PolicyCompiler_ipfw::sortTCPUDPServices::processNext()
 	Service *s=Service::cast(o);
 	assert(s!=NULL);
 
-        unsigned srs=s->getInt("src_range_start");
-        unsigned sre=s->getInt("src_range_end");
-        unsigned drs=s->getInt("dst_range_start");
-        unsigned dre=s->getInt("dst_range_end");
+        unsigned srs=TCPUDPService::cast(s)->getSrcRangeStart();
+        unsigned sre=TCPUDPService::cast(s)->getSrcRangeEnd();
+        unsigned drs=TCPUDPService::cast(s)->getDstRangeStart();
+        unsigned dre=TCPUDPService::cast(s)->getDstRangeEnd();
 
         if (srs!=0 && sre==0) sre=srs;
         if (drs!=0 && dre==0) dre=drs;
@@ -406,34 +407,32 @@ bool PolicyCompiler_ipfw::specialCaseWithDynInterface::processNext()
 }
 
 
-PolicyCompiler_ipfw::calculateNum::calculateNum(const std::string &n) : PolicyRuleProcessor(n)
-{
-    ipfw_num=0;
-}
+PolicyCompiler_ipfw::calculateNum::calculateNum(const std::string &n) :
+    PolicyRuleProcessor(n) {}
 
 bool PolicyCompiler_ipfw::calculateNum::processNext()
 {
+    PolicyCompiler_ipfw *pcomp = dynamic_cast<PolicyCompiler_ipfw*>(compiler);
+
     slurp();
     if (tmp_queue.size()==0) return false;
 
     for (deque<Rule*>::iterator k=tmp_queue.begin(); k!=tmp_queue.end(); ++k) 
     {
         PolicyRule *r = PolicyRule::cast( *k );
-
-        ipfw_num += 10;
-        r->setInt("ipfw_num", ipfw_num );
+        pcomp->ipfw_num += 10;
+        r->setInt("ipfw_num", pcomp->ipfw_num );
     }
 
-
     for (deque<Rule*>::iterator k=tmp_queue.begin(); k!=tmp_queue.end(); ++k) 
     {
         PolicyRule *r = PolicyRule::cast( *k );
-        int    current_position=r->getPosition();
+        int current_position = r->getPosition();
         if (r->getAction()==PolicyRule::Continue) 
         {
             r->setAction(PolicyRule::Skip);
             
-            deque<Rule*>::iterator j=k;
+            deque<Rule*>::iterator j = k;
             ++j;
             PolicyRule *r2;
             for ( ; j!=tmp_queue.end(); ++j) 
@@ -520,7 +519,10 @@ bool PolicyCompiler_ipfw::processMultiAddressObjectsInRE::processNext()
 
 void PolicyCompiler_ipfw::compile()
 {
-    cout << " Compiling policy for " << fw->getName() << " ..." <<  endl << flush;
+    cout << " Compiling " << fw->getName();
+    if (!getRuleSetName().empty())  cout << " ruleset " << getRuleSetName();
+    if (ipv6) cout << ", IPv6";
+    cout <<  endl << flush;
 
     try {
 
@@ -534,9 +536,11 @@ void PolicyCompiler_ipfw::compile()
             add( new Begin("Detecting rule shadowing"));
             add( new printTotalNumberOfRules());
 
-            add( new SpecialRuleActionsForShadowing( "disable rules with action Pipe and Custom") );
-            add( new ItfNegation(         "process negation in Itf"  ) );
-            add( new InterfacePolicyRules("process interface policy rules and store interface ids") );
+            add( new SpecialRuleActionsForShadowing(
+                     "disable rules with action Pipe and Custom") );
+            add( new ItfNegation("process negation in Itf"  ) );
+            add( new InterfacePolicyRules(
+                     "process interface policy rules and store interface ids"));
 
             add( new recursiveGroupsInSrc("check for recursive grps in SRC"));
             add( new recursiveGroupsInDst("check for recursive grps in DST"));
@@ -544,17 +548,21 @@ void PolicyCompiler_ipfw::compile()
             check_for_recursive_groups=false;
 
             add( new ExpandGroups("expand groups"));
+            add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
             add( new eliminateDuplicatesInSRC("eliminate duplicates in SRC"));
             add( new eliminateDuplicatesInDST("eliminate duplicates in DST"));
             add( new eliminateDuplicatesInSRV("eliminate duplicates in SRV"));
 
-            add( new swapMultiAddressObjectsInSrc(" swap MultiAddress -> MultiAddressRunTime in Src") );
-            add( new swapMultiAddressObjectsInDst(" swap MultiAddress -> MultiAddressRunTime in Dst") );
+            add( new swapMultiAddressObjectsInSrc(
+                     " swap MultiAddress -> MultiAddressRunTime in Src") );
+            add( new swapMultiAddressObjectsInDst(
+                     " swap MultiAddress -> MultiAddressRunTime in Dst") );
 
             add( new ExpandMultipleAddressesInSRC(
                      "expand objects with multiple addresses in SRC"));
             add( new ExpandMultipleAddressesInDST(
                      "expand objects with multiple addresses in DST"));
+            add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
             add( new ConvertToAtomic("convert to atomic rules"));
             add( new DetectShadowing("Detect shadowing"));
             add( new simplePrintProgress());
@@ -578,28 +586,35 @@ void PolicyCompiler_ipfw::compile()
         add( new emptyGroupsInDst("check for empty grps in DST"));
         add( new emptyGroupsInSrv("check for empty grps in SRV"));
 
-        add( new ItfNegation(         "process negation in Itf"  ) );
-        add( new InterfacePolicyRules("process interface policy rules and store interface ids") );
+        add( new ItfNegation("process negation in Itf"));
+        add( new InterfacePolicyRules(
+                 "process interface policy rules and store interface ids"));
 
         add( new doSrcNegation("process negation in Src"));
         add( new doDstNegation("process negation in Dst"));
         add( new doSrvNegation("process negation in Srv"));
         add( new ExpandGroups("expand groups"));
+        add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
         add( new eliminateDuplicatesInSRC("eliminate duplicates in SRC"));
         add( new eliminateDuplicatesInDST("eliminate duplicates in DST"));
         add( new eliminateDuplicatesInSRV("eliminate duplicates in SRV"));
 
-        add( new swapMultiAddressObjectsInSrc(" swap MultiAddress -> MultiAddressRunTime in Src") );
-        add( new swapMultiAddressObjectsInDst(" swap MultiAddress -> MultiAddressRunTime in Dst") );
+        add( new swapMultiAddressObjectsInSrc(
+                 " swap MultiAddress -> MultiAddressRunTime in Src") );
+        add( new swapMultiAddressObjectsInDst(
+                 " swap MultiAddress -> MultiAddressRunTime in Dst") );
 
-        add( new processMultiAddressObjectsInSrc("process MultiAddress objects in Src") );
-        add( new processMultiAddressObjectsInDst("process MultiAddress objects in Dst") );
+        add( new processMultiAddressObjectsInSrc(
+                 "process MultiAddress objects in Src") );
+        add( new processMultiAddressObjectsInDst(
+                 "process MultiAddress objects in Dst") );
 
         add( new splitIfFirewallInSrc("split rule if firewall is in Src"));
         add( new splitIfFirewallInDst("split rule if firewall is in Dst"));
         add( new fillDirection("determine directions"));
         add( new ExpandMultipleAddresses(
                  "expand objects with multiple addresses"));
+        add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
         add( new checkForDynamicInterfacesOfOtherObjects(
                  "check for dynamic interfaces of other hosts and firewalls"));
         add( new MACFiltering("verify for MAC address filtering"));
@@ -637,13 +652,14 @@ void PolicyCompiler_ipfw::compile()
 string PolicyCompiler_ipfw::debugPrintRule(Rule *r)
 {
     PolicyRule *rule=PolicyRule::cast(r);
+    string s= PolicyCompiler::debugPrintRule(rule);
 
-    string  iface = rule->getInterfaceId();
-    if (iface!="") {
+    int  iface = rule->getInterfaceId();
+    if (iface > -1)
+    {
 	Interface *rule_iface = getCachedFwInterface( iface );
-        iface=" intf: "+rule_iface->getName();
+        s += " intf: "+rule_iface->getName();
     }
-    string s= PolicyCompiler::debugPrintRule(rule)+" "+iface;
 
     return s;
 }
