@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipfw_writers.cpp,v 1.15 2007/05/08 02:11:39 vkurland Exp $
+  $Id: PolicyCompiler_ipfw_writers.cpp 545 2008-09-19 20:27:58Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -110,7 +110,7 @@ void PolicyCompiler_ipfw::PrintRule::_printProtocol(Service *srv)
 
 
 
-string PolicyCompiler_ipfw::PrintRule::_printPort(int rs,int re,bool neg)
+string PolicyCompiler_ipfw::PrintRule::_printPort(int rs,int re,bool )
 {
     ostringstream  str;
 
@@ -290,23 +290,34 @@ void PolicyCompiler_ipfw::PrintRule::_printAddr(Address  *o,bool neg)
         assert(atrt==NULL);
     }
 
-    IPAddress addr=o->getAddress();
-    Netmask   mask=o->getNetmask();
-
-    if (Interface::cast(o)!=NULL)  mask=Netmask("255.255.255.255");
-    if (IPv4::cast(o)!=NULL)       mask=Netmask("255.255.255.255");
-
-    if (addr.toString()=="0.0.0.0" && mask.toString()=="0.0.0.0") 
+    const InetAddr *addr = o->getAddressPtr();
+    if (Interface::cast(o)!=NULL && addr==NULL)
     {
-	compiler->output << "any ";
-    } else 
+        compiler->output << "me ";
+    }
+    if (addr)
     {
-	if (neg) compiler->output << "not ";
-	compiler->output << addr.toString();
-	if (mask.toString()!="255.255.255.255") {
-	    compiler->output << "/" << mask.getLength();
-	}
-	compiler->output << " ";
+        InetAddr mask = *(o->getNetmaskPtr());
+
+        if (Interface::cast(o)!=NULL)
+            mask = InetAddr(InetAddr::getAllOnes());
+
+        if (o->dimension()==1)
+            mask = InetAddr(InetAddr::getAllOnes());
+
+        if (addr->isAny() && mask.isAny()) 
+        {
+            compiler->output << "any ";
+        } else 
+        {
+            if (neg) compiler->output << "not ";
+            compiler->output << addr->toString();
+            if (!mask.isHostMask())
+            {
+                compiler->output << "/" << mask.getLength();
+            }
+            compiler->output << " ";
+        }
     }
 }
 
@@ -323,8 +334,8 @@ void PolicyCompiler_ipfw::PrintRule::_printDirection(libfwbuilder::PolicyRule *r
 
 void PolicyCompiler_ipfw::PrintRule::_printInterface(PolicyRule *r)
 {
-    string       iface_id = r->getInterfaceId();
-    if (iface_id!="") 
+    int iface_id = r->getInterfaceId();
+    if (iface_id > -1) 
     {
         switch (r->getDirection())
         {
@@ -377,8 +388,8 @@ string PolicyCompiler_ipfw::PrintRule::_printSrcService(Service *srv,bool neg)
 
     if (TCPService::isA(srv) || UDPService::isA(srv)) 
     {
-	int rs=srv->getInt("src_range_start");
-	int re=srv->getInt("src_range_end");
+	int rs=TCPUDPService::cast(srv)->getSrcRangeStart();
+	int re=TCPUDPService::cast(srv)->getSrcRangeEnd();
 	string s1= _printPort(rs,re,neg);
         if (!s1.empty()) res= s1;
     }
@@ -443,8 +454,8 @@ string PolicyCompiler_ipfw::PrintRule::_printDstService(Service *srv,bool neg)
 
     if (TCPService::isA(srv) || UDPService::isA(srv)) 
     {
-	int rs=srv->getInt("dst_range_start");
-	int re=srv->getInt("dst_range_end");
+	int rs=TCPUDPService::cast(srv)->getDstRangeStart();
+	int re=TCPUDPService::cast(srv)->getDstRangeEnd();
         string s1=_printPort(rs,re,neg);;
         if (!s1.empty()) res= s1;
     }
@@ -462,12 +473,8 @@ string PolicyCompiler_ipfw::PrintRule::_printDstService(Service *srv,bool neg)
     return res;
 }
 
-
-
-PolicyCompiler_ipfw::PrintRule::PrintRule(const std::string &name) : PolicyCompiler_pf::PrintRule(name)
-{ 
-    print_once_on_top=true;
-}
+PolicyCompiler_ipfw::PrintRule::PrintRule(const std::string &name) :
+    PolicyCompiler_pf::PrintRule(name) { }
 
 bool PolicyCompiler_ipfw::PrintRule::processNext()
 {
@@ -482,27 +489,6 @@ bool PolicyCompiler_ipfw::PrintRule::processNext()
 
     string quote = "\"";
 
-    if (print_once_on_top) 
-    {
-        compiler->output << quote << "$IPFW" << quote
-                         << " set disable 1" << endl;
-
-        /* checking if option add_check_state_rule is absent to
-         * provide for backward compatibility: before 2.1.6 build 131
-         * this option did not exist and compiler alawys generated
-         * check-state rule
-         */
-        if (options->getStr("add_check_state_rule").empty() ||
-            options->getBool("add_check_state_rule"))
-            compiler->output << quote << "$IPFW" << quote
-                             << " add 1 set 1 check-state ip from any to any"  << endl;
-
-        compiler->output << endl;
-
-        print_once_on_top=false;
-    }
-
-
     string rl=rule->getLabel();
     if (rl!=current_rule_label) 
     {
@@ -607,4 +593,29 @@ bool PolicyCompiler_ipfw::PrintRule::processNext()
     return true;
 }
 
+string PolicyCompiler_ipfw::defaultRules()
+{
+    FWOptions *options = fw->getOptionsObject();
+    string quote = "\"";
+    ostringstream res;
+
+    res << quote << "$IPFW" << quote
+        << " set disable 1" << endl;
+
+    /* checking if option add_check_state_rule is absent to
+     * provide for backward compatibility: before 2.1.6 build 131
+     * this option did not exist and compiler alawys generated
+     * check-state rule
+     */
+    if (options->getStr("add_check_state_rule").empty() ||
+        options->getBool("add_check_state_rule"))
+    {
+        res << quote << "$IPFW" << quote
+            << " add 1 set 1 check-state ip from any to any"  << endl;
+    }
+
+    res << endl;
+
+    return res.str();
+}
 
