@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf.cpp,v 1.29 2007/10/29 04:55:50 vkurland Exp $
+  $Id: PolicyCompiler_pf.cpp 545 2008-09-19 20:27:58Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -34,6 +34,7 @@
 #include "fwbuilder/ICMPService.h"
 #include "fwbuilder/TCPService.h"
 #include "fwbuilder/UDPService.h"
+#include "fwbuilder/TagService.h"
 #include "fwbuilder/Policy.h"
 #include "fwbuilder/Interface.h"
 #include "fwbuilder/Firewall.h"
@@ -83,7 +84,8 @@ int PolicyCompiler_pf::prolog()
     if (tables)
     {
         tables->init(dbcopy);
-        tables->setRuleSetName(getRuleSetName());
+        if (!getSourceRuleSet()->isTop())
+            tables->setRuleSetName(getRuleSetName());
     }
 
     return  PolicyCompiler::prolog();
@@ -124,7 +126,14 @@ bool PolicyCompiler_pf::swapAddressTableObjectsInRE::processNext()
         {
             MultiAddress *atbl = *i;
 
-            string mart_id = atbl->getId()+"_runtime";
+            // Need to make sure the ID of the MultiAddressRunTime
+            // object created here is stable and is always the same
+            // for the same MultiAddress object. In particular this
+            // ensures that we reuse tables between policy and NAT rules
+            string mart_id_str = FWObjectDatabase::getStringId(atbl->getId()) +
+                "_runtime";
+            int mart_id = FWObjectDatabase::registerStringId(mart_id_str);
+
             MultiAddressRunTime *mart = 
                 MultiAddressRunTime::cast(compiler->dbcopy->findInIndex(mart_id));
             if (mart==NULL)
@@ -338,8 +347,7 @@ bool PolicyCompiler_pf::fillDirection::processNext()
  * as long as it misses interface - we need to determine direction
  * again anyway.
  */
-
-    if (rule->getDirectionAsString()=="" || rule->getInterfaceId()=="" )
+    if (rule->getDirectionAsString()=="" || rule->getInterfaceId()==-1 )
     {
 	if ( compiler->getCachedFwOpt()->getBool("pass_all_out") )
         {
@@ -348,9 +356,9 @@ bool PolicyCompiler_pf::fillDirection::processNext()
         {
 	    rule->setDirection( PolicyRule::Both );
 
-	    Address  *src=compiler->getFirstSrc(rule);
-	    Address  *dst=compiler->getFirstDst(rule);
-	    string    fwid=compiler->getFwId();
+	    Address  *src = compiler->getFirstSrc(rule);
+	    Address  *dst = compiler->getFirstDst(rule);
+	    //int fwid = compiler->getFwId();
 
             if (src==NULL || dst==NULL)
                 compiler->abort("Broken src or dst in rule "+rule->getLabel());
@@ -374,133 +382,139 @@ bool PolicyCompiler_pf::fillDirection::processNext()
  */
 void PolicyCompiler_pf::addDefaultPolicyRule()
 {
-    if (!getRuleSetName().empty()) return;
-
-    if ( getCachedFwOpt()->getBool("mgmt_ssh") &&
-         !getCachedFwOpt()->getStr("mgmt_addr").empty() )
+    if (getSourceRuleSet()->isTop())
     {
-	PolicyRule *r;
-        TCPService *ssh=TCPService::cast(dbcopy->create(TCPService::TYPENAME) );
-        ssh->setInt("dst_range_start",22);
-        ssh->setInt("dst_range_end",22);
-        ssh->setName("mgmt_ssh");
-        dbcopy->add(ssh,false);
-        cacheObj(ssh); // to keep cache consistent
-
-        string mgmt_addr = getCachedFwOpt()->getStr("mgmt_addr");
-        IPAddress  addr;
-        Netmask netmask(32);
-        try
+        if ( getCachedFwOpt()->getBool("mgmt_ssh") &&
+             !getCachedFwOpt()->getStr("mgmt_addr").empty() )
         {
-            addr = IPAddress(mgmt_addr);
-            string::size_type sep = mgmt_addr.find("/");
-            if (sep != string::npos)
+            PolicyRule *r;
+            TCPService *ssh =
+                TCPService::cast(dbcopy->create(TCPService::TYPENAME) );
+            ssh->setDstRangeStart(22);
+            ssh->setDstRangeEnd(22);
+
+            ssh->setName("mgmt_ssh");
+            dbcopy->add(ssh,false);
+            cacheObj(ssh); // to keep cache consistent
+
+            string mgmt_addr = getCachedFwOpt()->getStr("mgmt_addr");
+            InetAddr  addr;
+            InetAddr netmask(InetAddr::getAllOnes());
+            try
             {
-                addr = IPAddress(mgmt_addr.substr(0,sep));
-                string nm = mgmt_addr.substr(sep+1);
-                int o1,o2,o3,o4;
-                if(sscanf(nm.c_str(), "%3u.%3u.%3u.%3u", &o1, &o2, &o3, &o4)==4)
+                addr = InetAddr(mgmt_addr);
+                string::size_type sep = mgmt_addr.find("/");
+                if (sep != string::npos)
                 {
-                    netmask = Netmask(nm);
-                } else
-                {
-                    sscanf(nm.c_str(),"%u",&o1);
-                    netmask = Netmask(o1);
+                    addr = InetAddr(mgmt_addr.substr(0,sep));
+                    string nm = mgmt_addr.substr(sep+1);
+                    int o1,o2,o3,o4;
+                    if (sscanf(nm.c_str(),
+                               "%3u.%3u.%3u.%3u", &o1, &o2, &o3, &o4)==4)
+                    {
+                        netmask = InetAddr(nm);
+                    } else
+                    {
+                        sscanf(nm.c_str(),"%u",&o1);
+                        netmask = InetAddr(o1);
+                    }
                 }
+            } catch(FWException &ex)
+            {
+                char errstr[256];
+                sprintf(errstr,
+                        _("Invalid address for the backup ssh access: '%s'"),
+                        mgmt_addr.c_str() );
+                abort( errstr );
             }
-        } catch(FWException &ex)
-        {
-            char errstr[256];
-            sprintf(errstr,
-                    _("Invalid address for the backup ssh access: '%s'"),
-                    mgmt_addr.c_str() );
-            abort( errstr );
-        }
 
-        Network *mgmt_workstation = Network::cast(dbcopy->create(Network::TYPENAME));
-        mgmt_workstation->setName("mgmt_addr");
-        mgmt_workstation->setAddress( addr );
-        mgmt_workstation->setNetmask( netmask );
+            Network *mgmt_workstation =
+                Network::cast(dbcopy->create(Network::TYPENAME));
+            mgmt_workstation->setName("mgmt_addr");
+            mgmt_workstation->setAddress( addr );
+            mgmt_workstation->setNetmask( netmask );
 //        IPv4 *mgmt_workstation = IPv4::cast(dbcopy->create(IPv4::TYPENAME));
 //        mgmt_workstation->setAddress( getCachedFwOpt()->getStr("mgmt_addr") );
-        dbcopy->add(mgmt_workstation,false);
-        cacheObj(mgmt_workstation); // to keep cache consistent
+            dbcopy->add(mgmt_workstation,false);
+            cacheObj(mgmt_workstation); // to keep cache consistent
 
 
-	r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
-	temp_ruleset->add(r);
-	r->setAction(PolicyRule::Accept);
-	r->setLogging(false);
-	r->setDirection(PolicyRule::Inbound);
-	r->setPosition(9999);
-        r->setComment("   backup ssh access rule ");
-        r->setHidden(true);
-        r->setFallback(false);
-        r->setLabel("backup ssh access rule");
-        r->setBool("needs_established",true);  // supported in ipfw
+            r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
+            temp_ruleset->add(r);
+            r->setAction(PolicyRule::Accept);
+            r->setLogging(false);
+            r->setDirection(PolicyRule::Inbound);
+            r->setPosition(9999);
+            r->setComment("   backup ssh access rule ");
+            r->setHidden(true);
+            r->setFallback(false);
+            r->setLabel("backup ssh access rule");
+            r->setBool("needs_established",true);  // supported in ipfw
 
-        RuleElement *src=r->getSrc();
-        assert(src!=NULL);
-        src->addRef(mgmt_workstation);
+            RuleElement *src=r->getSrc();
+            assert(src!=NULL);
+            src->addRef(mgmt_workstation);
 
-        RuleElement *dst=r->getDst();
-        assert(dst!=NULL);
-        dst->addRef(fw);
+            RuleElement *dst=r->getDst();
+            assert(dst!=NULL);
+            dst->addRef(fw);
 
-        RuleElement *srv=r->getSrv();
-        assert(srv!=NULL);
-        srv->addRef(ssh);
+            RuleElement *srv=r->getSrv();
+            assert(srv!=NULL);
+            srv->addRef(ssh);
 
-	combined_ruleset->push_front(r);
-    }
+            combined_ruleset->push_front(r);
+        }
 
-    if ( getCachedFwOpt()->getBool("pass_all_out") )
-    {
-	PolicyRule *r;
-        FWOptions *ruleopt;
+        if ( getCachedFwOpt()->getBool("pass_all_out") )
+        {
+            PolicyRule *r;
+            FWOptions *ruleopt;
 
-	r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
-	temp_ruleset->add(r);
-	r->setAction(PolicyRule::Accept);
-	r->setLogging( getCachedFwOpt()->getBool("fallback_log") );
-	r->setDirection(PolicyRule::Outbound);
-	r->setPosition(10000);
-        r->setComment("   fallback rule ");
-        r->setHidden(true);
-        r->setFallback(true);
-        r->setLabel("fallback rule");
-	combined_ruleset->push_back(r);
+            r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
+            temp_ruleset->add(r);
+            r->setAction(PolicyRule::Accept);
+            r->setLogging( getCachedFwOpt()->getBool("fallback_log") );
+            r->setDirection(PolicyRule::Outbound);
+            r->setPosition(10000);
+            r->setComment("   fallback rule ");
+            r->setHidden(true);
+            r->setFallback(true);
+            r->setLabel("fallback rule");
+            combined_ruleset->push_back(r);
 
-	r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
-	temp_ruleset->add(r);
-	r->setAction(PolicyRule::Deny);
-	r->setLogging( getCachedFwOpt()->getBool("fallback_log") );
-	r->setDirection(PolicyRule::Inbound);
-	r->setPosition(10001);
-        r->setComment("   fallback rule ");
-        r->setHidden(true);
-        r->setFallback(true);
-        r->setLabel("fallback rule");
-        ruleopt = r->getOptionsObject();
-        ruleopt->setBool("stateless", true);
-	combined_ruleset->push_back(r);
-    } else
-    {
-	PolicyRule *r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
-        FWOptions *ruleopt;
+            r= PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
+            temp_ruleset->add(r);
+            r->setAction(PolicyRule::Deny);
+            r->setLogging( getCachedFwOpt()->getBool("fallback_log") );
+            r->setDirection(PolicyRule::Inbound);
+            r->setPosition(10001);
+            r->setComment("   fallback rule ");
+            r->setHidden(true);
+            r->setFallback(true);
+            r->setLabel("fallback rule");
+            ruleopt = r->getOptionsObject();
+            ruleopt->setBool("stateless", true);
+            combined_ruleset->push_back(r);
+        } else
+        {
+            PolicyRule *r=
+                PolicyRule::cast(dbcopy->create(PolicyRule::TYPENAME) );
+            FWOptions *ruleopt;
 
-	temp_ruleset->add(r);
-	r->setAction(PolicyRule::Deny);
-	r->setLogging( getCachedFwOpt()->getBool("fallback_log") );
-	r->setDirection(PolicyRule::Both);
-	r->setPosition(10000);
-        r->setComment("   fallback rule ");
-        r->setHidden(true);
-        r->setFallback(true);
-        r->setLabel("fallback rule");
-        ruleopt = r->getOptionsObject();
-        ruleopt->setBool("stateless", true);
-	combined_ruleset->push_back(r);
+            temp_ruleset->add(r);
+            r->setAction(PolicyRule::Deny);
+            r->setLogging( getCachedFwOpt()->getBool("fallback_log") );
+            r->setDirection(PolicyRule::Both);
+            r->setPosition(10000);
+            r->setComment("   fallback rule ");
+            r->setHidden(true);
+            r->setFallback(true);
+            r->setLabel("fallback rule");
+            ruleopt = r->getOptionsObject();
+            ruleopt->setBool("stateless", true);
+            combined_ruleset->push_back(r);
+        }
     }
 }
 
@@ -719,14 +733,17 @@ bool PolicyCompiler_pf::addLoopbackForRedirect::processNext()
     RuleElementDst *dst=rule->getDst();
     RuleElementSrv *srv=rule->getSrv();
 
-    if (pf_comp->natcmp==NULL)
-        compiler->abort("addLoopbackForRedirect needs a valid pointer to the NAT compiler object");
+    if (pf_comp->redirect_rules_info==NULL)
+        compiler->abort(
+            "addLoopbackForRedirect needs a valid pointer to "
+            "the list<NATCompiler_pf::redirectRuleInfo> object");
 
     tmp_queue.push_back(rule);
 
-    const list<NATCompiler_pf::redirectRuleInfo> lst=pf_comp->natcmp->getRedirRulesInfo();
+    //const list<NATCompiler_pf::redirectRuleInfo> lst = 
+    //  pf_comp->natcmp->getRedirRulesInfo();
 
-    if (lst.empty()) return true;
+    if (pf_comp->redirect_rules_info->empty()) return true;
 
 /*
  *  struct redirectRuleInfo {
@@ -751,7 +768,8 @@ bool PolicyCompiler_pf::addLoopbackForRedirect::processNext()
             assert(a);
 
             list<NATCompiler_pf::redirectRuleInfo>::const_iterator k;
-            for (k=lst.begin(); k!=lst.end(); ++k)
+            for (k=pf_comp->redirect_rules_info->begin();
+                 k!=pf_comp->redirect_rules_info->end(); ++k)
             {
                 if ( *a == *(k->old_tdst) &&  *s == *(k->tsrv) )
                 {
@@ -857,53 +875,6 @@ bool PolicyCompiler_pf::splitIfInterfaceInRE::processNext()
     return true;
 }
 
-bool PolicyCompiler_pf::separateSrcPort::processNext()
-{
-    PolicyRule *rule=getNext(); if (rule==NULL) return false;
-
-    RuleElementSrv *rel= rule->getSrv();
-
-    if (rel->size()==1) {
-	tmp_queue.push_back(rule);
-	return true;
-    }
-
-    list<Service*> services;
-    for (FWObject::iterator i=rel->begin(); i!=rel->end(); i++) {
-	    
-	FWObject *o= *i;
-	if (FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
-	Service *s=Service::cast(o);
-	assert(s!=NULL);
-
-	if ( TCPService::isA(s) || UDPService::isA(s) ) {
-            int srs=s->getInt("src_range_start");
-            int sre=s->getInt("src_range_end");
-
-            compiler->normalizePortRange(srs,sre);
-
-            if (srs!=0 || sre!=0) {
-                PolicyRule *r= PolicyRule::cast(
-                    compiler->dbcopy->create(PolicyRule::TYPENAME) );
-                compiler->temp_ruleset->add(r);
-                r->duplicate(rule);
-                RuleElementSrv *nsrv=r->getSrv();
-                nsrv->clearChildren();
-                nsrv->addRef( s );
-                tmp_queue.push_back(r);
-                services.push_back(s);
-            } 
-        }
-    }
-    for (list<Service*>::iterator i=services.begin(); i!=services.end(); i++) 
-	rel->removeRef( (*i) );
-
-    if (!rel->isAny())
-	tmp_queue.push_back(rule);
-
-    return true;
-}
-
 bool PolicyCompiler_pf::createTables::processNext()
 {
     PolicyCompiler_pf *pf_comp=dynamic_cast<PolicyCompiler_pf*>(compiler);
@@ -940,8 +911,90 @@ bool PolicyCompiler_pf::printScrubRule::processNext()
     return true;
 }
 
+
+
+
+
+
+PolicyCompiler_pf::separateServiceObject::separateServiceObject(
+    const string &name) : PolicyRuleProcessor(name)
+{
+}
+
+bool PolicyCompiler_pf::separateServiceObject::processNext()
+{
+    PolicyRule *rule=getNext(); if (rule==NULL) return false;
+
+    RuleElementSrv *rel= rule->getSrv();
+
+    if (rel->size()==1) {
+	tmp_queue.push_back(rule);
+	return true;
+    }
+
+    list<Service*> services;
+    for (FWObject::iterator i=rel->begin(); i!=rel->end(); i++)
+    {
+	FWObject *o= *i;
+	if (FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
+	Service *s=Service::cast(o);
+	assert(s!=NULL);
+
+	if (condition(s))
+        {
+            PolicyRule *r= PolicyRule::cast(
+                compiler->dbcopy->create(PolicyRule::TYPENAME) );
+            compiler->temp_ruleset->add(r);
+            r->duplicate(rule);
+            RuleElementSrv *nsrv=r->getSrv();
+            nsrv->clearChildren();
+            nsrv->addRef( s );
+            tmp_queue.push_back(r);
+            services.push_back(s);
+        }
+    }
+    for (list<Service*>::iterator i=services.begin(); i!=services.end(); i++) 
+	rel->removeRef( (*i) );
+
+    if (!rel->isAny())
+	tmp_queue.push_back(rule);
+
+    return true;
+}
+
+
+bool PolicyCompiler_pf::separateSrcPort::condition(const Service *srv)
+{
+    if ( TCPService::isA(srv) || UDPService::isA(srv) )
+    {
+        int srs = TCPUDPService::constcast(srv)->getSrcRangeStart();
+        int sre = TCPUDPService::constcast(srv)->getSrcRangeEnd();
+
+        compiler->normalizePortRange(srs,sre);
+
+        return (srs!=0 || sre!=0);
+    }
+    return false;
+}
+
+bool PolicyCompiler_pf::separateTagged::condition(const Service *srv)
+{
+    return ( TagService::isA(srv));
+}
+
+bool PolicyCompiler_pf::separateTOS::condition(const Service *srv)
+{
+    const IPService *ip = IPService::constcast(srv);
+    return (ip && !ip->getTOSCode().empty());
+}
+
 void PolicyCompiler_pf::compile()
 {
+    cout << " Compiling " << fw->getName();
+    if (!getRuleSetName().empty())  cout << " ruleset " << getRuleSetName();
+    if (ipv6) cout << ", IPv6";
+    cout <<  endl << flush;
+
     try 
     {
 	Compiler::compile();
@@ -963,7 +1016,9 @@ void PolicyCompiler_pf::compile()
             add( new recursiveGroupsInSrv("check for recursive groups in SRV"));
             check_for_recursive_groups=false;
 
-            add( new ExpandGroups                ("expand groups"          ) );
+            add( new ExpandGroups("expand groups"          ) );
+            add( new dropRuleWithEmptyRE(
+                     "drop rules with empty rule elements"));
             add( new eliminateDuplicatesInSRC("eliminate duplicates in SRC") );
             add( new eliminateDuplicatesInDST("eliminate duplicates in DST") );
             add( new eliminateDuplicatesInSRV("eliminate duplicates in SRV") );
@@ -982,6 +1037,8 @@ void PolicyCompiler_pf::compile()
                      "expand objects with multiple addresses in SRC" ) );
             add( new ExpandMultipleAddressesInDST(
                      "expand objects with multiple addresses in DST" ) );
+            add( new dropRuleWithEmptyRE(
+                     "drop rules with empty rule elements"));
             add( new ConvertToAtomic             ("convert to atomic rules") );
             add( new DetectShadowing             ("Detect shadowing"       ) );
             add( new simplePrintProgress         (                         ) );
@@ -1011,6 +1068,7 @@ void PolicyCompiler_pf::compile()
 
 // ExpandGroups opens groups, as well as groups in groups etc.
         add( new ExpandGroups(          "expand groups"                      ));
+        add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
 
         add( new CheckForTCPEstablished(
                  "check for TCPService objects with flag \"established\"") );
@@ -1038,22 +1096,26 @@ void PolicyCompiler_pf::compile()
         add( new InterfacePolicyRules(
                  "process interface policy rules and store interface ids") );
 
-	add( new splitIfFirewallInSrc(  "split rule if firewall is in Src"   ));
-	add( new splitIfFirewallInDst(  "split rule if firewall is in Dst"   ));
-	add( new fillDirection(         "determine directions"               ));
-	add( new SplitDirection(        "split rules with direction 'both'"  ));
+	add( new splitIfFirewallInSrc("split rule if firewall is in Src"   ));
+	add( new splitIfFirewallInDst("split rule if firewall is in Dst"   ));
+	add( new fillDirection("determine directions"               ));
+	add( new SplitDirection("split rules with direction 'both'"  ));
         add( new addLoopbackForRedirect(
                  "add loopback to rules that permit redirected services" ) );
 	add( new ExpandMultipleAddresses(
                  "expand objects with multiple addresses" ) );
+        add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
         add( new checkForDynamicInterfacesOfOtherObjects(
                  "check for dynamic interfaces of other hosts and firewalls" ));
-        add( new MACFiltering(          "verify for MAC address filtering"   ));
-        add( new checkForUnnumbered(    "check for unnumbered interfaces"    ));
-	add( new addressRanges(         "expand address range objects"       ));
-	add( new splitServices(       "split rules with different protocols"));
+        add( new MACFiltering("verify for MAC address filtering"   ));
+        add( new checkForUnnumbered("check for unnumbered interfaces"    ));
+	add( new addressRanges("expand address range objects"       ));
+	add( new splitServices("split rules with different protocols"));
 	add( new separateTCPWithFlags("separate TCP services with flags"    ));
         add( new separateSrcPort("split on TCP and UDP with source ports"));
+        add( new separateTagged("split on TagService"));
+        add( new separateTOS("split on IPService with TOS"));
+
 	add( new verifyCustomServices(
                  "verify custom services for this platform"));
 //	add( new ProcessScrubOption(    "process 'scrub' option"         ));
