@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf.h,v 1.10 2006/06/17 21:53:54 vkurland Exp $
+  $Id: PolicyCompiler_pf.h 324 2008-07-06 02:02:26Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -29,6 +29,7 @@
 #include <fwbuilder/libfwbuilder-config.h>
 #include "fwcompiler/PolicyCompiler.h"
 
+#include "NATCompiler_pf.h"
 #include "TableFactory.h"
 
 namespace libfwbuilder {
@@ -45,8 +46,6 @@ namespace libfwbuilder {
 
 namespace fwcompiler {
 
-    class NATCompiler_pf;
-
     class PolicyCompiler_pf : public PolicyCompiler {
 
 	public:
@@ -355,12 +354,55 @@ namespace fwcompiler {
                 eliminateDuplicatesInRE(n,libfwbuilder::RuleElementSrv::TYPENAME) {}
         };
 
+        /**
+	 * separate service object that satisfies condition
+	 * implemented in the virtual method "condition" so we have
+	 * exactly one such object per rule.
+	 */
+        class separateServiceObject : public PolicyRuleProcessor
+        {
+            protected:
+            virtual bool condition(const libfwbuilder::Service *srv) =0;
+            public:
+            separateServiceObject(const std::string &name);
+            virtual bool processNext();
+        };
+
 	/**
 	 * separate TCP/UDP services that specify source port (can
 	 * not be used in combination with destination port with
 	 * multiport)
 	 */
-        DECLARE_POLICY_RULE_PROCESSOR(separateSrcPort);
+        class separateSrcPort : public separateServiceObject
+        {
+            protected:
+            virtual bool condition(const libfwbuilder::Service *srv);
+            public:
+            separateSrcPort(const std::string &name) : separateServiceObject(name) {}
+        };
+        
+        /**
+	 * separate Tag services so we have exactly one per rule.
+	 */
+        class separateTagged : public separateServiceObject
+        {
+            protected:
+            virtual bool condition(const libfwbuilder::Service *srv);
+            public:
+            separateTagged(const std::string &name) : separateServiceObject(name) {}
+        };
+
+        /**
+	 * separate IPService objects with tos attrubute so we have
+	 * exactly one per rule.
+	 */
+        class separateTOS : public separateServiceObject
+        {
+            protected:
+            virtual bool condition(const libfwbuilder::Service *srv);
+            public:
+            separateTOS(const std::string &name) : separateServiceObject(name) {}
+        };
 
 
         class printScrubRule : public PolicyRuleProcessor
@@ -422,8 +464,10 @@ namespace fwcompiler {
             virtual void _printLogging(libfwbuilder::PolicyRule *r);
             virtual void _printDirection(libfwbuilder::PolicyRule *r);
             virtual void _printInterface(libfwbuilder::PolicyRule *r);
+            virtual void _printAF(libfwbuilder::PolicyRule *r);
             virtual void _printLabel(libfwbuilder::PolicyRule *r);
             virtual void _printQueue(libfwbuilder::PolicyRule *r);
+            virtual void _printUser(libfwbuilder::PolicyRule *r);
             virtual void _printTag(libfwbuilder::PolicyRule *r);
             virtual std::string _printLogPrefix(libfwbuilder::PolicyRule *r,const std::string &prefix);
 
@@ -431,6 +475,7 @@ namespace fwcompiler {
             PrintRule(const std::string &name);
             virtual bool processNext();
         };
+        friend class PolicyCompiler_pf::PrintRule;
  
 
 	virtual std::string myPlatformName();
@@ -440,11 +485,13 @@ namespace fwcompiler {
 
 	PolicyCompiler_pf(libfwbuilder::FWObjectDatabase *_db,
 			  const std::string &fwname,
+                          bool ipv6_policy,
 			  fwcompiler::OSConfigurator *_oscnf,
-                          NATCompiler_pf *_natcmp,
-                          TableFactory *tbf = NULL) : PolicyCompiler(_db,fwname,_oscnf) 
+                          const std::list<NATCompiler_pf::redirectRuleInfo> *rri,
+                          TableFactory *tbf = NULL) :
+        PolicyCompiler(_db, fwname, ipv6_policy, _oscnf) 
         {
-            natcmp=_natcmp;
+            redirect_rules_info = rri;
             tables = tbf;
         }
 
@@ -455,9 +502,8 @@ namespace fwcompiler {
 	protected:
 
         TableFactory           *tables;
-        NATCompiler_pf         *natcmp;
 	libfwbuilder::IPv4     *loopback_address;
-
+        const std::list<NATCompiler_pf::redirectRuleInfo> *redirect_rules_info;
 
 
         private:
