@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf_writers.cpp,v 1.28 2008/05/06 03:18:50 vkurland Exp $
+  $Id: PolicyCompiler_pf_writers.cpp 555 2008-09-26 18:58:17Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -30,10 +30,12 @@
 #include "fwbuilder/RuleElement.h"
 #include "fwbuilder/IPService.h"
 #include "fwbuilder/ICMPService.h"
+#include "fwbuilder/ICMP6Service.h"
 #include "fwbuilder/TCPService.h"
 #include "fwbuilder/UDPService.h"
 #include "fwbuilder/CustomService.h"
 #include "fwbuilder/TagService.h"
+#include "fwbuilder/UserService.h"
 #include "fwbuilder/Policy.h"
 #include "fwbuilder/FWOptions.h"
 #include "fwbuilder/FWObjectDatabase.h"
@@ -117,8 +119,14 @@ void PolicyCompiler_pf::PrintRule::_printAction(PolicyRule *rule)
         compiler->output << ruleopt->getStr("custom_str") << " ";
         break;
     case PolicyRule::Branch:
-        compiler->output << "anchor " << ruleopt->getStr("branch_name") << " ";
+    {
+        RuleSet *ruleset = rule->getBranch();
+        if (ruleset==NULL)
+            compiler->abort(string("Branching rule ") + rule->getLabel() +
+                            " refers ruleset that does not exist");
+        compiler->output << "anchor " << ruleset->getName() << " ";
         break;
+    }
     default:
         compiler->abort(
             string("Unknown action '") + rule->getActionAsString()
@@ -180,14 +188,14 @@ void PolicyCompiler_pf::PrintRule::_printRouteOptions(PolicyRule *rule)
                         compiler->output << roif << " ";
                         compiler->output << roaddr << " ";
                         compiler->output << ") ";
-                        int sp = roaddr.find('/');
+                        std::string::size_type sp = roaddr.find('/');
                         if (sp!=std::string::npos) 
                         {
                             // roaddr is addr/netmask
                             try 
                             {
                                 string a = roaddr.substr(0,sp);
-                                IPAddress roaddr_addr = IPAddress(a);
+                                InetAddr roaddr_addr = InetAddr(a);
                             } catch (FWException &ex)
                             {
                                 compiler->abort(
@@ -195,14 +203,14 @@ void PolicyCompiler_pf::PrintRule::_printRouteOptions(PolicyRule *rule)
                             }
                             try
                             {
-                                Netmask roaddr_netmask;
+                                InetAddr roaddr_netmask;
                                 string n = roaddr.substr(sp+1);
                                 if (n.find('.')!=std::string::npos)
                                 {
-                                    roaddr_netmask = n;
+                                    roaddr_netmask = InetAddr(n);
                                 } else
                                 {
-                                    roaddr_netmask = Netmask(
+                                    roaddr_netmask = InetAddr(
                                         atoi(n.c_str()));
                                 }
                                 if (roaddr_netmask.getLength()==32)
@@ -224,7 +232,7 @@ void PolicyCompiler_pf::PrintRule::_printRouteOptions(PolicyRule *rule)
                             // roaddr is just an addres
                             try 
                             {
-                                IPAddress roaddr_addr = IPAddress(roaddr);
+                                InetAddr roaddr_addr = InetAddr(roaddr);
                             } catch (FWException &ex)
                             {
                                 compiler->abort(
@@ -276,12 +284,48 @@ void PolicyCompiler_pf::PrintRule::_printQueue(PolicyRule *rule)
         compiler->output << "queue " << ruleopt->getStr("classify_str") << " ";
 }
 
+void PolicyCompiler_pf::PrintRule::_printUser(PolicyRule *rule)
+{
+    RuleElementSrv *srvrel = rule->getSrv();
+    FWObject *o = srvrel->front();
+    if (o && FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
+    Service *srv= Service::cast(o);
+    if (!UserService::isA(srv)) return;
+    ostringstream str;
+
+    if (srvrel->size()==1) 
+    {
+        str << "user ";
+        if (srvrel->getNeg()) str << "!= ";
+        str << UserService::constcast(srv)->getUserId() << " ";
+        compiler->output << str.str() << " ";
+    } else 
+    {
+        int counter = 0;
+	for (FWObject::iterator i=srvrel->begin(); i!=srvrel->end(); i++) 
+        {
+	    FWObject *o= *i;
+	    if (FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
+	    Service *s=Service::cast( o );
+	    assert(s);
+            if (counter > 0) str << ",";
+            str << " ";
+            if (srvrel->getNeg()) str << "!= ";
+            str << UserService::constcast(s)->getUserId();
+            counter++;
+	}
+	if ( counter )
+        {
+            compiler->output << "user {" << str.str() << " } ";
+	}
+    }
+}
+
 void PolicyCompiler_pf::PrintRule::_printTag(PolicyRule *rule)
 {
-    FWOptions *ruleopt =rule->getOptionsObject();
-
     if (rule->getAction() == PolicyRule::Tag)
-        compiler->output << "tag " << ruleopt->getStr("tagvalue") << " ";
+        compiler->output << "tag " << rule->getTagValue() << " ";
+//        compiler->output << "tag " << ruleopt->getStr("tagvalue") << " ";
 }
 
 void PolicyCompiler_pf::PrintRule::_printDirection(PolicyRule *rule)
@@ -358,12 +402,21 @@ void PolicyCompiler_pf::PrintRule::_printInterface(PolicyRule *rule)
 	compiler->output << "on " << iface_name << " ";
 }
 
+// print address family
+void PolicyCompiler_pf::PrintRule::_printAF(PolicyRule*)
+{
+    PolicyCompiler_pf *pf_comp=dynamic_cast<PolicyCompiler_pf*>(compiler);
+    if (pf_comp->ipv6) compiler->output << "inet6 ";
+    else compiler->output << "inet ";
+}
+
 void PolicyCompiler_pf::PrintRule::_printProtocol(libfwbuilder::Service *srv)
 {
 
     if (!srv->isAny() &&
         !CustomService::isA(srv) &&
-        !TagService::isA(srv) &&
+        !TagService::isA(srv) && 
+        !UserService::isA(srv) && 
         srv->getProtocolName()!="ip")
     {
 	compiler->output << "proto ";
@@ -418,7 +471,7 @@ string PolicyCompiler_pf::PrintRule::_printPort(int rs,int re,bool neg)
 }
 
 /*
- * we made sure that all services in rel  represent the same protocol
+ * we made sure that all services in rel  represent the same protocol. 
  */
 void PolicyCompiler_pf::PrintRule::_printSrcService(RuleElementSrv  *rel)
 {
@@ -429,39 +482,46 @@ void PolicyCompiler_pf::PrintRule::_printSrcService(RuleElementSrv  *rel)
     if (o && FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
 
     Service *srv= Service::cast(o);
+    string prefix = "";
+    if (UDPService::isA(srv) || TCPService::isA(srv)) prefix = "port ";
 
-    if (rel->size()==1) {
-	if (UDPService::isA(srv) || TCPService::isA(srv)) {
+    if (rel->size()==1)
+    {
+        if (UDPService::isA(srv) || TCPService::isA(srv))
+        {
 	    string str=_printSrcService( srv , rel->getNeg());
-	    if (! str.empty() ) compiler->output << "port " << str << " ";
-	}
-    } else {
-
+            if (! str.empty() ) compiler->output << prefix << str << " ";
+        }
+    } else
+    {
 	string str;
-	for (FWObject::iterator i=rel->begin(); i!=rel->end(); i++) {
+	for (FWObject::iterator i=rel->begin(); i!=rel->end(); i++)
+        {
 	    FWObject *o= *i;
-	    if (FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
-	    Service *s=Service::cast( o );
+	    if (FWReference::cast(o)!=NULL)
+                o=FWReference::cast(o)->getPointer();
+	    Service *s = Service::cast( o );
 	    assert(s);
-	    if (UDPService::isA(srv) || TCPService::isA(srv)) {
-		string str1= _printSrcService(s , rel->getNeg() );
-		if (! str.empty() && ! str1.empty() )  str = str + ", ";
-		str = str + str1;
-	    }
-	}
-	if ( !str.empty() ) {
-	    compiler->output << "port { " << str << "} ";
+            string str1;
+
+	    if (UDPService::isA(srv) || TCPService::isA(srv))
+                str1 = _printSrcService(s , rel->getNeg() );
+
+            if (! str.empty() && ! str1.empty() )  str = str + ", ";
+            str = str + str1;
 	}
+	if ( !str.empty() )
+	    compiler->output << prefix << "{ " << str << "} ";
     }
 }
 
-string PolicyCompiler_pf::PrintRule::_printSrcService(Service *srv,bool neg)
+string PolicyCompiler_pf::PrintRule::_printSrcService(Service *srv, bool neg)
 {
     ostringstream  str;
     if (TCPService::isA(srv) || UDPService::isA(srv)) 
     {
-	int rs=srv->getInt("src_range_start");
-	int re=srv->getInt("src_range_end");
+	int rs=TCPUDPService::cast(srv)->getSrcRangeStart();
+	int re=TCPUDPService::cast(srv)->getSrcRangeEnd();
 	str << _printPort(rs,re,neg);
     }
     return str.str();
@@ -471,10 +531,8 @@ void PolicyCompiler_pf::PrintRule::_printDstService(RuleElementSrv  *rel)
 {
     FWObject *o=rel->front();
     if (o && FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
-
     Service *srv= Service::cast(o);
 
-
     if (rel->size()==1) 
     {
 	string str=_printDstService( srv , rel->getNeg());
@@ -487,7 +545,10 @@ void PolicyCompiler_pf::PrintRule::_printDstService(RuleElementSrv  *rel)
                 if (ICMPService::isA(srv)) 
                     compiler->output << "icmp-type " << str << " ";
                 else
-                    compiler->output << str << " ";
+                    if (ICMP6Service::isA(srv)) 
+                        compiler->output << "icmp6-type " << str << " ";
+                    else
+                        compiler->output << str << " ";
             }
 	}
 	if (TCPService::isA(srv)) 
@@ -495,9 +556,17 @@ void PolicyCompiler_pf::PrintRule::_printDstService(RuleElementSrv  *rel)
 	    str=_printTCPFlags(TCPService::cast(srv));
 	    if (!str.empty()) compiler->output << "flags " << str << " ";
 	}
-        if (IPService::isA(srv) && (srv->getBool("fragm") || srv->getBool("short_fragm")) )
+        if (IPService::isA(srv))
+        {
+            if (srv->getBool("fragm") || srv->getBool("short_fragm"))
                 compiler->output << " fragment ";
-
+            const IPService *ip = IPService::constcast(srv);
+            string tos = ip->getTOSCode();
+            string dscp = ip->getDSCPCode();
+            if (!tos.empty()) compiler->output << " tos " << tos;
+            if (!dscp.empty())
+                compiler->abort("PF does not support DSCP matching");
+        }
     } else 
     {
 	string str;
@@ -520,19 +589,24 @@ void PolicyCompiler_pf::PrintRule::_printDstService(RuleElementSrv  *rel)
                 if (ICMPService::isA(srv)) 
                     compiler->output << "icmp-type { " << str << " } ";
                 else
-                    compiler->output << str << " " << endl;
+                {
+                    if (ICMP6Service::isA(srv)) 
+                        compiler->output << "icmp6-type { " << str << " } ";
+                    else
+                        compiler->output << str << " " << endl;
+                }
             }
 	}
     }
 }
 
-string PolicyCompiler_pf::PrintRule::_printDstService(Service *srv,bool neg)
+string PolicyCompiler_pf::PrintRule::_printDstService(Service *srv, bool neg)
 {
     ostringstream  str;
     if (TCPService::isA(srv) || UDPService::isA(srv)) 
     {
-	int rs=srv->getInt("dst_range_start");
-	int re=srv->getInt("dst_range_end");
+	int rs=TCPUDPService::cast(srv)->getDstRangeStart();
+	int re=TCPUDPService::cast(srv)->getDstRangeEnd();
 	str << _printPort(rs,re,neg);
     }
 
@@ -545,12 +619,13 @@ string PolicyCompiler_pf::PrintRule::_printDstService(Service *srv,bool neg)
 
     if (CustomService::isA(srv)) 
     {
-	str << CustomService::cast(srv)->getCodeForPlatform( compiler->myPlatformName() ) << " ";
+	str << CustomService::cast(srv)->getCodeForPlatform(
+            compiler->myPlatformName() ) << " ";
     }
 
     if (TagService::isA(srv)) 
     {
-	str << "tagged " << TagService::cast(srv)->getCode() << " ";
+	str << "tagged " << TagService::constcast(srv)->getCode() << " ";
     }
 
     return str.str();
@@ -578,7 +653,7 @@ string PolicyCompiler_pf::PrintRule::_printTCPFlags(libfwbuilder::TCPService *sr
     return str;
 }
 
-void PolicyCompiler_pf::PrintRule::_printAddr(Address  *o,bool neg)
+void PolicyCompiler_pf::PrintRule::_printAddr(Address  *o,bool )
 {
     MultiAddressRunTime *atrt = MultiAddressRunTime::cast(o);
     if (atrt!=NULL)
@@ -596,8 +671,8 @@ void PolicyCompiler_pf::PrintRule::_printAddr(Address  *o,bool neg)
         assert(atrt==NULL);
     }
 
-    IPAddress addr=o->getAddress();
-    Netmask   mask=o->getNetmask();
+    const InetAddr *addr = o->getAddressPtr();
+    InetAddr mask = *(o->getNetmaskPtr());
 
     if (Interface::cast(o)!=NULL)
     {
@@ -608,22 +683,22 @@ void PolicyCompiler_pf::PrintRule::_printAddr(Address  *o,bool neg)
 	    return;
 	}
 
-	mask=Netmask("255.255.255.255");
+	mask = InetAddr(InetAddr::getAllOnes());
     }
 
-    if (IPv4::cast(o)!=NULL) 
+    if (o->dimension()==1) 
     {
-	mask=Netmask("255.255.255.255");
+	mask = InetAddr(InetAddr::getAllOnes());
     }
 
-    if (addr.toString()=="0.0.0.0" && mask.toString()=="0.0.0.0") 
+    if (addr->isAny() && mask.isAny()) 
     {
 	compiler->output << "any ";
     } else 
     {
 //	if (neg) compiler->output << "! ";
-	compiler->output << addr.toString();
-	if (mask.toString()!="255.255.255.255")
+	compiler->output << addr->toString();
+	if (!mask.isHostMask())
         {
 	    compiler->output << "/" << mask.getLength();
 	}
@@ -659,7 +734,14 @@ void PolicyCompiler_pf::PrintRule::_printSrcAddr(RuleElementSrc  *rel)
     if (o==NULL)
     {
         PolicyRule *rule = PolicyRule::cast(rel->getParent());
-        compiler->abort("Broken rule element " + rel->getTypeName() + " in rule '" + rule->getLabel() + "'  rel->front(): " + oref->getPointerId());
+        ostringstream errstr;
+        errstr << "Broken rule element " 
+               << rel->getTypeName()
+               << " in rule '"
+               << rule->getLabel()
+               << "'  rel->front(): "
+               << oref->getPointerId();
+        compiler->abort(errstr.str());
     }
 
     if (rel->size()==1 && ! o->getBool("pf_table") )
@@ -691,7 +773,14 @@ void PolicyCompiler_pf::PrintRule::_printDstAddr(RuleElementDst  *rel)
     if (o==NULL)
     {
         PolicyRule *rule = PolicyRule::cast(rel->getParent());
-        compiler->abort("Broken rule element " + rel->getTypeName() + " in rule '" + rule->getLabel() + "'  rel->front(): " + oref->getPointerId());
+        ostringstream errstr;
+        errstr << "Broken rule element "
+               << rel->getTypeName()
+               << " in rule '"
+               << rule->getLabel()
+               <<  "'  rel->front(): "
+               << oref->getPointerId();
+        compiler->abort(errstr.str());
     }
 
     if (rel->size()==1 && ! o->getBool("pf_table") )
@@ -773,7 +862,7 @@ bool PolicyCompiler_pf::PrintRule::processNext()
 
     _printRouteOptions(rule);
 
-    compiler->output << "inet ";
+    _printAF(rule);
 
     _printProtocol(srv);
 
@@ -788,6 +877,7 @@ bool PolicyCompiler_pf::PrintRule::processNext()
     _printDstService(srvrel);
 
     _printTag(rule);
+    _printUser(rule);
 
 /* 
  * Dealing with "keep state" and "modulate state" flags
@@ -830,34 +920,45 @@ bool PolicyCompiler_pf::PrintRule::processNext()
             }
         }
 
-	if (compiler->getCachedFwOpt()->getBool("modulate_state") &&
+        // in PF "modulate state", "synproxy state", "keep state" are mutually
+        // exclusive
+        // "keep state" can be used with any protocol, while "modulate state"
+        // and "synproxy state" can only be used with tcp.
+
+	if (compiler->getCachedFwOpt()->getBool("pf_synproxy") &&
             tcpsrv!=NULL)
-	    compiler->output << "modulate state ";
-	else
+	    compiler->output << "synproxy state ";
+        else
         {
-            /*
-             * "flags S/SA keep state" is implicit in 4.x
-             * However see section "1.2. Operational changes" in
-             *  http://www.openbsd.org/faq/upgrade41.html
-             *
-             * Quote:
-             *
-             * In particular care should be taken with the enc0
-             * interface, as floating states are a potential problem
-             * for filtering IPsec traffic: states need to be
-             * interface bound, to avoid permitting unencrypted
-             * traffic should isakmpd(8) exit. Therefore all rules on
-             * the enc0 interface should explicitly set keep state
-             * (if-bound).
-             *
-             * This seems to imply that even though "keep state" is
-             * the default, it should be explicitly used with enc0
-             * interface. Adding rule option "Set 'keep state'
-             * explicitly" to cope with this.
-             */
-            if ( version != "4.x" ||
-                 compiler->getCachedFwOpt()->getBool("pf_keep_state"))
-                compiler->output << "keep state ";
+            if (compiler->getCachedFwOpt()->getBool("pf_modulate_state") &&
+                tcpsrv!=NULL)
+                compiler->output << "modulate state ";
+            else
+            {
+                /*
+                 * "flags S/SA keep state" is implicit in 4.x
+                 * However see section "1.2. Operational changes" in
+                 *  http://www.openbsd.org/faq/upgrade41.html
+                 *
+                 * Quote:
+                 *
+                 * In particular care should be taken with the enc0
+                 * interface, as floating states are a potential problem
+                 * for filtering IPsec traffic: states need to be
+                 * interface bound, to avoid permitting unencrypted
+                 * traffic should isakmpd(8) exit. Therefore all rules on
+                 * the enc0 interface should explicitly set keep state
+                 * (if-bound).
+                 *
+                 * This seems to imply that even though "keep state" is
+                 * the default, it should be explicitly used with enc0
+                 * interface. Adding rule option "Set 'keep state'
+                 * explicitly" to cope with this.
+                 */
+                if ( version != "4.x" ||
+                     compiler->getCachedFwOpt()->getBool("pf_keep_state"))
+                    compiler->output << "keep state ";
+            }
         }
 
         int nopt=0;
