@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Preprocessor_pf.h,v 1.1 2006/05/21 04:47:10 vkurland Exp $
+  $Id: Preprocessor_pf.h 312 2008-07-05 17:40:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -41,7 +41,9 @@ namespace fwcompiler {
 	public:
 
 	Preprocessor_pf(libfwbuilder::FWObjectDatabase *_db,
-                        const std::string &fwname) : Preprocessor(_db,fwname)
+                        const std::string &fwname,
+                        bool ipv6_policy) :
+        Preprocessor(_db, fwname, ipv6_policy)
         { }
 
         virtual void convertObject(libfwbuilder::FWObject *obj);
