@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_pix_writers.cpp,v 1.1 2008/03/06 06:48:59 vkurland Exp $
+  $Id: NATCompiler_pix_writers.cpp 312 2008-07-05 17:40:12Z vadim $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -51,7 +51,6 @@ using namespace std;
 
 bool NATCompiler_pix::PrintClearCommands::processNext()
 {
-    NATCompiler_pix *pix_comp=dynamic_cast<NATCompiler_pix*>(compiler);
     string version = compiler->fw->getStr("version");
     string platform = compiler->fw->getStr("platform");
 
@@ -83,8 +82,8 @@ bool NATCompiler_pix::PrintClearCommands::processNext()
 
 string NATCompiler_pix::PrintRule::_printAddress(Address *a,bool print_netmask)
 {
-    string addr=a->getAddress().toString();
-    string mask=a->getNetmask().toString();
+    string addr = a->getAddressPtr()->toString();
+    string mask = a->getNetmaskPtr()->toString();
     if (addr=="0.0.0.0" && mask=="0.0.0.0") return "any";
 //    if (addr=="0.0.0.0") addr="0";
 //    if (mask=="0.0.0.0") mask="0";
@@ -119,8 +118,8 @@ void NATCompiler_pix::PrintRule::_printNONAT(NATRule *rule)
     {
     case NONAT_NAT0:
     {
-        nonat n0=pix_comp->nonat_rules[rule->getId()];
-        Interface *iface1=n0.i_iface;
+        nonat n0 = pix_comp->nonat_rules[rule->getId()];
+        Interface *iface1 = n0.i_iface;
 //        Interface *iface2=n0.o_iface;
 
         if (rule->getBool("use_nat_0_0"))
@@ -135,7 +134,8 @@ void NATCompiler_pix::PrintRule::_printNONAT(NATRule *rule)
             compiler->output << endl;
 
             if (pix_comp->getACLFlag(n0.acl_name)==0 && 
-                compiler->fw->getOptionsObject()->getBool("pix_acl_substitution"))
+                compiler->fw->getOptionsObject()->getBool(
+                    "pix_acl_substitution"))
             {
                 compiler->output << clearACLcmd <<" " << n0.acl_name << endl;
                 pix_comp->setACLFlag(n0.acl_name,1);
@@ -149,10 +149,11 @@ void NATCompiler_pix::PrintRule::_printNONAT(NATRule *rule)
                              << _printAddress(n0.dst,true)
                              << endl;
 
-            if ( pix_comp->first_nonat_rule_id[iface1->getId()]==rule->getId() )
+            if (pix_comp->first_nonat_rule_id[iface1->getId()]==rule->getId())
             {
                 if (compiler->fw->getStr("platform")=="fwsm" && 
-                    compiler->fw->getOptionsObject()->getBool("pix_use_manual_commit") )
+                    compiler->fw->getOptionsObject()->getBool(
+                        "pix_use_manual_commit") )
                 {
                     compiler->output << "access-list commit" << endl;
                     compiler->output << endl;
@@ -171,12 +172,14 @@ void NATCompiler_pix::PrintRule::_printNONAT(NATRule *rule)
 	Address  *osrc=compiler->getFirstOSrc(rule);  assert(osrc);
 	Address  *odst=compiler->getFirstODst(rule);  assert(odst);
 
-        Interface *osrc_iface=compiler->getCachedFwInterface( helper.findInterfaceByNetzone(osrc ) );
-        Interface *odst_iface=compiler->getCachedFwInterface( helper.findInterfaceByNetzone(odst ) );
+        Interface *osrc_iface = compiler->getCachedFwInterface(
+            helper.findInterfaceByNetzone(osrc ) );
+        Interface *odst_iface = compiler->getCachedFwInterface(
+            helper.findInterfaceByNetzone(odst ) );
 
-        string addr=odst->getAddress().toString();
+        string addr=odst->getAddressPtr()->toString();
 	string mask;
-	if (Network::isA(odst)) mask=odst->getNetmask().toString();
+	if (Network::isA(odst)) mask=odst->getNetmaskPtr()->toString();
 	else mask="255.255.255.255";
 
         compiler->output << "static (" 
@@ -203,7 +206,7 @@ void NATCompiler_pix::PrintRule::_printPort(Service *srv)
 {
     if (TCPService::isA(srv) || UDPService::isA(srv))
     {
-	int drs=srv->getInt("dst_range_start");
+	int drs=TCPUDPService::cast(srv)->getDstRangeStart();
 
 	if (drs!=0)   compiler->output << drs << " ";
     }
@@ -215,8 +218,8 @@ string NATCompiler_pix::PrintRule::_printSrcService(Service *srv)
 
     if (TCPService::isA(srv) || UDPService::isA(srv)) 
     {
-	int rs=srv->getInt("src_range_start");
-	int re=srv->getInt("src_range_end");
+	int rs=TCPUDPService::cast(srv)->getSrcRangeStart();
+	int re=TCPUDPService::cast(srv)->getSrcRangeEnd();
 
         if (rs<0) rs=0;
         if (re<0) re=0;
@@ -239,8 +242,8 @@ string NATCompiler_pix::PrintRule::_printDstService(Service *srv)
     ostringstream  str;
 
     if (TCPService::isA(srv) || UDPService::isA(srv)) {
-	int rs=srv->getInt("dst_range_start");
-	int re=srv->getInt("dst_range_end");
+	int rs=TCPUDPService::cast(srv)->getDstRangeStart();
+	int re=TCPUDPService::cast(srv)->getDstRangeEnd();
 
         if (rs<0) rs=0;
         if (re<0) re=0;
@@ -328,8 +331,8 @@ bool NATCompiler_pix::PrintRule::processNext()
     Service  *tsrv=compiler->getFirstTSrv(rule);  assert(tsrv);
 
 
-    Interface *iface_orig = compiler->getCachedFwInterface( rule->getStr("nat_iface_orig") );
-    Interface *iface_trn  = compiler->getCachedFwInterface( rule->getStr("nat_iface_trn" ) );
+    Interface *iface_orig = compiler->getCachedFwInterface( rule->getInt("nat_iface_orig") );
+    Interface *iface_trn  = compiler->getCachedFwInterface( rule->getInt("nat_iface_trn" ) );
 
     switch (rule->getRuleType()) 
     {
@@ -354,14 +357,14 @@ bool NATCompiler_pix::PrintRule::processNext()
                 break;
             case SINGLE_ADDRESS:
                 compiler->output << " " 
-                                 << natcmd->t_addr->getAddress().toString()
+                                 << natcmd->t_addr->getAddressPtr()->toString()
                                  << endl;
                 break;
             case NETWORK_ADDRESS:
                 compiler->output << " " 
-                                 << natcmd->t_addr->getAddress().toString() 
+                                 << natcmd->t_addr->getAddressPtr()->toString() 
                                  << " netmask "
-                                 << natcmd->t_addr->getNetmask().toString()
+                                 << natcmd->t_addr->getNetmaskPtr()->toString()
                                  << endl;
                 break;
             case ADDRESS_RANGE:
@@ -372,7 +375,7 @@ bool NATCompiler_pix::PrintRule::processNext()
                                  << "-"
                                  << ar->getRangeEnd().toString()
                                  << " netmask "
-                                 << natcmd->t_iface->getNetmask().toString()
+                                 << natcmd->t_iface->getNetmaskPtr()->toString()
                                  << endl;
             }
             break;
@@ -389,13 +392,16 @@ bool NATCompiler_pix::PrintRule::processNext()
                 libfwbuilder::XMLTools::version_compare(compiler->fw->getStr("version"),"6.3")<0)
             {
 /* old, < 6.3 */
-                compiler->output << "nat (" << natcmd->o_iface->getLabel() << ") "
-                                 << natcmd->nat_id
-                                 << " "
-                                 << natcmd->o_src->getAddress().toString()  << " "
-                                 << natcmd->o_src->getNetmask().toString();
-                if (natcmd->outside)  compiler->output << " outside";
-                else                  compiler->output << " " << _printConnOptions(rule);
+                compiler->output
+                    << "nat (" << natcmd->o_iface->getLabel() << ") "
+                    << natcmd->nat_id
+                    << " "
+                    << natcmd->o_src->getAddressPtr()->toString()  << " "
+                    << natcmd->o_src->getNetmaskPtr()->toString();
+                if (natcmd->outside)
+                    compiler->output << " outside";
+                else
+                    compiler->output << " " << _printConnOptions(rule);
                 compiler->output << endl;
             } else
             {
@@ -447,11 +453,11 @@ bool NATCompiler_pix::PrintRule::processNext()
 
     case NATRule::DNAT:
     {
-        StaticCmd *scmd=pix_comp->static_commands[ rule->getInt("sc_cmd") ];
+        StaticCmd *scmd = pix_comp->static_commands[ rule->getInt("sc_cmd") ];
 
-        IPAddress outa=scmd->oaddr->getAddress();
-        Netmask   outm=scmd->oaddr->getNetmask();
-        IPAddress insa=scmd->iaddr->getAddress();
+        const InetAddr *outa = scmd->oaddr->getAddressPtr();
+        const InetAddr *outm = scmd->oaddr->getNetmaskPtr();
+        const InetAddr *insa = scmd->iaddr->getAddressPtr();
 /*
  * we verify that odst and tdst have the same size in verifyRuleElements,
  * so we can rely on that now.
@@ -477,17 +483,17 @@ bool NATCompiler_pix::PrintRule::processNext()
                 compiler->output << "interface ";
                 if (use_ports)	_printPort(scmd->osrv);
 
-                compiler->output << insa.toString() << " ";
+                compiler->output << insa->toString() << " ";
                 if (use_ports)	_printPort(scmd->tsrv);
             } else
             {
-                compiler->output << outa.toString() << " ";
+                compiler->output << outa->toString() << " ";
                 if (use_ports)	_printPort(scmd->osrv);
 
-                compiler->output << insa.toString() << " ";
+                compiler->output << insa->toString() << " ";
                 if (use_ports)	_printPort(scmd->tsrv);
 
-                compiler->output << " netmask " << outm.toString();
+                compiler->output << " netmask " << outm->toString();
             }
             compiler->output << " " << _printConnOptions(rule) << endl;
         } else
@@ -540,8 +546,10 @@ bool NATCompiler_pix::PrintRule::processNext()
                 if (TCPService::cast(scmd->osrv)) { use_ports=true; compiler->output << "tcp "; }
                 if (UDPService::cast(scmd->osrv)) { use_ports=true; compiler->output << "udp "; }
 
-                if (Interface::cast(scmd->oaddr)!=NULL) compiler->output << "interface ";
-                else                                    compiler->output << outa.toString() << " ";
+                if (Interface::cast(scmd->oaddr)!=NULL)
+                    compiler->output << "interface ";
+                else
+                    compiler->output << outa->toString() << " ";
                 if (use_ports) _printPort(scmd->osrv);
                 compiler->output << " ";
 
